(function () {
    'use strict';

    queueListService.$inject = ["$resource", "amlConfig", "exceptionResourceHandler", "amlConstants"];
    angular
        .module('aml.admin')
        .factory('queueListService', queueListService);


    function queueListService($resource, amlConfig, exceptionResourceHandler, amlConstants) {
        var queueListPromise = null;
        var queueList;

        //the url here is: http://d10c667.na.sas.com:8780/SASComplianceSolutionsMid/rest so add the /queues
        var queueResource = $resource(amlConfig.baseUrl + '/queues',
            {},     //empty, we just send the queue object -- Spring serializes/de-serializes to java object of type Queue when requested
            {
                create: {
                    method: 'POST',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                getActiveNonDeleted: {
                    method: 'GET',
                    params: {'getActiveOnly' : 'true'},
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                getAll: {
                    method: 'GET',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                update: {
                    method: 'PUT', interceptor: {responseError: exceptionResourceHandler.resourceErrorHandler}
                    //this is idempotent, resource change is independent of number of times requested
                }
            }
        );

        var queueResourceForFilter = $resource(amlConfig.baseUrl + '/users/current/queues',
            {},
            {
                get: {
                    method: 'GET',
                    params: {'returnType' : 'Queue'},
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                }
            }
        );

        var queueUsersResource = $resource(amlConfig.baseUrl + '/queues/:queueCode/users',
            { queueCode: '@queueCode' },
            {
                get: {
                    method: 'GET',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                }
            }
        );

        function createQueue(queue) {
            return queueResource.create( queue ).$promise;
        }

        function getQueues(getActiveOnly) {
            if (getActiveOnly) {
                return queueResource.getActiveNonDeleted({ }).$promise;
            } else {
                return queueResource.getAll({ }).$promise;
            }
        }

        function getFilterQueuePreference() {
            return amlConstants.config.filterIncludeInactiveQueues;
        }

        function downloadQueueList() {

            // This method is called from app.routes.js
            if(!queueListPromise) {
                queueListPromise = queueResourceForFilter.get({}).$promise.then(function(data) {
                    queueList = data;
                    return data;
                });
            }

            return queueListPromise;
        }

        function getQueueListArray(type) {
            var filterFunction;
            var filterIncludeInactiveQueues = getFilterQueuePreference();
            if(filterIncludeInactiveQueues === undefined || filterIncludeInactiveQueues === null) {
                filterIncludeInactiveQueues = true;
            }

            if(type === 'deleted') {
                filterFunction = function(item) {
                    return item.logicalDeleteInd === 'Y' && (filterIncludeInactiveQueues ? true : item.activeInd === 'Y');
                };
            }
            else if(type === 'nondeleted') {
                filterFunction = function(item) {
                    return item.logicalDeleteInd === 'N' && (filterIncludeInactiveQueues ? true : item.activeInd === 'Y');
                };
            }
            else {
                filterFunction = function (item) {
                    return (filterIncludeInactiveQueues ? true : item.activeInd === 'Y');
                };
            }

            return queueList.items.filter(filterFunction);
        }

        function updateQueue(queue) {       //used for updating a logically deleting a queue
            return queueResource.update( queue ).$promise;
        }

        function getQueueUsers(queueCode) {
            return queueUsersResource.get({queueCode: queueCode}).$promise;
        }


        var service = {

            getQueueListArray: getQueueListArray,
            downloadQueueList: downloadQueueList,
            getQueues: getQueues,
            createQueue: createQueue,
            updateQueue: updateQueue,
            getQueueUsers: getQueueUsers

        };


        return service;

    }
})();
