(function () {
    'use strict';

    segmentListService.$inject = ["$resource", "amlConfig", "exceptionResourceHandler"];
    angular
        .module('aml.admin')
        .factory('segmentListService', segmentListService);


    function segmentListService($resource, amlConfig, exceptionResourceHandler) {


        //the url here is: http://dxxxxxx.na.sas.com:8780/SASComplianceSolutionsMid/rest so add the /segments
        var segmentResource = $resource(amlConfig.baseUrl + '/segments',
            {},     //empty, we just send the segment object -- Spring serializes/de-serializes to java object of type Segment when requested
            {
                create: {
                    method: 'POST',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                get: {
                    params: {type: '@type'},
                    method: 'GET',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                update: {
                    method: 'PUT', interceptor: {responseError: exceptionResourceHandler.resourceErrorHandler}
                    //this is idempotent, resource change is independent of number of times requested
                }
            }
        );


        function createSegment(segment) {
            return segmentResource.create( segment ).$promise;
        }

        function getSegments(type) {
            return segmentResource.get({ type: type }).$promise;
        }

        function updateSegment(segment) {       //used for updating a logically deleting a segment
            return segmentResource.update( segment ).$promise;
        }


        var service = {

            getSegments: getSegments,
            createSegment: createSegment,
            updateSegment: updateSegment

        };


        return service;

    }
})();
