
/***********************************************************************************/
/* Copyright (c) 2009-2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved */
/*                                                                                 */
/* NAME:          rc_global_mvar.sas                                               */
/* PRODUCT:       SAS Regulatory Console                                           */
/* PURPOSE:       Create global macro variables and set SAS system options for     */
/*                SAS Regulatory Console                                           */
/* PARAMETERS:    None                                                             */
/* NOTE:                                                                           */
/***********************************************************************************/

%macro rc_global_mvar;

options NOQUOTELENMAX;

%global rc_charMultiplier
        rc_dtFmt
        rc_dttmFmt
        rc_debug
        rc_win_zip_cmd
        rc_unix_zip_cmd
        nbsp
        rc_webusername
        rc_webpassword

        rc_efile_path
        rc_efile_resp_path
        rc_sdtm_YN_sar
        rc_sdtm_YN_sarx
        rc_sdtm_YN_ctr
        rc_sdtm_YN_ctrx
        rc_sdtm_YN_doep
        rc_sdtm_YN_doepx
        rc_sdtm_suffix_sar
        rc_sdtm_suffix_sarx
        rc_sdtm_suffix_ctr
        rc_sdtm_suffix_ctrx
        rc_sdtm_suffix_doep
        rc_sdtm_suffix_doepx
        rc_sdtm_efile_path_sar
        rc_sdtm_efile_path_sarx
        rc_sdtm_efile_path_ctr
        rc_sdtm_efile_path_ctrx
        rc_sdtm_efile_path_doep
        rc_sdtm_efile_path_doepx
        rc_sdtm_resp_path_sar
        rc_sdtm_resp_path_sarx
        rc_sdtm_resp_path_ctr 
        rc_sdtm_resp_path_ctrx
        rc_sdtm_resp_path_doep
        rc_sdtm_resp_path_doepx
          
        rc_resp_case_updt_YN_sar
        rc_resp_case_updt_YN_sarx
        rc_resp_case_updt_YN_ctr
        rc_resp_case_updt_YN_ctrx
        rc_resp_case_updt_YN_doep
        rc_resp_case_updt_YN_doepx
        rc_resp_parent_comment_updt_YN
 
        rc_json_max_level

        rc_validate_xml_source_YN

        ;

/* html tag that may appears in column labels */
%let nbsp=;

/* In 9.3, sas server is default to Unicode */
/* So the length of the this macro is set based on the default locale (English) */

%let rc_charMultiplier=1;

/* Uncomment the following line if the length multiplication should be set based on the SAS environment */
 
/*
  %if  %sysfunc(getoption(DBCS))=DBCS %then %let rc_charMultiplier=2;
  %else %let rc_charMultiplier=1;
*/

%let rc_dtfmt=nldate10;
%let rc_dttmfmt=nldatm20;

%let rc_debug=N;
 

/* Specify the path of the winzip command for Windows only                                     */
/* Make the macro variable is properly quoted because the path may contains special characters */
/* Example for 7-zip */
%let rc_win_zip_cmd=%nrstr("C:\Program Files\7-Zip\7z" a -tzip);

/* Example for WINZIP */
%*let rc_win_zip_cmd=%nrstr("C:\Program Files\WinZip\WZZIP.exe");

%let rc_unix_zip_cmd=%nrstr(zip -j);

/* Specify the web credential from sas metadata for accessing attachment service API */
/* The password can be encoded using PROC PWENCODE                                   */
/* If web credential is not defined, the password of the user will be retreived      */
/* from the metadata server.                                                         */

%let rc_webusername=;
%let rc_webpassword=;

/************************************************************************/
/* Macro variables to support general efile process.                    */
/************************************************************************/

%let rc_efile_path=&rcdata_path&slash.efiles;
%let rc_efile_resp_path=&rcdata_path&slash.efiles_responses;

/*******************************************************/
/* Macro variables to support FINCEN SDTM process.     */
/* Only relevant to sites filing regulatory reports to */
/* FINCEN using SDTM (Secured Direct Transfer Method)  */
/*******************************************************/

/* Specifiy whether FINCEN e-files should be generated for SDTM process */

%let rc_sdtm_YN_sar=Y;
%let rc_sdtm_YN_sarx=Y;
%let rc_sdtm_YN_ctr=Y;
%let rc_sdtm_YN_ctrx=Y;
%let rc_sdtm_YN_doep=Y;
%let rc_sdtm_YN_doepx=Y;

/* Specify your organization name for use in SDTM e-file names. */

%let rc_sdtm_suffix_sar=SAR_ORG;
%let rc_sdtm_suffix_sarx=SARX_ORG;
%let rc_sdtm_suffix_ctr=CTR_ORG;
%let rc_sdtm_suffix_ctrx=CTRX_ORG;
%let rc_sdtm_suffix_doep=DOEP_ORG;
%let rc_sdtm_suffix_doepx=DOEPX_ORG;
 
/* Specify the directory paths where the e-files should be generated for SDTM. */

%let rc_sdtm_efile_path_sar=&rcdata_path&slash.FINCEN_SDTM_efiles&slash.fincen-sar-v1;
%let rc_sdtm_efile_path_sarx=&rcdata_path&slash.FINCEN_SDTM_efiles&slash.fincen-sarx-v1;
%let rc_sdtm_efile_path_ctr=&rcdata_path&slash.FINCEN_SDTM_efiles&slash.fincen-ctr-v1;
%let rc_sdtm_efile_path_ctrx=&rcdata_path&slash.FINCEN_SDTM_efiles&slash.fincen-ctrx-v1;
%let rc_sdtm_efile_path_doep=&rcdata_path&slash.FINCEN_SDTM_efiles&slash.fincen-doep-v1;
%let rc_sdtm_efile_path_doepx=&rcdata_path&slash.FINCEN_SDTM_efiles&slash.fincen-doepx-v1;

/* Specify the directory paths where the acknowledgement receipts from SDTM are saved. */

%let rc_sdtm_resp_path_sar=&rcdata_path&slash.FINCEN_SDTM_efiles_responses&slash.fincen-sar-v1;
%let rc_sdtm_resp_path_sarx=&rcdata_path&slash.FINCEN_SDTM_efiles_responses&slash.fincen-sarx-v1;
%let rc_sdtm_resp_path_ctr=&rcdata_path&slash.FINCEN_SDTM_efiles_responses&slash.fincen-ctr-v1;
%let rc_sdtm_resp_path_ctrx=&rcdata_path&slash.FINCEN_SDTM_efiles_responses&slash.fincen-ctrx-v1;
%let rc_sdtm_resp_path_doep=&rcdata_path&slash.FINCEN_SDTM_efiles_responses&slash.fincen-doep-v1;
%let rc_sdtm_resp_path_doepx=&rcdata_path&slash.FINCEN_SDTM_efiles_responses&slash.fincen-doepx-v1;

/* Set rc_RESP_CASE_UPDT_YN_<form> to N  if no parent case change should be made when an acknowledge receipt is received. */
 
%let rc_resp_case_updt_YN_sar=Y;
%let rc_resp_case_updt_YN_sarx=Y;
%let rc_resp_case_updt_YN_ctr=Y;
%let rc_resp_case_updt_YN_ctrx=Y;
%let rc_resp_case_updt_YN_doep=N;
%let rc_resp_case_updt_YN_doepx=N;

/* Specify whether a commment should be posted to the parent of the report when an acknowledge receipt is received. */
/* Set rc_resp_parent_comment_updt_yn to N if a comment should not be added.                                        */

%let rc_resp_parent_comment_updt_YN=Y;
 
/* Determine if the XML Source is displayed by default when displaying Validate Report output. */
/* If set to N, XML Source is only displayed when an XML validation error occurs.              */
%let rc_validate_xml_source_YN=Y;

%let rc_json_max_level=1;

%mend;
 
