/*==============================================================================
|                               SAS SAMPLE FILE
|
| NAME:    unrelated_transfers_prep.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================


PREP FILE DESCRIPTION
---------------------
Creates unrelated_transfers prep data set


PREP FILE NOTES
---------------
1. This code converts date_key from an integer value in yyyymmdd format to a SAS
date value. The converted value of date_key is then output to the prep data set
as required by dependent scenario(s).

The value of date_key is not converted from an integer value in yyyymmdd format
as used in the where clause, as this value is compared to runasofdate which is
also an integer value in yyyymmdd format.


PREP DATA SET(S) CREATED
------------------------
MST_PREP.UNRELATED_TRANSFERS


PREP DATA SET(S) SORT ORDER
----------------------------

| Data Set                         Field                           Sort Order
|--------------------------------|-------------------------------|--------------
|UNRELATED_TRANSFERS             |PARTY_NUMBER                   |1
|UNRELATED_TRANSFERS             |DATE_KEY                       |2


PREP DATA SET(S) VOLUME
-----------------------
1. UNRELATED_TRANSFERS is expected to contain all internal transfers where the
remitting and beneficiary accounts/parties are not members of the same
household. The character of a transfer is expected to be determined once during
the ETL process and stored in FSC_CASH_FLOW_FACT.RELATED_IND.


PREP DATA SET(S) NOTES
----------------------
None


================================================================================
SCENARIO(S) SUPPORTED:

- SAS10074
==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2014 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

 proc sql;

    create table mst_prep.unrelated_transfers as

    select
       a.party_number,
       b.account_type_desc,
       c.currency_amount,
       input(put(c.date_key,8.),yymmdd8.) as date_key,
       c.transaction_key,
       d.transaction_cdi_code,
       a.entity_segment_id

    from
       seg_kc.fsc_party_dim a,
       seg_kc.fsc_account_dim b,
       seg_kc.fsc_cash_flow_fact c,
       seg_kc.fsc_transaction_type_dim d,
       seg_kc.fsc_party_account_bridge e

    where
       c.account_key          = b.account_key          and
       b.account_key          = e.account_key          and
       a.party_key            = e.party_key            and
       c.related_ind          = 'N'                    and
       e.change_current_ind   = 'Y'                    and
       c.transaction_type_key = d.transaction_type_key and
       d.primary_medium_desc  = 'INTERNAL TRANSFER'    and
       e.role_key             = 1                      and
       c.date_key             <= &runasofdate

    order by party_number, date_key;

 quit;
