-- Add segments
CREATE TABLE FCFKC.FSK_SEGMENT (
  entity_segment_key  NUMERIC(12) NOT NULL,
  entity_segment_id   NUMERIC(12) NOT NULL,
  segment_name        VARCHAR(50),
  segment_description VARCHAR(100),
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
  change_end_date     TIMESTAMP NOT NULL DEFAULT TIMESTAMP('59990101000000'),
  change_current_ind  CHAR(1) NOT NULL DEFAULT 'Y',
  CONSTRAINT XPKFSK_SEGMENT PRIMARY KEY (entity_segment_key)
);

ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM   ADD entity_segment_id         NUMERIC(12) NULL;
ALTER TABLE FCFCORE.FSC_PARTY_DIM     ADD entity_segment_id         NUMERIC(12) NULL;
ALTER TABLE FCFKC.FSK_ALERT           ADD entity_segment_id         NUMERIC(12) NULL;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY  ADD alerted_entity_segment_id NUMERIC(12) NULL;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY  alter column alerted_entity_name  set data type VARCHAR(200);
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY  DROP COLUMN owner_userid;

CREATE OR REPLACE VIEW FCFBU1.FSC_PARTY_DIM AS SELECT * FROM FCFCORE.FSC_PARTY_DIM;
CREATE OR REPLACE VIEW FCFBU1.FSK_SEGMENT AS SELECT * FROM FCFKC.FSK_SEGMENT;
CREATE OR REPLACE VIEW FCFBU1.FSK_ALERTED_ENTITY AS SELECT * FROM FCFKC.FSK_ALERTED_ENTITY;

ALTER TABLE FCFKC.FSK_SCENARIO_PARAMETER DROP CONSTRAINT  PK_SCEN_PARAM;
ALTER TABLE FCFKC.FSK_SCENARIO_PARAMETER
   ADD COLUMN btl_parm_value      VARCHAR(1024) NULL
   ADD COLUMN entity_segment_id   NUMERIC(12) NOT NULL DEFAULT -1;
ALTER TABLE FCFKC.FSK_SCENARIO_PARAMETER 	ADD CONSTRAINT PK_SCEN_PARAM PRIMARY KEY (scenario_id, entity_segment_id, parm_name);
CREATE OR REPLACE VIEW FCFBU1.FSK_SCENARIO_PARAMETER AS SELECT * FROM FCFKC.FSK_SCENARIO_PARAMETER;

ALTER TABLE FCFKC.FSK_SCENARIO
ADD COLUMN segments_enabled_ind CHAR(1) NULL DEFAULT 'N'
ADD COLUMN btl_enabled_ind      CHAR(1) NULL DEFAULT 'N';
CREATE OR REPLACE VIEW FCFBU1.FSK_SCENARIO AS SELECT * FROM FCFKC.FSK_SCENARIO;

REORG TABLE FCFKC.FSK_ALERTED_ENTITY;

-- Add queues

CREATE TABLE FCFKC.FSK_QUEUE (
  queue_key           NUMERIC(12) NOT NULL,
  queue_code          VARCHAR(32) NOT NULL,
  queue_description   VARCHAR(100),
  access_role_name    VARCHAR(60) NOT NULL,
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
  change_end_date     TIMESTAMP NOT NULL DEFAULT TIMESTAMP('59990101000000'),
  change_current_ind  CHAR(1) NOT NULL DEFAULT 'Y',
  CONSTRAINT XPKFSK_QUEUE PRIMARY KEY (queue_key)
);

CREATE INDEX FCFKC.IDX_ID_FSK_QUEUE ON FCFKC.FSK_QUEUE (queue_code ASC);

ALTER TABLE FCFKC.FSK_ALERT           ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_CASE            ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_CDD_REVIEW      ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_RC_REPORT       ADD queue_code         VARCHAR(32) NULL;
ALTER TABLE FCFKC.FSK_RC_REPORT       ADD employee_ind  CHAR(1) NULL DEFAULT 'N';

CREATE INDEX FCFKC.XEIQFSK_ALERT ON FCFKC.FSK_ALERT (queue_code);
CREATE INDEX FCFKC.XEIQFSK_CASE ON FCFKC.FSK_CASE (queue_code);
CREATE INDEX FCFKC.XEIQFSK_CDD_REVIEW ON FCFKC.FSK_CDD_REVIEW (queue_code);
CREATE INDEX FCFKC.XEIQFSK_RC_REPORT ON FCFKC.FSK_RC_REPORT (queue_code);

CREATE OR REPLACE VIEW FCFBU1.FSK_QUEUE AS SELECT * FROM FCFKC.FSK_QUEUE;
CREATE OR REPLACE VIEW FCFBU1.FSK_CDD_REVIEW AS SELECT * FROM FCFKC.FSK_CDD_REVIEW;
CREATE OR REPLACE VIEW FCFBU1.FSK_RC_REPORT AS SELECT * FROM FCFKC.FSK_RC_REPORT;

CREATE TABLE FCFKC.FSK_ENTITY_QUEUE (
  queue_code                VARCHAR(32) NULL,
	alerted_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_number     VARCHAR(50) NOT NULL,
	owner_userid              VARCHAR(60) NULL
);
CREATE INDEX FCFKC.IDX_ID_FSK_ENTITY_QUEUE ON FCFKC.FSK_ENTITY_QUEUE (alerted_entity_level_code, alerted_entity_number, queue_code, owner_userid);
CREATE OR REPLACE VIEW FCFBU1.FSK_ENTITY_QUEUE AS SELECT * FROM FCFKC.FSK_ENTITY_QUEUE;

-- AML-800: Add case close date
ALTER TABLE FCFKC.FSK_CASE ADD case_close_date TIMESTAMP NULL;
CREATE OR REPLACE VIEW FCFBU1.FSK_CASE AS SELECT * FROM FCFKC.FSK_CASE;


CREATE TABLE FCFKC.FSK_RC_REPORT_ENTITY_BRIDGE (
	report_key           NUMERIC(12) NOT NULL ,
	parent_level_code    VARCHAR(32) NOT NULL ,
	parent_key           NUMERIC(12) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	entity_key           NUMERIC(12) NOT NULL ,
	ui_json              CLOB NULL ,
  CONSTRAINT XPKFSK_RPT_ENT_BR PRIMARY KEY (report_key, parent_key, entity_key)
);

ALTER TABLE FCFKC.FSK_RC_REPORT_ENTITY_BRIDGE
	ADD CONSTRAINT FSK_RC_ENT_BRIDGE_RPT FOREIGN KEY (report_key) REFERENCES FCFKC.FSK_RC_REPORT (report_key);

CREATE OR REPLACE VIEW FCFBU1.FSK_RC_REPORT_ENTITY_BRIDGE AS SELECT * FROM FCFKC.FSK_RC_REPORT_ENTITY_BRIDGE;

-- AML-1213: standardize lengths for entity name
ALTER TABLE FCFKC.FSK_ALERT ALTER COLUMN alerted_entity_name set data type VARCHAR(200);
ALTER TABLE FCFKC.FSK_ALERT alter column primary_entity_name  set data type VARCHAR(200);
ALTER TABLE FCFKC.FSK_CASE_ENTITY alter column entity_name  set data type VARCHAR(200);
ALTER TABLE FCFKC.FSK_RC_REPORT_ENTITY alter column entity_name  set data type VARCHAR(200);
ALTER TABLE FCFKC.FSK_RC_REPORT_ENTITY_INFO alter column entity_name  set data type VARCHAR(200);

ALTER TABLE FCFCORE.FSC_BANK_DIM alter column bank_name  set data type VARCHAR(200);
ALTER TABLE FCFCORE.FSC_ASSOCIATE_DIM alter column associate_last_name  set data type VARCHAR(200);
ALTER TABLE FCFCORE.FSC_HOUSEHOLD_DIM alter column head_of_household_name  set data type VARCHAR(200);
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM alter column account_name  set data type VARCHAR(200);

CREATE OR REPLACE VIEW FCFBU1.FSK_ALERT AS SELECT * FROM FCFKC.FSK_ALERT;
CREATE OR REPLACE VIEW FCFBU1.FSK_CASE_ENTITY AS SELECT * FROM FCFKC.FSK_CASE_ENTITY;
CREATE OR REPLACE VIEW FCFBU1.FSK_RC_REPORT_ENTITY AS SELECT * from FCFKC.FSK_RC_REPORT_ENTITY;
CREATE OR REPLACE VIEW FCFBU1.FSK_RC_REPORT_ENTITY_INFO AS SELECT * FROM FCFKC.FSK_RC_REPORT_ENTITY_INFO;
CREATE OR REPLACE VIEW FCFBU1.FSC_BANK_DIM AS SELECT * FROM FCFCORE.FSC_BANK_DIM;
CREATE OR REPLACE VIEW FCFBU1.FSC_ASSOCIATE_DIM AS SELECT * FROM FCFCORE.FSC_ASSOCIATE_DIM;
CREATE OR REPLACE VIEW FCFBU1.FSC_HOUSEHOLD_DIM AS SELECT * FROM FCFCORE.FSC_HOUSEHOLD_DIM;
CREATE OR REPLACE VIEW FCFBU1.FSC_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_ACCOUNT_DIM;

CREATE OR REPLACE VIEW FCFBU1.FSC_TRANSACTION_VIEW (account_key, account_number, branch_key, date_key, time_key, transaction_type_key, transaction_key,
currency_amount, transaction_reference_number, transaction_description, security_name, deal_number, bank_name_1, role_desc_1, bank_name_2,
role_desc_2, bank_name_3, role_desc_3, bank_name_4, role_desc_4, bank_name_5, role_desc_5, bank_name_6, role_desc_6) AS SELECT CFF.account_key,
ACC.account_number, CFF.branch_key, CFF.date_key, CFF.time_key, CFF.transaction_type_key, CFF.transaction_key, CFF.currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, BD.BANK_NAME AS bank_name_1, CFBB.Role_Desc AS role_desc_1, BD2.BANK_NAME AS bank_name_2,
 CFBB2.Role_Desc AS role_desc_2, BD3.BANK_NAME AS bank_name_3, CFBB3.Role_Desc AS role_desc_3, BD4.BANK_NAME AS bank_name_4, CFBB4.Role_Desc AS role_desc_4,
BD5.BANK_NAME AS bank_name_5, CFBB5.Role_Desc AS role_desc_5, BD6.BANK_NAME AS bank_name_6, CFBB6.Role_Desc AS role_desc_6
FROM FCFCORE.FSC_CASH_FLOW_FACT CFF JOIN FCFCORE.FSC_TRANSACTION_DIM TD ON CFF.transaction_key = TD.transaction_key
JOIN FCFCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key  LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB
ON CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY AND CFBB.SEQUENCE_NUMBER = 1 LEFT JOIN FCFCORE.FSC_BANK_DIM BD
ON CFBB.BANK_KEY = BD.BANK_KEY LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 ON CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY
AND CFBB2.SEQUENCE_NUMBER = 2  LEFT JOIN FCFCORE.FSC_BANK_DIM BD2 ON CFBB2.BANK_KEY = BD2.BANK_KEY
LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 ON CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY AND CFBB3.SEQUENCE_NUMBER = 3
LEFT JOIN FCFCORE.FSC_BANK_DIM BD3 ON CFBB3.BANK_KEY = BD3.BANK_KEY  LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4
ON CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY AND CFBB4.SEQUENCE_NUMBER = 4 LEFT JOIN FCFCORE.FSC_BANK_DIM BD4
ON CFBB4.BANK_KEY = BD4.BANK_KEY  LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 ON CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY
AND CFBB5.SEQUENCE_NUMBER = 5  LEFT JOIN FCFCORE.FSC_BANK_DIM BD5 ON CFBB5.BANK_KEY = BD5.BANK_KEY
LEFT JOIN FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 ON CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY AND CFBB6.SEQUENCE_NUMBER = 6
LEFT JOIN FCFCORE.FSC_BANK_DIM BD6 ON CFBB6.BANK_KEY = BD6.BANK_KEY
UNION ALL(SELECT AEF.account_key,
ACC.account_number, AEF.branch_key, AEF.date_key, AEF.time_key, AEF.transaction_type_key, AEF.transaction_key, 0, TD.transaction_reference_number, TD.transaction_description,
TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM FCFCORE.FSC_ACCOUNT_EVENT_FACT AEF JOIN FCFCORE.FSC_ACCOUNT_DIM ACC
ON AEF.account_key = ACC.account_key  JOIN FCFCORE.FSC_TRANSACTION_DIM TD ON AEF.transaction_key = TD.transaction_key
UNION ALL
(SELECT ATF.account_key, ACC.account_number, ATF.branch_key, ATF.trade_date_key AS date_key,
ATF.execution_time_key AS time_key, ATF.transaction_type_key, ATF.transaction_key, ATF.principal_amount AS currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM FCFCORE.FSC_ACCOUNT_TRADE_FACT ATF
JOIN FCFCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key  JOIN FCFCORE.FSC_TRANSACTION_DIM TD
ON ATF.transaction_key = TD.transaction_key));
