-------------------------------------------------------------------
-- NAME:    AML7.5.5__drop_bu.sql
-- PRODUCT: SAS Compliance Solutions
-- DESC:    recreate views for business unit schema ready after
--          column type conversion
-------------------------------------------------------------------
-- USAGE:   Substiture the schema for each of your business units 
--          and execute in your SQL Server client
-------------------------------------------------------------------
-------------------------------------------------------------------
-- Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
--               All Rights Reserved.
-------------------------------------------------------------------

USE [LOCALDB]
GO

CREATE VIEW SCHBU1.FSK_CDD_EDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_EDD_REVIEW
GO

CREATE VIEW SCHBU1.FSK_CDD_REVIEW_EVENT AS SELECT * FROM SCHKC.FSK_CDD_REVIEW_EVENT
GO

CREATE VIEW SCHBU1.FSK_CDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_REVIEW
GO

CREATE  VIEW SCHBU1.FSK_SEQ AS SELECT next_sequence_id FROM SCHKC.FSK_SEQ
GO

CREATE PROCEDURE [SCHBU1].[GET_SEQ]( @next_seq DECIMAL(12,0) OUTPUT )
AS
 BEGIN TRANSACTION
   set @next_seq = (select next_sequence_id from SCHBU1.FSK_SEQ with
   (updlock, rowlock))
   update SCHBU1.fsk_seq set next_sequence_id = next_sequence_id + 1
 COMMIT
GO

----- SCHBU1 views on Vector table. This  is only needed in SQL Server 2012 ------

CREATE  VIEW SCHBU1.FSC_ACCOUNT_STATE_VECTOR_FACT
AS SELECT SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.account_number,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.date_key,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.account_type_desc,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.debits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.credits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.atm_debits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.atm_credits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.atm_d_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.atm_c_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.debit_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.credit_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.debit_loc_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.credit_loc_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.atm_d_loc_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.atm_c_loc_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.wire_credit_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.wire_credit_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.wire_debits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.wire_debit_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.d_i_wire_credits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.d_i_wire_credit_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.d_i_wire_debits_total,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.d_i_wire_debit_trans_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.balance_inquiry_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.exceeded_daily_limit_count,
SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT.insufficient_funds_count
FROM SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT
GO


CREATE  VIEW SCHBU1.fsc_account_state_vector_view
AS
   SELECT 
    account_number,
    account_type_desc,
    date_key,
        debits_total,
          SUM (debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                               debits_total_5,
          SUM (debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                              debits_total_10,
          SUM (debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                              debits_total_30,
          credits_total,
          SUM (credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                              credits_total_5,
          SUM (credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                             credits_total_10,
          SUM (credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                             credits_total_30,
          atm_debits_total,
          SUM (atm_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                           atm_debits_total_5,
          SUM (atm_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                          atm_debits_total_10,
          SUM (atm_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                          atm_debits_total_30,
          atm_credits_total,
          SUM (atm_credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                          atm_credits_total_5,
          SUM (atm_credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                         atm_credits_total_10,
          SUM (atm_credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                         atm_credits_total_30,
          atm_d_trans_count,
          SUM (atm_d_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                          atm_d_trans_count_5,
          SUM (atm_d_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                         atm_d_trans_count_10,
          SUM (atm_d_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                         atm_d_trans_count_30,
          atm_c_trans_count,
          SUM (atm_c_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                          atm_c_trans_count_5,
          SUM (atm_c_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                         atm_c_trans_count_10,
          SUM (atm_c_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                         atm_c_trans_count_30,
          debit_trans_count,
          SUM (debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                          debit_trans_count_5,
          SUM (debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                         debit_trans_count_10,
          SUM (debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                         debit_trans_count_30,
          credit_trans_count,
          SUM (credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                         credit_trans_count_5,
          SUM (credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                        credit_trans_count_10,
          SUM (credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                        credit_trans_count_30,
          debit_loc_count,
          SUM (debit_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                            debit_loc_count_5,
          SUM (debit_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                           debit_loc_count_10,
          SUM (debit_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                           debit_loc_count_30,
          credit_loc_count,
          SUM (credit_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                           credit_loc_count_5,
          SUM (credit_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                          credit_loc_count_10,
          SUM (credit_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                          credit_loc_count_30,
          atm_d_loc_count,
          SUM (atm_d_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                            atm_d_loc_count_5,
          SUM (atm_d_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                           atm_d_loc_count_10,
          SUM (atm_d_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                           atm_d_loc_count_30,
          atm_c_loc_count,
          SUM (atm_c_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                            atm_c_loc_count_5,
          SUM (atm_c_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                           atm_c_loc_count_10,
          SUM (atm_c_loc_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                           atm_c_loc_count_30,
          wire_credit_total,
          SUM (wire_credit_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                          wire_credit_total_5,
          SUM (wire_credit_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                         wire_credit_total_10,
          SUM (wire_credit_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                         wire_credit_total_30,
          wire_credit_trans_count,
          SUM (wire_credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                    wire_credit_trans_count_5,
          SUM (wire_credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                   wire_credit_trans_count_10,
          SUM (wire_credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                   wire_credit_trans_count_30,
          wire_debits_total,
          SUM (wire_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                          wire_debits_total_5,
          SUM (wire_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                         wire_debits_total_10,
          SUM (wire_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                         wire_debits_total_30,
          wire_debit_trans_count,
          SUM (wire_debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                     wire_debit_trans_count_5,
          SUM (wire_debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                    wire_debit_trans_count_10,
          SUM (wire_debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                    wire_debit_trans_count_30,
          d_i_wire_credits_total,
          SUM (d_i_wire_credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                     d_i_wire_credits_total_5,
          SUM (d_i_wire_credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                    d_i_wire_credits_total_10,
          SUM (d_i_wire_credits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                    d_i_wire_credits_total_30,
          d_i_wire_credit_trans_count,
          SUM (d_i_wire_credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                d_i_wire_credit_trans_count_5,
          SUM (d_i_wire_credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                               d_i_wire_credit_trans_count_10,
          SUM (d_i_wire_credit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                               d_i_wire_credit_trans_count_30,
          d_i_wire_debits_total,
          SUM (d_i_wire_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                      d_i_wire_debits_total_5,
          SUM (d_i_wire_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                     d_i_wire_debits_total_10,
          SUM (d_i_wire_debits_total) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                     d_i_wire_debits_total_30,
          d_i_wire_debit_trans_count,
          SUM (d_i_wire_debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                 d_i_wire_debit_trans_count_5,
          SUM (d_i_wire_debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                d_i_wire_debit_trans_count_10,
          SUM (d_i_wire_debit_trans_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                d_i_wire_debit_trans_count_30,
          balance_inquiry_count,
          SUM (balance_inquiry_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                      balance_inquiry_count_5,
          SUM (balance_inquiry_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                     balance_inquiry_count_10,
          SUM (balance_inquiry_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                     balance_inquiry_count_30,
          exceeded_daily_limit_count,
          SUM (exceeded_daily_limit_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                 exceeded_daily_limit_count_5,
          SUM (exceeded_daily_limit_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                exceeded_daily_limit_count_10,
          SUM (exceeded_daily_limit_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                exceeded_daily_limit_count_30,
          insufficient_funds_count,
          SUM (insufficient_funds_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 4 PRECEDING AND CURRENT ROW)
                                                   insufficient_funds_count_5,
          SUM (insufficient_funds_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 9 PRECEDING AND CURRENT ROW)
                                                  insufficient_funds_count_10,
          SUM (insufficient_funds_count) OVER (PARTITION BY account_number ORDER BY date_key ROWS BETWEEN 29 PRECEDING AND CURRENT ROW)
                                                  insufficient_funds_count_30
     FROM SCHCORE.fsc_account_state_vector_fact
GO

---------- Paste SCHBU1 views on SCHCORE tables starting here. -----------------

CREATE  VIEW SCHBU1.FSC_ACCOUNT_ANALYSIS_DIM AS SELECT * FROM SCHCORE.FSC_ACCOUNT_ANALYSIS_DIM
GO

CREATE  VIEW SCHBU1.FSC_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_ACCOUNT_DIM
GO

CREATE  VIEW SCHBU1.FSC_ACCOUNT_EVENT_FACT AS SELECT * FROM SCHCORE.FSC_ACCOUNT_EVENT_FACT
GO

CREATE  VIEW SCHBU1.FSC_ACCOUNT_PROFILE_FACT AS SELECT * FROM SCHCORE.FSC_ACCOUNT_PROFILE_FACT
GO

CREATE  VIEW SCHBU1.FSC_ACCOUNT_TRADE_FACT AS SELECT * FROM SCHCORE.FSC_ACCOUNT_TRADE_FACT
GO

CREATE  VIEW SCHBU1.FSC_ASSOCIATE_DIM AS SELECT * FROM SCHCORE.FSC_ASSOCIATE_DIM
GO

CREATE  VIEW SCHBU1.FSC_BANK_DIM AS SELECT * FROM SCHCORE.FSC_BANK_DIM
GO

CREATE  VIEW SCHBU1.FSC_BRANCH_DIM AS SELECT * FROM SCHCORE.FSC_BRANCH_DIM
GO

CREATE  VIEW SCHBU1.FSC_CASH_FLOW_BANK_BRIDGE AS SELECT * FROM SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE 
GO

CREATE  VIEW SCHBU1.FSC_CASH_FLOW_FACT AS SELECT * FROM SCHCORE.FSC_CASH_FLOW_FACT
GO

CREATE  VIEW SCHBU1.FSC_CLASSIFIER_FACT AS SELECT * FROM SCHCORE.FSC_CLASSIFIER_FACT
GO

CREATE  VIEW SCHBU1.FSC_COUNTRY_DIM AS SELECT * FROM SCHCORE.FSC_COUNTRY_DIM
GO

CREATE  VIEW SCHBU1.FSC_CURRENCY_DIM AS SELECT * FROM SCHCORE.FSC_CURRENCY_DIM
GO

CREATE  VIEW SCHBU1.FSC_DATE_DIM AS SELECT * FROM SCHCORE.FSC_DATE_DIM
GO

CREATE  VIEW SCHBU1.FSC_ENTITY_WATCH_LIST_DIM AS SELECT * FROM SCHCORE.FSC_ENTITY_WATCH_LIST_DIM
GO

CREATE  VIEW SCHBU1.FSC_EXT_PARTY_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM 
GO

CREATE  VIEW SCHBU1.FSC_HOUSEHOLD_ACCOUNT_BRIDGE AS SELECT * FROM SCHCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
GO

CREATE  VIEW SCHBU1.FSC_HOUSEHOLD_DIM AS SELECT * FROM SCHCORE.FSC_HOUSEHOLD_DIM
GO

CREATE  VIEW SCHBU1.FSC_HOUSEHOLD_PARTY_BRIDGE AS SELECT * FROM SCHCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
GO

CREATE  VIEW SCHBU1.FSC_LOCATION_WATCH_LIST_DIM AS SELECT * FROM SCHCORE.FSC_LOCATION_WATCH_LIST_DIM
GO

CREATE  VIEW SCHBU1.FSC_MONTH_DIM AS SELECT * FROM SCHCORE.FSC_MONTH_DIM
GO

CREATE  VIEW SCHBU1.FSC_PARTY_ACCOUNT_BRIDGE AS SELECT * FROM SCHCORE.FSC_PARTY_ACCOUNT_BRIDGE
GO

CREATE  VIEW SCHBU1.FSC_PARTY_DIM AS SELECT * FROM SCHCORE.FSC_PARTY_DIM
GO

CREATE  VIEW SCHBU1.FSC_PARTY_PROFILE_FACT AS SELECT * FROM SCHCORE.FSC_PARTY_PROFILE_FACT
GO

CREATE  VIEW SCHBU1.FSC_TIME_DIM AS SELECT * FROM SCHCORE.FSC_TIME_DIM
GO

CREATE  VIEW SCHBU1.FSC_TRANSACTION_DIM AS SELECT * FROM SCHCORE.FSC_TRANSACTION_DIM
GO

CREATE  VIEW SCHBU1.FSC_TRANSACTION_STATUS_DIM AS SELECT * FROM SCHCORE.FSC_TRANSACTION_STATUS_DIM
GO

CREATE  VIEW SCHBU1.FSC_TRANSACTION_TYPE_DIM AS SELECT * FROM SCHCORE.FSC_TRANSACTION_TYPE_DIM
GO

CREATE  VIEW SCHBU1.FSC_PARTY_SEQUENCE AS SELECT * FROM SCHCORE.FSC_PARTY_SEQUENCE
GO

CREATE  VIEW SCHBU1.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (account_number, current_primary_owner_number) AS SELECT a.account_number AS account_number, p.party_number AS current_primary_owner_number FROM SCHCORE.fsc_party_dim p JOIN SCHCORE.fsc_party_account_bridge b ON p.party_key = b.party_key AND b.change_current_ind = 'Y' AND b.role_key = 1 JOIN SCHCORE.fsc_account_dim a ON a.account_key = b.account_key AND b.change_current_ind = 'Y' WHERE p.change_current_ind = 'Y'
GO

CREATE  VIEW SCHBU1.fsc_transaction_view (account_key, account_number, branch_key, date_key, time_key, transaction_type_key, transaction_key, 
currency_amount, transaction_reference_number, transaction_description, security_name, deal_number, bank_name_1, role_desc_1, bank_name_2, 
role_desc_2, bank_name_3, role_desc_3, bank_name_4, role_desc_4, bank_name_5, role_desc_5, bank_name_6, role_desc_6) AS SELECT CFF.account_key, 
ACC.account_number, CFF.branch_key, CFF.date_key, CFF.time_key, CFF.transaction_type_key, CFF.transaction_key, CFF.currency_amount, TD.transaction_reference_number, 
TD.transaction_description, TD.security_name, TD.deal_number, BD.BANK_NAME AS bank_name_1, CFBB.Role_Desc AS role_desc_1, BD2.BANK_NAME AS bank_name_2,
 CFBB2.Role_Desc AS role_desc_2, BD3.BANK_NAME AS bank_name_3, CFBB3.Role_Desc AS role_desc_3, BD4.BANK_NAME AS bank_name_4, CFBB4.Role_Desc AS role_desc_4, 
BD5.BANK_NAME AS bank_name_5, CFBB5.Role_Desc AS role_desc_5, BD6.BANK_NAME AS bank_name_6, CFBB6.Role_Desc AS role_desc_6
FROM SCHCORE.FSC_CASH_FLOW_FACT CFF JOIN SCHCORE.FSC_TRANSACTION_DIM TD ON CFF.transaction_key = TD.transaction_key 
JOIN SCHCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB 
ON CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY AND CFBB.SEQUENCE_NUMBER = 1 LEFT JOIN SCHCORE.FSC_BANK_DIM BD 
ON CFBB.BANK_KEY = BD.BANK_KEY LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 ON CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY 
AND CFBB2.SEQUENCE_NUMBER = 2  LEFT JOIN SCHCORE.FSC_BANK_DIM BD2 ON CFBB2.BANK_KEY = BD2.BANK_KEY
LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 ON CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY AND CFBB3.SEQUENCE_NUMBER = 3 
LEFT JOIN SCHCORE.FSC_BANK_DIM BD3 ON CFBB3.BANK_KEY = BD3.BANK_KEY  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 
ON CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY AND CFBB4.SEQUENCE_NUMBER = 4 LEFT JOIN SCHCORE.FSC_BANK_DIM BD4 
ON CFBB4.BANK_KEY = BD4.BANK_KEY  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 ON CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY 
AND CFBB5.SEQUENCE_NUMBER = 5  LEFT JOIN SCHCORE.FSC_BANK_DIM BD5 ON CFBB5.BANK_KEY = BD5.BANK_KEY 
LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 ON CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY AND CFBB6.SEQUENCE_NUMBER = 6 
LEFT JOIN SCHCORE.FSC_BANK_DIM BD6 ON CFBB6.BANK_KEY = BD6.BANK_KEY   
UNION ALL(SELECT AEF.account_key, 
ACC.account_number, AEF.branch_key, AEF.date_key, AEF.time_key, AEF.transaction_type_key, AEF.transaction_key, 0, TD.transaction_reference_number, TD.transaction_description, 
TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM SCHCORE.FSC_ACCOUNT_EVENT_FACT AEF JOIN SCHCORE.FSC_ACCOUNT_DIM ACC 
ON AEF.account_key = ACC.account_key  JOIN SCHCORE.FSC_TRANSACTION_DIM TD ON AEF.transaction_key = TD.transaction_key 
UNION ALL
(SELECT ATF.account_key, ACC.account_number, ATF.branch_key, ATF.trade_date_key AS date_key, 
ATF.execution_time_key AS time_key, ATF.transaction_type_key, ATF.transaction_key, ATF.principal_amount AS currency_amount, TD.transaction_reference_number, 
TD.transaction_description, TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM SCHCORE.FSC_ACCOUNT_TRADE_FACT ATF 
JOIN SCHCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key  JOIN SCHCORE.FSC_TRANSACTION_DIM TD 
ON ATF.transaction_key = TD.transaction_key))
GO

CREATE VIEW SCHBU1.FSC_LOOKUP_DIM ( lookup_code,lookup_char_value,lookup_num_value,change_begin_date,change_end_date,change_current_ind,lookup_date_value,lookup_level_1_type_code,lookup_level_2_type_code,lookup_key ) 
	 AS  SELECT SCHCORE.FSC_LOOKUP_DIM.lookup_code,SCHCORE.FSC_LOOKUP_DIM.lookup_char_value,SCHCORE.FSC_LOOKUP_DIM.lookup_num_value,SCHCORE.FSC_LOOKUP_DIM.change_begin_date,SCHCORE.FSC_LOOKUP_DIM.change_end_date,SCHCORE.FSC_LOOKUP_DIM.change_current_ind,SCHCORE.FSC_LOOKUP_DIM.lookup_date_value,SCHCORE.FSC_LOOKUP_DIM.lookup_level_1_type_code,SCHCORE.FSC_LOOKUP_DIM.lookup_level_2_type_code,SCHCORE.FSC_LOOKUP_DIM.lookup_key
		FROM SCHCORE.FSC_LOOKUP_DIM
GO

CREATE VIEW SCHBU1.FSC_ADDRESS_DIM ( address_key,address_line_1_text,address_line_2_text,city_name,state_code,state_name,postal_code,country_code,country_name,match_code_address,match_code_addr_lines,match_code_city,match_code_state,match_code_country,change_begin_date,change_end_date,change_current_ind,address_type_code,primary_entity_level_code,primary_entity_number ) 
	 AS  SELECT SCHCORE.FSC_ADDRESS_DIM.address_key,SCHCORE.FSC_ADDRESS_DIM.address_line_1_text,SCHCORE.FSC_ADDRESS_DIM.address_line_2_text,SCHCORE.FSC_ADDRESS_DIM.city_name,SCHCORE.FSC_ADDRESS_DIM.state_code,SCHCORE.FSC_ADDRESS_DIM.state_name,SCHCORE.FSC_ADDRESS_DIM.postal_code,SCHCORE.FSC_ADDRESS_DIM.country_code,SCHCORE.FSC_ADDRESS_DIM.country_name,SCHCORE.FSC_ADDRESS_DIM.match_code_address,SCHCORE.FSC_ADDRESS_DIM.match_code_addr_lines,SCHCORE.FSC_ADDRESS_DIM.match_code_city,SCHCORE.FSC_ADDRESS_DIM.match_code_state,SCHCORE.FSC_ADDRESS_DIM.match_code_country,SCHCORE.FSC_ADDRESS_DIM.change_begin_date,SCHCORE.FSC_ADDRESS_DIM.change_end_date,SCHCORE.FSC_ADDRESS_DIM.change_current_ind,SCHCORE.FSC_ADDRESS_DIM.address_type_code,SCHCORE.FSC_ADDRESS_DIM.primary_entity_level_code,SCHCORE.FSC_ADDRESS_DIM.primary_entity_number
		FROM SCHCORE.FSC_ADDRESS_DIM
GO

CREATE VIEW SCHBU1.FSC_PARTY_ASSOC ( party_number,related_party_number,relationship_type_code,change_begin_date,change_end_date,change_current_ind ) 
	 AS  SELECT SCHCORE.FSC_PARTY_ASSOC.party_number,SCHCORE.FSC_PARTY_ASSOC.related_party_number,SCHCORE.FSC_PARTY_ASSOC.relationship_type_code,SCHCORE.FSC_PARTY_ASSOC.change_begin_date,SCHCORE.FSC_PARTY_ASSOC.change_end_date,SCHCORE.FSC_PARTY_ASSOC.change_current_ind
		FROM SCHCORE.FSC_PARTY_ASSOC
GO

CREATE VIEW SCHBU1.FSC_PARTY_ASSOC_ATTRIBUTE ( party_number,related_party_number,relationship_type_code,attribute_type_code,attribute_char_value,attribute_num_value,change_begin_date,change_end_date,change_current_ind,attribute_date_value ) 
	 AS  SELECT SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.party_number,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.related_party_number,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.relationship_type_code,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.attribute_type_code,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.attribute_char_value,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.attribute_num_value,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.change_begin_date,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.change_end_date,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.change_current_ind,SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE.attribute_date_value
		FROM SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE
GO

CREATE VIEW SCHBU1.FSC_SUMMARY_TRANS_TYPE_BRIDGE ( transaction_type_key,summary_group_key,change_begin_date,change_end_date,change_current_ind ) 
	 AS  SELECT SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE.transaction_type_key,SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE.summary_group_key,SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE.change_begin_date,SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE.change_end_date,SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE.change_current_ind
		FROM SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE
GO

CREATE VIEW SCHBU1.FSC_ENTITY_PROFILE_HISTORY ( history_period_code,history_begin_date_key,history_period_count,period_sufficiency_count,avg_trans_count,avg_trans_amount,avg_max_trans_amount,max_trans_count,max_trans_amount,max_max_trans_amount,std_trans_count,std_trans_amount,std_max_trans_amount,avg_log10_trans_count,avg_log10_trans_amount,avg_log10_max_trans_amount,max_log10_trans_count,max_log10_trans_amount,max_log10_max_trans_amount,std_log10_trans_count,std_log10_trans_amount,std_log10_max_trans_amount,period_count,profile_group_id,entity_level_code,entity_number,history_end_date_key ) 
	 AS  SELECT SCHCORE.FSC_ENTITY_PROFILE_HISTORY.history_period_code,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.history_begin_date_key,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.history_period_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.period_sufficiency_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.avg_trans_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.avg_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.avg_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.max_trans_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.max_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.std_trans_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.std_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.std_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.avg_log10_trans_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.avg_log10_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.avg_log10_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.max_log10_trans_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.max_log10_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.max_log10_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.std_log10_trans_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.std_log10_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.std_log10_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.period_count,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.profile_group_id,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.entity_level_code,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.entity_number,SCHCORE.FSC_ENTITY_PROFILE_HISTORY.history_end_date_key
		FROM SCHCORE.FSC_ENTITY_PROFILE_HISTORY
GO

CREATE VIEW SCHBU1.FSC_ENTITY_PEER_GROUP ( entity_level_code,entity_number,change_begin_date,change_end_date,change_current_ind,peer_group_id ) 
	 AS  SELECT SCHCORE.FSC_ENTITY_PEER_GROUP.entity_level_code,SCHCORE.FSC_ENTITY_PEER_GROUP.entity_number,SCHCORE.FSC_ENTITY_PEER_GROUP.change_begin_date,SCHCORE.FSC_ENTITY_PEER_GROUP.change_end_date,SCHCORE.FSC_ENTITY_PEER_GROUP.change_current_ind,SCHCORE.FSC_ENTITY_PEER_GROUP.peer_group_id
		FROM SCHCORE.FSC_ENTITY_PEER_GROUP
GO

CREATE VIEW SCHBU1.FSC_PEER_GROUP ( peer_group_key,peer_group_id,peer_group_name,peer_group_desc,change_begin_date,change_end_date,change_current_ind ) 
	 AS  SELECT SCHCORE.FSC_PEER_GROUP.peer_group_key,SCHCORE.FSC_PEER_GROUP.peer_group_id,SCHCORE.FSC_PEER_GROUP.peer_group_name,SCHCORE.FSC_PEER_GROUP.peer_group_desc,SCHCORE.FSC_PEER_GROUP.change_begin_date,SCHCORE.FSC_PEER_GROUP.change_end_date,SCHCORE.FSC_PEER_GROUP.change_current_ind
		FROM SCHCORE.FSC_PEER_GROUP
GO

CREATE VIEW SCHBU1.FSC_PROFILE_GROUP ( profile_group_key,profile_group_id,profile_group_name,profile_group_desc,change_begin_date,change_end_date,change_current_ind ) 
	 AS  SELECT SCHCORE.FSC_PROFILE_GROUP.profile_group_key,SCHCORE.FSC_PROFILE_GROUP.profile_group_id,SCHCORE.FSC_PROFILE_GROUP.profile_group_name,SCHCORE.FSC_PROFILE_GROUP.profile_group_desc,SCHCORE.FSC_PROFILE_GROUP.change_begin_date,SCHCORE.FSC_PROFILE_GROUP.change_end_date,SCHCORE.FSC_PROFILE_GROUP.change_current_ind
		FROM SCHCORE.FSC_PROFILE_GROUP
GO

CREATE VIEW SCHBU1.FSC_ENTITY_PROFILE_SUMMARY_AGG ( summary_period_code,summary_begin_date_key,entity_level_code,trans_count,trans_amount,max_trans_amount,round_trans_amount,non_monetary_trans_count,log10_trans_amount,log10_max_trans_amount,log10_round_trans_count,log10_round_trans_amount,round_trans_count,log10_trans_count,entity_number,profile_group_id,summary_group_id,summary_end_date_key ) 
	 AS  SELECT SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.summary_period_code,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.summary_begin_date_key,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.entity_level_code,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.trans_count,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.trans_amount,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.round_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.non_monetary_trans_count,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.log10_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.log10_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.log10_round_trans_count,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.log10_round_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.round_trans_count,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.log10_trans_count,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.entity_number,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.profile_group_id,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.summary_group_id,SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG.summary_end_date_key
		FROM SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG
GO

CREATE VIEW SCHBU1.FSC_SUMMARY_GROUP ( summary_group_key,summary_group_id,summary_group_name,summary_group_desc,change_begin_date,change_end_date,change_current_ind ) 
	 AS  SELECT SCHCORE.FSC_SUMMARY_GROUP.summary_group_key,SCHCORE.FSC_SUMMARY_GROUP.summary_group_id,SCHCORE.FSC_SUMMARY_GROUP.summary_group_name,SCHCORE.FSC_SUMMARY_GROUP.summary_group_desc,SCHCORE.FSC_SUMMARY_GROUP.change_begin_date,SCHCORE.FSC_SUMMARY_GROUP.change_end_date,SCHCORE.FSC_SUMMARY_GROUP.change_current_ind
		FROM SCHCORE.FSC_SUMMARY_GROUP
GO

CREATE VIEW SCHBU1.FSC_PEER_GROUP_PROFILE_HISTORY ( history_period_code,history_begin_date_key,history_period_count,entity_sufficiency_count,avg_trans_count,avg_trans_amount,avg_max_trans_amount,max_trans_count,max_trans_amount,max_max_trans_amount,std_trans_count,std_trans_amount,std_max_trans_amount,avg_log10_trans_count,avg_log10_trans_amount,avg_log10_max_trans_amount,max_log10_trans_count,max_log10_trans_amount,max_log10_max_trans_amount,std_log10_trans_count,std_log10_trans_amount,std_log10_max_trans_amount,entity_count,peer_group_id,profile_group_id,history_end_date_key ) 
	 AS  SELECT SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.history_period_code,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.history_begin_date_key,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.history_period_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.entity_sufficiency_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.avg_trans_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.avg_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.avg_max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.max_trans_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.max_max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.std_trans_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.std_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.std_max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.avg_log10_trans_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.avg_log10_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.avg_log10_max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.max_log10_trans_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.max_log10_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.max_log10_max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.std_log10_trans_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.std_log10_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.std_log10_max_trans_amount,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.entity_count,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.peer_group_id,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.profile_group_id,SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY.history_end_date_key
		FROM SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY
GO

CREATE VIEW SCHBU1.FSC_PROFILE_SUMMARY_BRIDGE ( profile_group_key,summary_group_key,change_begin_date,change_end_date,change_current_ind ) 
	 AS  SELECT SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE.profile_group_key,SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE.summary_group_key,SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE.change_begin_date,SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE.change_end_date,SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE.change_current_ind
		FROM SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE
GO

CREATE VIEW SCHBU1.FSC_ENTITY_PROFILE_AGG ( summary_period_code,summary_begin_date_key,entity_level_code,trans_count,trans_amount,max_trans_amount,round_trans_amount,non_monetary_trans_count,log10_trans_amount,log10_max_trans_amount,log10_round_trans_count,log10_round_trans_amount,round_trans_count,log10_trans_count,entity_number,profile_group_id,summary_end_date_key ) 
	 AS  SELECT SCHCORE.FSC_ENTITY_PROFILE_AGG.summary_period_code,SCHCORE.FSC_ENTITY_PROFILE_AGG.summary_begin_date_key,SCHCORE.FSC_ENTITY_PROFILE_AGG.entity_level_code,SCHCORE.FSC_ENTITY_PROFILE_AGG.trans_count,SCHCORE.FSC_ENTITY_PROFILE_AGG.trans_amount,SCHCORE.FSC_ENTITY_PROFILE_AGG.max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_AGG.round_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_AGG.non_monetary_trans_count,SCHCORE.FSC_ENTITY_PROFILE_AGG.log10_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_AGG.log10_max_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_AGG.log10_round_trans_count,SCHCORE.FSC_ENTITY_PROFILE_AGG.log10_round_trans_amount,SCHCORE.FSC_ENTITY_PROFILE_AGG.round_trans_count,SCHCORE.FSC_ENTITY_PROFILE_AGG.log10_trans_count,SCHCORE.FSC_ENTITY_PROFILE_AGG.entity_number,SCHCORE.FSC_ENTITY_PROFILE_AGG.profile_group_id,SCHCORE.FSC_ENTITY_PROFILE_AGG.summary_end_date_key
		FROM SCHCORE.FSC_ENTITY_PROFILE_AGG
GO

CREATE  VIEW SCHBU1.FSC_TRANSPORT_WATCH_LIST_DIM AS SELECT * FROM SCHCORE.FSC_TRANSPORT_WATCH_LIST_DIM
GO

--------- Cut and paste SCHBU1 views on SCHKC tables starting here ---------

CREATE  VIEW SCHBU1.FSK_ACCOUNT_EVENT_ALERT AS SELECT * FROM SCHKC.FSK_ACCOUNT_EVENT_ALERT
GO

CREATE  VIEW SCHBU1.FSK_ACCOUNT_PROFILE_ALERT AS SELECT * FROM SCHKC.FSK_ACCOUNT_PROFILE_ALERT
GO

CREATE  VIEW SCHBU1.FSK_ACCOUNT_TRADE_ALERT AS SELECT * FROM SCHKC.FSK_ACCOUNT_TRADE_ALERT
GO

CREATE  VIEW SCHBU1.FSK_ALERT AS SELECT * FROM SCHKC.FSK_ALERT
GO

CREATE  VIEW SCHBU1.FSK_ALERT_EMAIL AS SELECT * FROM SCHKC.FSK_ALERT_EMAIL
GO

CREATE  VIEW SCHBU1.FSK_ALERT_EVENT AS SELECT * FROM SCHKC.FSK_ALERT_EVENT
GO

CREATE  VIEW SCHBU1.FSK_ALERT_REMINDER AS SELECT * FROM SCHKC.FSK_ALERT_REMINDER
GO

CREATE  VIEW SCHBU1.FSK_ALERT_RISK_FACTOR AS SELECT * FROM SCHKC.FSK_ALERT_RISK_FACTOR
GO

CREATE  VIEW SCHBU1.FSK_CASH_FLOW_ALERT AS SELECT * FROM SCHKC.FSK_CASH_FLOW_ALERT
GO

CREATE  VIEW SCHBU1.FSK_CASH_FLOW_BANK_ALERT AS SELECT * FROM SCHKC.FSK_CASH_FLOW_BANK_ALERT
GO

CREATE  view SCHBU1.FSK_HEADER as select
   HEADER_ID,
   HEADER_NAME,
   HEADER_DESCRIPTION,
   ENTITY_LEVEL_CODE,
   DENORM_TABLE_NAME,
   ALERT_TABLE_NAME,
   HEADER_AUTOGEN_IND,
   HEADER_LOCATION_DESC,
   SOURCE_TYPE_DESC,
   CREATE_USER_ID,
   CREATE_DATE,
   LSTUPDATE_USER_ID,
   LSTUPDATE_DATE,
   HEADER_HOST_DESC,
   VERSION_NUMBER,
   LOGICAL_DELETE_IND
   from SCHKC.FSK_HEADER
GO

CREATE  view SCHBU1.FSK_HEADER_ELEMENT as select
   HEADER_ID,
   ELEMENT_NAME,
   ELEMENT_TYPE_CODE,
   ELEMENT_LENGTH_COUNT,
   ELEMENT_FORMAT_CODE,
   ELEMENT_LABEL_DESC,
   ELEMENT_USAGE_DESC
   from SCHKC.FSK_HEADER_ELEMENT
GO

CREATE  VIEW SCHBU1.FSK_JOB_CALENDAR AS SELECT * FROM SCHKC.FSK_JOB_CALENDAR
GO

CREATE  VIEW SCHBU1.FSK_LIST AS SELECT * FROM SCHKC.FSK_LIST
GO

CREATE  VIEW SCHBU1.FSK_LIST_CATEGORY AS SELECT * FROM SCHKC.FSK_LIST_CATEGORY
GO

CREATE  VIEW SCHBU1.FSK_LIST_ELEMENT AS SELECT * FROM SCHKC.FSK_LIST_ELEMENT
GO

CREATE  VIEW SCHBU1.FSK_LOV AS SELECT * FROM SCHKC.FSK_LOV
GO

CREATE  VIEW SCHBU1.FSK_PARTY_PROFILE_ALERT AS SELECT * FROM SCHKC.FSK_PARTY_PROFILE_ALERT
GO

CREATE  VIEW SCHBU1.FSK_RISK_ASSESSMENT AS SELECT * FROM SCHKC.FSK_RISK_ASSESSMENT
GO

CREATE  VIEW SCHBU1.FSK_RISK_ASSESSMENT_CLASSIFIER AS SELECT * FROM SCHKC.FSK_RISK_ASSESSMENT_CLASSIFIER
GO

CREATE  VIEW SCHBU1.FSK_RISK_ASSESSMENT_EMAIL AS SELECT * FROM SCHKC.FSK_RISK_ASSESSMENT_EMAIL
GO

CREATE  VIEW SCHBU1.FSK_RISK_ASSESSMENT_EVENT AS SELECT * FROM SCHKC.FSK_RISK_ASSESSMENT_EVENT
GO

CREATE  VIEW SCHBU1.FSK_RISK_CLASSIFIER AS SELECT * FROM SCHKC.FSK_RISK_CLASSIFIER
GO

CREATE  VIEW SCHBU1.FSK_RISK_CLASSIFIER_CATEGORY AS SELECT * FROM SCHKC.FSK_RISK_CLASSIFIER_CATEGORY
GO

create  view SCHBU1.FSK_ROUTING_CONSTRAINT as select 
    routing_group_id,
    routing_rule_id,
    constraint_order_number,
    column_name,
    operator_desc,
    value_desc,
    compound_operator_name 
from SCHKC.FSK_ROUTING_CONSTRAINT
GO

create  view SCHBU1.FSK_ROUTING_GROUP as select 
    routing_group_id,
    routing_group_name,
    version_number,
    logical_delete_ind,
    lstupdate_user_id,
    lstupdate_date 
from SCHKC.FSK_ROUTING_GROUP
GO

create  view SCHBU1.FSK_ROUTING_RULE as select 
    routing_group_id,
    routing_rule_id,
    route_order_number,
    alert_type_cd,
    alert_category_cd,
    alert_subcategory_cd,
    routing_user_long_id
from SCHKC.FSK_ROUTING_RULE
GO

CREATE  VIEW SCHBU1.FSK_SCENARIO_MESSAGE AS SELECT * FROM SCHKC.FSK_SCENARIO_MESSAGE
GO

CREATE  view SCHBU1.FSK_SCENARIO_PARAMETER as select
   SCENARIO_ID ,
   PARM_NAME ,
   PARM_VALUE ,
   PARM_TYPE_DESC,
   PARM_DESC
   from SCHKC.FSK_SCENARIO_PARAMETER
GO

CREATE  VIEW SCHBU1.FSK_TRANSACTION_ALERT AS SELECT * FROM SCHKC.FSK_TRANSACTION_ALERT
GO

CREATE  VIEW SCHBU1.FSK_UI_AVAILABILITY AS SELECT * FROM SCHKC.FSK_UI_AVAILABILITY
GO

CREATE  VIEW SCHBU1.FSK_UI_COLUMN AS SELECT * FROM SCHKC.FSK_UI_COLUMN
GO

CREATE  VIEW SCHBU1.FSK_UI_GROUP AS SELECT * FROM SCHKC.FSK_UI_GROUP
GO

CREATE  VIEW SCHBU1.FSK_UI_TABLE AS SELECT * FROM SCHKC.FSK_UI_TABLE
GO

CREATE  VIEW SCHBU1.FSK_ASSESSMENT_ROUTING_RULE AS SELECT * FROM SCHKC.FSK_ASSESSMENT_ROUTING_RULE
GO

CREATE  VIEW SCHBU1.FSK_SCD2_COLUMNS AS SELECT * FROM SCHKC.FSK_SCD2_COLUMNS
GO

CREATE  VIEW SCHBU1.fsk_account_list_view (
   list_id,
   value )
AS
SELECT element.list_id,element.list_element_value
FROM SCHKC.FSK_LIST list
JOIN SCHKC.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'ACC'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
GO

CREATE  VIEW SCHBU1.fsk_party_list_view (
   list_id,
   value )
AS
SELECT element.list_id,element.list_element_value
FROM SCHKC.FSK_LIST list
JOIN SCHKC.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'PTY'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
GO

CREATE   VIEW SCHBU1.FSK_SCENARIO_FILTER ( scenario_id,filter_id,filter_name,save_trig_trans_ind,days_number,filter_order_number ) 
	 AS  SELECT SCHKC.FSK_SCENARIO_FILTER.scenario_id,SCHKC.FSK_SCENARIO_FILTER.filter_id,SCHKC.FSK_SCENARIO_FILTER.filter_name,SCHKC.FSK_SCENARIO_FILTER.save_trig_trans_ind,SCHKC.FSK_SCENARIO_FILTER.days_number,SCHKC.FSK_SCENARIO_FILTER.filter_order_number
		FROM SCHKC.FSK_SCENARIO_FILTER
GO

CREATE   VIEW SCHBU1.FSK_SCENARIO_FILTER_CONSTRAINT ( filter_id,left_operand,left_operand_type,constraint_operator,right_operand,right_operand_type,compound_operator,constraint_order_number ) 
	 AS  SELECT SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.filter_id,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.left_operand,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.left_operand_type,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.constraint_operator,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.right_operand,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.right_operand_type,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.compound_operator,SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT.constraint_order_number
		FROM SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT
GO

CREATE   VIEW SCHBU1.FSK_SCENARIO_FILTER_VARIABLE ( filter_id,variable_name,function_name,variable_type ) 
	 AS  SELECT SCHKC.FSK_SCENARIO_FILTER_VARIABLE.filter_id,SCHKC.FSK_SCENARIO_FILTER_VARIABLE.variable_name,SCHKC.FSK_SCENARIO_FILTER_VARIABLE.function_name,SCHKC.FSK_SCENARIO_FILTER_VARIABLE.variable_type
		FROM SCHKC.FSK_SCENARIO_FILTER_VARIABLE
GO

CREATE   VIEW SCHBU1.FSK_SCENARIO_MESSAGE_PARAMETER ( scenario_id,message_parameter,message_parameter_type,variable_format,parameter_number ) 
	 AS  SELECT SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER.scenario_id,SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER.message_parameter,SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER.message_parameter_type,SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER.variable_format,SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER.parameter_number
		FROM SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER
GO

CREATE   VIEW SCHBU1.FSK_SCENARIO_ALERT_CONSTRAINT ( scenario_id,left_operand,left_operand_type,constraint_operator,right_operand,right_operand_type,compound_operator,constraint_order_number ) 
	 AS  SELECT SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.scenario_id,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.left_operand,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.left_operand_type,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.constraint_operator,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.right_operand,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.right_operand_type,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.compound_operator,SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT.constraint_order_number
		FROM SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT
GO

CREATE   VIEW SCHBU1.FSK_SCENARIO_LOCALIZED_MSG ( scenario_id,locale,scenario_message_text ) 
	 AS  SELECT SCHKC.FSK_SCENARIO_LOCALIZED_MSG.scenario_id,SCHKC.FSK_SCENARIO_LOCALIZED_MSG.locale,SCHKC.FSK_SCENARIO_LOCALIZED_MSG.scenario_message_text
		FROM SCHKC.FSK_SCENARIO_LOCALIZED_MSG
GO

CREATE   VIEW SCHBU1.FSK_TEMP_ASSESS ( create_date,party_key ) 
	 AS  SELECT SCHKC.FSK_TEMP_ASSESS.create_date,SCHKC.FSK_TEMP_ASSESS.party_key
		FROM SCHKC.FSK_TEMP_ASSESS
GO

CREATE   VIEW SCHBU1.FSK_TEMP_NUMBER ( primary_entity_number ) 
	 AS  SELECT SCHKC.FSK_TEMP_NUMBER.primary_entity_number
		FROM SCHKC.FSK_TEMP_NUMBER
GO

CREATE   VIEW SCHBU1.FSK_TEMP_EXT_PARTY_KEYS ( alert_id,ext_party_account_key,run_date ) 
	 AS  SELECT SCHKC.FSK_TEMP_EXT_PARTY_KEYS.alert_id,SCHKC.FSK_TEMP_EXT_PARTY_KEYS.ext_party_account_key,SCHKC.FSK_TEMP_EXT_PARTY_KEYS.run_date
		FROM SCHKC.FSK_TEMP_EXT_PARTY_KEYS
GO

CREATE   VIEW SCHBU1.FSK_ACCOUNT_KEYS_PTY ( alert_id,account_key,run_date ) 
	 AS  SELECT SCHKC.FSK_ACCOUNT_KEYS_PTY.alert_id,SCHKC.FSK_ACCOUNT_KEYS_PTY.account_key,SCHKC.FSK_ACCOUNT_KEYS_PTY.run_date
		FROM SCHKC.FSK_ACCOUNT_KEYS_PTY
GO

CREATE   VIEW SCHBU1.FSK_NN_PARTY ( alert_id,party_number ) 
	 AS  SELECT SCHKC.FSK_NN_PARTY.alert_id,SCHKC.FSK_NN_PARTY.party_number
		FROM SCHKC.FSK_NN_PARTY
GO

CREATE   VIEW SCHBU1.FSK_REPLICATION_DATES ( alert_id,start_date,start_date_key ) 
	 AS  SELECT SCHKC.FSK_REPLICATION_DATES.alert_id,SCHKC.FSK_REPLICATION_DATES.start_date,SCHKC.FSK_REPLICATION_DATES.start_date_key
		FROM SCHKC.FSK_REPLICATION_DATES
GO

CREATE   VIEW SCHBU1.FSK_ACCOUNT_KEYS_HHD ( alert_id,account_key,run_date ) 
	 AS  SELECT SCHKC.FSK_ACCOUNT_KEYS_HHD.alert_id,SCHKC.FSK_ACCOUNT_KEYS_HHD.account_key,SCHKC.FSK_ACCOUNT_KEYS_HHD.run_date
		FROM SCHKC.FSK_ACCOUNT_KEYS_HHD
GO

CREATE   VIEW SCHBU1.FSK_NN_ENTITY ( primary_entity_number,primary_entity_level_code,alert_id ) 
	 AS  SELECT SCHKC.FSK_NN_ENTITY.primary_entity_number,SCHKC.FSK_NN_ENTITY.primary_entity_level_code,SCHKC.FSK_NN_ENTITY.alert_id
		FROM SCHKC.FSK_NN_ENTITY
GO

CREATE   VIEW SCHBU1.FSK_ALERT_NEIGHBOR ( alert_id,target_account_number,neighbor_account_number,distance ) 
	 AS  SELECT SCHKC.FSK_ALERT_NEIGHBOR.alert_id,SCHKC.FSK_ALERT_NEIGHBOR.target_account_number,SCHKC.FSK_ALERT_NEIGHBOR.neighbor_account_number,SCHKC.FSK_ALERT_NEIGHBOR.distance
		FROM SCHKC.FSK_ALERT_NEIGHBOR
GO

CREATE   VIEW SCHBU1.FSK_ACCOUNT_KEYS_ASC ( alert_id,account_key,run_date ) 
	 AS  SELECT SCHKC.FSK_ACCOUNT_KEYS_ASC.alert_id,SCHKC.FSK_ACCOUNT_KEYS_ASC.account_key,SCHKC.FSK_ACCOUNT_KEYS_ASC.run_date
		FROM SCHKC.FSK_ACCOUNT_KEYS_ASC
GO


CREATE VIEW SCHBU1.FSK_CDD_SCORING_EVENT AS SELECT * FROM SCHKC.FSK_CDD_SCORING_EVENT
GO

CREATE   VIEW SCHBU1.FSK_CDD_TRIGGERING_VALUES ( cdd_scoring_event_key,cdd_triggering_value_key,triggering_value_id,triggering_char_value,triggering_date_value,triggering_num_value,triggering_value_type_code,ref_table_nm ) 
	 AS  SELECT SCHKC.FSK_CDD_TRIGGERING_VALUES.cdd_scoring_event_key,SCHKC.FSK_CDD_TRIGGERING_VALUES.cdd_triggering_value_key,SCHKC.FSK_CDD_TRIGGERING_VALUES.triggering_value_id,SCHKC.FSK_CDD_TRIGGERING_VALUES.triggering_char_value,SCHKC.FSK_CDD_TRIGGERING_VALUES.triggering_date_value,SCHKC.FSK_CDD_TRIGGERING_VALUES.triggering_num_value,SCHKC.FSK_CDD_TRIGGERING_VALUES.triggering_value_type_code,SCHKC.FSK_CDD_TRIGGERING_VALUES.ref_table_nm
		FROM SCHKC.FSK_CDD_TRIGGERING_VALUES
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE AS SELECT * FROM SCHKC.FSK_CDD_RULE
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE_GROUP AS SELECT * FROM SCHKC.FSK_CDD_RULE_GROUP
GO

CREATE VIEW SCHBU1.FSK_CDD_RULE_PARAMETER AS SELECT * FROM SCHKC.FSK_CDD_RULE_PARAMETER
GO

CREATE   VIEW SCHBU1.FSK_CDD_ENTITY_FACT ( primary_entity_number,primary_entity_level_code,last_change_date,next_review_date,override_score_class_code,final_disposition_code,last_review_date,last_scoring_event_key,last_review_scoring_event_key,curr_review_scoring_event_key ) 
	 AS  SELECT SCHKC.FSK_CDD_ENTITY_FACT.primary_entity_number,SCHKC.FSK_CDD_ENTITY_FACT.primary_entity_level_code,SCHKC.FSK_CDD_ENTITY_FACT.last_change_date,SCHKC.FSK_CDD_ENTITY_FACT.next_review_date,SCHKC.FSK_CDD_ENTITY_FACT.override_score_class_code,SCHKC.FSK_CDD_ENTITY_FACT.final_disposition_code,SCHKC.FSK_CDD_ENTITY_FACT.last_review_date,SCHKC.FSK_CDD_ENTITY_FACT.last_scoring_event_key,SCHKC.FSK_CDD_ENTITY_FACT.last_review_scoring_event_key,SCHKC.FSK_CDD_ENTITY_FACT.curr_review_scoring_event_key
		FROM SCHKC.FSK_CDD_ENTITY_FACT
GO

CREATE   VIEW SCHBU1.FSK_TEMP_TABLE ( temp_char_1_value,temp_char_2_value,temp_char_3_value,temp_char_4_value,temp_date_1_value,temp_date_2_value,temp_date_3_value,temp_date_4_value,temp_num_1_value,temp_num_2_value,temp_num_3_value,temp_num_4_value ) 
	 AS  SELECT SCHKC.FSK_TEMP_TABLE.temp_char_1_value,SCHKC.FSK_TEMP_TABLE.temp_char_2_value,SCHKC.FSK_TEMP_TABLE.temp_char_3_value,SCHKC.FSK_TEMP_TABLE.temp_char_4_value,SCHKC.FSK_TEMP_TABLE.temp_date_1_value,SCHKC.FSK_TEMP_TABLE.temp_date_2_value,SCHKC.FSK_TEMP_TABLE.temp_date_3_value,SCHKC.FSK_TEMP_TABLE.temp_date_4_value,SCHKC.FSK_TEMP_TABLE.temp_num_1_value,SCHKC.FSK_TEMP_TABLE.temp_num_2_value,SCHKC.FSK_TEMP_TABLE.temp_num_3_value,SCHKC.FSK_TEMP_TABLE.temp_num_4_value
		FROM SCHKC.FSK_TEMP_TABLE
GO

CREATE  VIEW SCHBU1.FSK_SCENARIO AS SELECT * from SCHKC.FSK_SCENARIO
GO

CREATE   VIEW SCHBU1.FSK_PREFERENCE AS  SELECT * FROM SCHKC.FSK_PREFERENCE
GO

CREATE  VIEW SCHBU1.FSK_ALERT_TX_AGG AS SELECT * FROM SCHKC.FSK_ALERT_TX_AGG
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_TX_AGG AS SELECT * FROM SCHKC.FSK_ENTITY_TX_AGG
GO

CREATE  VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO

CREATE  VIEW SCHBU1.FSK_ALERT_TRANSACTION AS SELECT * FROM SCHKC.FSK_ALERT_TRANSACTION
GO

CREATE  VIEW SCHBU1.FSK_RC_REPORT AS SELECT * from SCHKC.FSK_RC_REPORT
GO

CREATE  VIEW SCHBU1.FSK_RC_REPORT_ENTITY AS SELECT * from SCHKC.FSK_RC_REPORT_ENTITY
GO

CREATE   VIEW SCHBU1.FSK_RC_EFILE AS  SELECT * FROM SCHKC.FSK_RC_EFILE
GO

CREATE   VIEW SCHBU1.FSK_RC_FORM_CONFIG AS  SELECT * FROM SCHKC.FSK_RC_FORM_CONFIG
GO

CREATE   VIEW SCHBU1.FSK_RC_EFILE_REPORT AS  SELECT * FROM SCHKC.FSK_RC_EFILE_REPORT
GO

CREATE  VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE
GO

CREATE  VIEW SCHBU1.FSK_CASE_ENTITY AS SELECT * FROM SCHKC.FSK_CASE_ENTITY
GO

CREATE   VIEW SCHBU1.FSK_ACCOUNT_KEYS_ACC ( alert_id,account_key,run_date ) 
	 AS  SELECT SCHKC.FSK_ACCOUNT_KEYS_ACC.alert_id,SCHKC.FSK_ACCOUNT_KEYS_ACC.account_key,SCHKC.FSK_ACCOUNT_KEYS_ACC.run_date
		FROM SCHKC.FSK_ACCOUNT_KEYS_ACC
GO

CREATE  VIEW SCHBU1.FSK_RC_FORM_DEFAULT AS SELECT * FROM SCHKC.FSK_RC_FORM_DEFAULT
GO

CREATE  VIEW SCHBU1.FSK_COMMENT AS SELECT * FROM SCHKC.FSK_COMMENT
GO

CREATE  VIEW SCHBU1.FSK_ATTACHMENT AS SELECT * FROM SCHKC.FSK_ATTACHMENT
GO

CREATE  VIEW SCHBU1.FSK_CASE_EVENT AS SELECT * FROM SCHKC.FSK_CASE_EVENT
GO

CREATE  VIEW SCHBU1.FSK_CASE_ENTITY_EVENT AS SELECT * FROM SCHKC.FSK_CASE_ENTITY_EVENT
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_EVENT AS SELECT * FROM SCHKC.FSK_ENTITY_EVENT
GO

CREATE  VIEW SCHBU1.FSK_ALERT_CASE AS SELECT * FROM SCHKC.FSK_ALERT_CASE
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_TRANSACTION AS SELECT * FROM SCHKC.FSK_ENTITY_TRANSACTION
GO

CREATE  VIEW SCHBU1.FSK_RC_REPORT_ENTITY_EVENT AS SELECT * FROM SCHKC.FSK_RC_REPORT_ENTITY_EVENT
GO

CREATE  VIEW SCHBU1.FSK_RC_REPORT_EVENT AS SELECT * FROM SCHKC.FSK_RC_REPORT_EVENT
GO

CREATE  VIEW SCHBU1.FSK_RC_REPORT_ENTITY_INFO AS SELECT * FROM SCHKC.FSK_RC_REPORT_ENTITY_INFO
GO

CREATE  VIEW SCHBU1.FSK_RC_FORM_CODE_MAPPING AS SELECT * FROM SCHKC.FSK_RC_FORM_CODE_MAPPING
GO

CREATE  VIEW SCHBU1.FSK_SCENARIO_ALERT_COLUMN AS SELECT scenario_id, column_name, column_usage_code FROM 
SCHKC.FSK_SCENARIO_ALERT_COLUMN
GO

CREATE  VIEW SCHBU1.FSK_ENHANCED_ALERT AS SELECT * FROM SCHKC.FSK_ENHANCED_ALERT
GO

CREATE  VIEW SCHBU1.FSK_ENHANCED_ALERT_RISK_FACTOR AS SELECT * FROM 
SCHKC.FSK_ENHANCED_ALERT_RISK_FACTOR
GO

CREATE  VIEW SCHBU1.FSK_INT_XFER AS SELECT * FROM SCHKC.FSK_INT_XFER
GO

CREATE  VIEW SCHBU1.FSK_CASE_TRANSACTION AS SELECT * FROM SCHKC.FSK_CASE_TRANSACTION
GO

CREATE  VIEW SCHBU1.FSK_CASE_ENTITY_TRANSACTION AS SELECT * FROM SCHKC.FSK_CASE_ENTITY_TRANSACTION
GO