--------------------------------------------------------------
--------------------------------------------------------------
--Core TABLE, INDEX, AND TABLESPACE CREATION TEMPLATE
--------------------------------------------------------------
--This script is a template for creating the tablespaces, tables, 
--indexes, and constraints required for the 'CORE' FCF schema
--if the FCF Core tables are being stored in Oracle.
--
--This script is only a template.  It must be customized
--to the physical environment and volume of data expected. 
--
--Indexes may be added or removed as desired for performance reasons, 
--however, modifications to the ETL process might be necessary to 
--accomodate such changes, since it is often necessary to drop and
--rebuild indexes during ETL for performance reasons.
--
--This script must be run as an account with DBA privileges.
--
--This script assumes that one bank segment is being
--created (SCHBU1)
--------------------------------------------------------------
--------------------------------------------------------------
USE [LOCALDB]
GO

-- Create the FSC_ACCOUNT_STATE_VECTOR_FACT table. This is needed only in SQL Server 2012.

CREATE TABLE SCHCORE.FSC_ACCOUNT_STATE_VECTOR_FACT
(
	account_number       VARCHAR(50) NOT NULL ,
	date_key             DECIMAL(8) NOT NULL ,
	account_type_desc    VARCHAR(20) NOT NULL ,
	debits_total         DECIMAL(18,5)  ,
	credits_total        DECIMAL(18,5)  ,
	atm_debits_total     DECIMAL(18,5)  ,
	atm_credits_total    DECIMAL(18,5)  ,
	atm_d_trans_count    DECIMAL(10)  ,
	atm_c_trans_count    DECIMAL(10)  ,
	debit_trans_count    DECIMAL(10)  ,
	credit_trans_count   DECIMAL(10)  ,
	debit_loc_count      DECIMAL(10)  ,
	credit_loc_count     DECIMAL(10)  ,
	atm_d_loc_count      DECIMAL(10) NOT NULL ,
	atm_c_loc_count      DECIMAL(10)  ,
	wire_credit_total    DECIMAL(18,5)  ,
	wire_credit_trans_count DECIMAL(10)  ,
	wire_debits_total    DECIMAL(18,5)  ,
	wire_debit_trans_count DECIMAL(10)  ,
	d_i_wire_credits_total DECIMAL(18,5)  ,
	d_i_wire_credit_trans_count DECIMAL(10)  ,
	d_i_wire_debits_total DECIMAL(18,5)  ,
	d_i_wire_debit_trans_count DECIMAL(10)  ,
	balance_inquiry_count DECIMAL(10)  ,
	exceeded_daily_limit_count DECIMAL(10)  ,
	insufficient_funds_count DECIMAL(10)  ,
	CONSTRAINT XPKFSC_ACCOUNT_STATE_VECTOR_FA PRIMARY KEY CLUSTERED (account_number,date_key))
GO

--------- Paste SCHCORE Create table statements starting here. ----------


CREATE TABLE SCHCORE.FSC_ACCOUNT_ANALYSIS_DIM
(
	account_number       VARCHAR(50) NOT NULL ,
	expected_incoming_amount DECIMAL(18,5)  ,
	expected_outgoing_amount DECIMAL(18,5)  ,
	expected_incoming_count DECIMAL(10)  ,
	expected_outgoing_count DECIMAL(10)  ,
	increased_behavior_credit_amt DECIMAL(18,5)  ,
	increased_behavior_debit_amt DECIMAL(18,5)  ,
	increased_behavior_credit_cnt DECIMAL(15,5)  ,
	increased_behavior_debit_cnt DECIMAL(15,5)  ,
	expected_credit_ceiling_amount DECIMAL(18,5)  ,
	expected_debit_ceiling_amount DECIMAL(18,5)  ,
	last_activity_date   DATETIME  ,
	CONSTRAINT XPKFSC_ACCOUNT_ANALYSIS_DIM PRIMARY KEY CLUSTERED (account_number))
GO

CREATE TABLE SCHCORE.FSC_ACCOUNT_DIM
(
	account_key          DECIMAL(12) NOT NULL ,
	account_number       VARCHAR(50) NOT NULL ,
	line_of_business_name VARCHAR(35)  ,
	account_type_desc    VARCHAR(20) NOT NULL ,
	account_currency_code CHAR(3) NOT NULL ,
	account_currency_name VARCHAR(100) NOT NULL ,
	account_registration_type_desc VARCHAR(20)  ,
	account_registration_name VARCHAR(255)  ,
	account_name         VARCHAR(35)  ,
	alternate_name       VARCHAR(35)  ,
	account_open_date    DATETIME  ,
	account_close_date   DATETIME  ,
	account_status_desc  VARCHAR(35)  ,
	dormant_ind          CHAR(1)  ,
	product_line_name    VARCHAR(35)  ,
	product_category_name VARCHAR(35)  ,
	product_type_name    VARCHAR(35)  ,
	product_name         VARCHAR(35)  ,
	product_number       VARCHAR(25)  ,
	account_tax_id       VARCHAR(35)  ,
	account_tax_id_type_code CHAR(1)  ,
	account_tax_state_code CHAR(3)  ,
	account_primary_branch_name VARCHAR(25)  ,
	mailing_address_1    VARCHAR(35)  ,
	mailing_address_2    VARCHAR(35)  ,
	mailing_city_name    VARCHAR(35)  ,
	mailing_state_code   CHAR(3)  ,
	mailing_state_name   VARCHAR(35)  ,
	mailing_postal_code  CHAR(10)  ,
	mailing_country_code CHAR(3)  ,
	mailing_country_name VARCHAR(100)  ,
	currency_based_account_ind CHAR(1)  ,
	maturity_date        DATETIME  ,
	original_loan_amount DECIMAL(15,5)  ,
	collateral_type_code CHARACTER(10)  ,
	collateral_type_desc VARCHAR(35)  ,
	insured_amount       DECIMAL(15,5)  ,
	employee_ind         CHAR(1)  ,
	letter_of_credit_onfile_ind CHAR(1)  ,
	cash_intensive_business_ind CHAR(1)  ,
	trade_finance_ind    CHAR(1)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_ACCOUNT_DIM PRIMARY KEY CLUSTERED (account_key))
GO

CREATE INDEX XIE1FSC_ACCOUNT_DIM ON SCHCORE.FSC_ACCOUNT_DIM
(
	account_number ASC
)
GO

CREATE INDEX XIE2FSC_ACCOUNT_DIM ON SCHCORE.FSC_ACCOUNT_DIM
(
	account_name ASC
)
GO

CREATE INDEX XIE3FSC_ACCOUNT_DIM ON SCHCORE.FSC_ACCOUNT_DIM
(
	account_tax_id ASC
)
GO

CREATE TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
(
	transaction_key      DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	branch_key           DECIMAL(12) NOT NULL ,
	transaction_type_key DECIMAL(12) NOT NULL ,
	transaction_status_key DECIMAL(5) NOT NULL ,
	trade_date_key       DECIMAL(8,0) NOT NULL ,
	execution_time_key   DECIMAL(6) NOT NULL ,
	posted_date_key      DECIMAL(8) NOT NULL ,
	settlement_date_key  DECIMAL(8,0) NOT NULL ,
	quantity_executed    DECIMAL(15,5)  ,
	execution_price      DECIMAL(10,5)  ,
	transaction_currency_key DECIMAL(5) NOT NULL ,
	principal_amount_in_txn_ccy DECIMAL(15,5)  ,
	principal_amount     DECIMAL(15,5)  ,
	principal_amount_in_acct_ccy DECIMAL(15,5) NOT NULL ,
	associate_key        DECIMAL(12)  ,
	CONSTRAINT XPKFSC_ACCOUNT_TRADE_FACT PRIMARY KEY CLUSTERED (transaction_key))
GO

CREATE INDEX XIF1FSC_ACCOUNT_TRADE_FACT ON SCHCORE.FSC_ACCOUNT_TRADE_FACT
(
	account_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_TRANSACTION_STATUS_DIM
(
	transaction_status_key DECIMAL(5) NOT NULL ,
	status_desc          VARCHAR(20)  ,
	status_reason_desc   VARCHAR(35)  ,
	CONSTRAINT XPKFSC_TRANSACTION_STATUS_DIM PRIMARY KEY CLUSTERED (transaction_status_key))
GO

CREATE INDEX XIE1FSC_TRANSACTION_STATUS_DIM ON SCHCORE.FSC_TRANSACTION_STATUS_DIM
(
	status_desc ASC
)
GO

CREATE INDEX XIE2FSC_TRANSACTION_STATUS_DIM ON SCHCORE.FSC_TRANSACTION_STATUS_DIM
(
	status_reason_desc ASC
)
GO

CREATE TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
(
	transaction_key      DECIMAL(12) NOT NULL ,
	branch_key           DECIMAL(12) NOT NULL ,
	time_key             DECIMAL(6) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	country_key          DECIMAL(5) NOT NULL ,
	transaction_type_key DECIMAL(12) NOT NULL ,
	transaction_status_key DECIMAL(5) NOT NULL ,
	CONSTRAINT XPKFSC_ACCOUNT_EVENT_FACT PRIMARY KEY CLUSTERED (transaction_key))
GO

CREATE INDEX XIF1FSC_ACCOUNT_EVENT_FACT ON SCHCORE.FSC_ACCOUNT_EVENT_FACT
(
	account_key ASC
)
GO

CREATE INDEX XIF10FSC_ACCOUNT_EVENT_FACT ON SCHCORE.FSC_ACCOUNT_EVENT_FACT
(
	transaction_status_key ASC
)
GO

CREATE INDEX XIF2FSC_ACCOUNT_EVENT_FACT ON SCHCORE.FSC_ACCOUNT_EVENT_FACT
(
	date_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_MONTH_DIM
(
	month_key            DECIMAL(6,0) NOT NULL ,
	month_and_year       CHAR(6)  ,
	month_name           VARCHAR(9)  ,
	month_name_3c        CHAR(3)  ,
	quarter_name_2c      CHAR(2)  ,
	quarter_name_4c      CHAR(4)  ,
	year_2c              CHAR(2)  ,
	year_4c              CHAR(4)  ,
	current_month_ind    CHAR(1)  ,
	CONSTRAINT XPKFSC_MONTH_DIM PRIMARY KEY CLUSTERED (month_key))
GO

CREATE UNIQUE  INDEX XAK1MONTH_DIM ON SCHCORE.FSC_MONTH_DIM
(
	month_and_year ASC
)
GO

CREATE INDEX XIE1FSC_MONTH_DIM ON SCHCORE.FSC_MONTH_DIM
(
	current_month_ind ASC
)
GO

CREATE TABLE SCHCORE.FSC_ACCOUNT_PROFILE_FACT
(
	account_number       VARCHAR(50) NOT NULL ,
	month_key            DECIMAL(6,0) NOT NULL ,
	transactions_count   DECIMAL(10,0)  ,
	deposits_count       DECIMAL(10,0)  ,
	withdrawals_count    DECIMAL(10,0)  ,
	wires_count          DECIMAL(10,0)  ,
	cash_transactions_count DECIMAL(10,0)  ,
	account_value_amount DECIMAL(18,5)  ,
	total_transactions_amount DECIMAL(18,5)  ,
	total_credits_amount DECIMAL(18,5)  ,
	total_debits_amount  DECIMAL(18,5)  ,
	total_cash_debits_amount DECIMAL(18,5)  ,
	total_cash_credits_amount DECIMAL(18,5)  ,
	total_wire_credits_amount DECIMAL(18,5)  ,
	total_wire_debits_amount DECIMAL(18,5)  ,
	beginning_balance_amount DECIMAL(18,5)  ,
	average_daily_balance_amount DECIMAL(18,5)  ,
	ending_cash_balance_amount DECIMAL(18,5)  ,
	max_account_value_amount DECIMAL(18,5)  ,
	min_account_value_amount DECIMAL(18,5)  ,
	avg_account_value_amount DECIMAL(18,5)  ,
	cust_initiated_trans_count DECIMAL(10,0)  ,
	largest_credit_amount DECIMAL(18,5)  ,
	largest_debit_amount DECIMAL(18,5)  ,
	CONSTRAINT XPKFSC_ACCOUNT_PROFILE_FACT PRIMARY KEY CLUSTERED (account_number,month_key))
GO

CREATE INDEX XIF6FSC_ACCOUNT_PROFILE_FACT ON SCHCORE.FSC_ACCOUNT_PROFILE_FACT
(
	month_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_PARTY_DIM
(
	party_key            DECIMAL(12) NOT NULL ,
	party_number         VARCHAR(50) NOT NULL ,
	party_type_desc      VARCHAR(20) NOT NULL ,
	party_tax_id         VARCHAR(35)  ,
	party_tax_id_type_code CHAR(1)  ,
	party_identification_id VARCHAR(35)  ,
	party_identification_type_desc CHAR(4)  ,
	party_id_state_code  CHAR(3)  ,
	party_id_country_code CHAR(3)  ,
	party_date_of_birth  DATETIME  ,
	party_first_name     VARCHAR(50)  ,
	party_last_name      VARCHAR(50)  ,
	party_middle_name    VARCHAR(100)  ,
	party_name           VARCHAR(200)  ,
	doing_business_as_name VARCHAR(35)  ,
	party_status_desc    VARCHAR(20)  ,
	ultimate_parent_name VARCHAR(35)  ,
	match_code_organization VARCHAR(100)  ,
	match_code_individual VARCHAR(80)  ,
	match_code_street_address VARCHAR(140)  ,
	match_code_mailing_address VARCHAR(140)  ,
	match_code_street_addr_lines VARCHAR(80)  ,
	match_code_street_city VARCHAR(30)  ,
	match_code_street_state VARCHAR(15)  ,
	match_code_street_country VARCHAR(15)  ,
	match_code_mailing_addr_lines VARCHAR(80)  ,
	match_code_mailing_city VARCHAR(30)  ,
	match_code_mailing_state VARCHAR(15)  ,
	match_code_mailing_country VARCHAR(15)  ,
	street_address_1     VARCHAR(35)  ,
	street_address_2     VARCHAR(35)  ,
	street_city_name     VARCHAR(35)  ,
	street_state_code    CHAR(3)  ,
	street_state_name    VARCHAR(35)  ,
	street_postal_code   CHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	mailing_address_1    VARCHAR(35)  ,
	mailing_address_2    VARCHAR(35)  ,
	mailing_city_name    VARCHAR(35)  ,
	mailing_state_code   CHAR(3)  ,
	mailing_state_name   VARCHAR(35)  ,
	mailing_postal_code  CHAR(10)  ,
	mailing_country_code CHAR(3)  ,
	mailing_country_name VARCHAR(100)  ,
	residence_country_code CHAR(3)  ,
	residence_country_name VARCHAR(100)  ,
	citizenship_country_code CHAR(3)  ,
	citizenship_country_name VARCHAR(100)  ,
	org_country_of_business_code CHAR(3)  ,
	org_country_of_business_name VARCHAR(100)  ,
	employee_ind         CHAR(1)  ,
	employee_number      VARCHAR(20)  ,
	employer_name        VARCHAR(35)  ,
	employer_phone_number VARCHAR(25)  ,
	email_address        VARCHAR(35)  ,
	occupation_desc      VARCHAR(35)  ,
	industry_code        CHAR(10)  ,
	industry_code_rr     VARCHAR(10)  ,
	industry_desc        VARCHAR(255)  ,
	phone_number_1       VARCHAR(25)  ,
	phone_number_2       VARCHAR(25)  ,
	phone_number_3       VARCHAR(25)  ,
	annual_income_amount DECIMAL(10,0)  ,
	net_worth_amount     DECIMAL(10,0)  ,
	marital_status_desc  VARCHAR(20)  ,
	last_contact_date    DATETIME  ,
	politically_exposed_person_ind CHAR(1) DEFAULT 'N' NOT NULL ,
	non_profit_org_ind   CHAR(1)  ,
	customer_since_date  DATETIME  ,
	last_susp_actv_rpt_date DATETIME  ,
	last_cash_trans_rpt_date DATETIME  ,
	last_risk_assessment_date DATETIME  ,
	risk_classification  DECIMAL(1)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	external_party_ind   CHAR(1)  ,
	legal_entity_type    VARCHAR(30)  ,
	money_orders_ind     CHAR(1)  ,
	travelers_cheques_ind CHAR(1)  ,
	prepaid_cards_ind    CHAR(1)  ,
	msb_ind              CHAR(1)  ,
	money_transmitter_ind CHAR(1)  ,
	currency_exchange_ind CHAR(1)  ,
	check_casher_ind     CHAR(1)  ,
	internet_gambling_ind CHAR(1)  ,
	trust_account_ind    CHAR(1)  ,
	foreign_consulate_embassy_ind CHAR(1)  ,
	issues_bearer_shares_ind CHAR(1)  ,
	negative_news_ind    CHAR(1)  ,
	susp_actv_rpt_count  DECIMAL(4)  ,
	lst_update_date      DATETIME  ,
	CONSTRAINT XPKFSC_PARTY_DIM PRIMARY KEY CLUSTERED (party_key))
GO

CREATE INDEX XIE12FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	party_name ASC
)
GO

CREATE INDEX XIE13FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	party_number ASC
)
GO

CREATE INDEX XIE14FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	party_tax_id ASC
)
GO

CREATE INDEX XIE15FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	match_code_mailing_address ASC
)
GO

CREATE INDEX XIE16FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	match_code_street_address ASC
)
GO

CREATE INDEX XIE17FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	phone_number_1 ASC
)
GO

CREATE INDEX XIE18FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	phone_number_2 ASC
)
GO

CREATE INDEX XIE19FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	phone_number_3 ASC
)
GO

CREATE INDEX XIE20FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	employer_name ASC
)
GO

CREATE INDEX XIE21FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	match_code_individual ASC
)
GO

CREATE INDEX XIE22FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	match_code_organization ASC
)
GO

CREATE INDEX XIE23FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	employer_phone_number ASC
)
GO

CREATE INDEX XIE7FSC_PARTY_DIM ON SCHCORE.FSC_PARTY_DIM
(
	party_last_name ASC
)
GO

CREATE TABLE SCHCORE.FSC_ADDRESS_DIM
(
	address_key          DECIMAL(12) NOT NULL ,
	primary_entity_number VARCHAR(50)  ,
	primary_entity_level_code CHAR(3)  ,
	address_type_code    VARCHAR(20)  ,
	address_line_1_text  VARCHAR(35)  ,
	address_line_2_text  VARCHAR(35)  ,
	city_name            VARCHAR(35)  ,
	state_code           CHAR(3)  ,
	state_name           VARCHAR(35)  ,
	postal_code          CHAR(10)  ,
	country_code         CHAR(3)  ,
	country_name         VARCHAR(100)  ,
	match_code_address   VARCHAR(140)  ,
	match_code_addr_lines VARCHAR(80)  ,
	match_code_city      VARCHAR(30)  ,
	match_code_state     VARCHAR(15)  ,
	match_code_country   VARCHAR(15)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_ADDRESS_DIM PRIMARY KEY CLUSTERED (address_key))
GO

CREATE INDEX XIF1FSC_ADDRESS_DIM ON SCHCORE.FSC_ADDRESS_DIM
(
	primary_entity_number ASC
)
GO

CREATE TABLE SCHCORE.FSC_DATE_DIM
(
	date_key             DECIMAL(8,0) NOT NULL ,
	calendar_date        DATETIME  ,
	calendar_date_sas    DECIMAL(8,0)  ,
	calendar_date_dmy    CHAR(9)  ,
	day_name             VARCHAR(9)  ,
	day_name_short       CHAR(3)  ,
	day_number_in_month  DECIMAL(2,0)  ,
	day_number_in_year   DECIMAL(3,0)  ,
	week_number_in_month DECIMAL(1,0)  ,
	week_number_in_year  DECIMAL(2,0)  ,
	month_number_in_year DECIMAL(2,0)  ,
	month_key            DECIMAL(6,0)  ,
	month_and_year       CHAR(6)  ,
	month_name           VARCHAR(9)  ,
	month_name_short     CHAR(3)  ,
	quarter_name         CHAR(4)  ,
	quarter_and_year     CHAR(6)  ,
	month_name_3c        CHAR(3)  ,
	quarter_name_2c      CHAR(2)  ,
	quarter_name_4c      CHAR(4)  ,
	year_2c              CHAR(2)  ,
	year_4c              CHAR(4)  ,
	holiday_ind          CHAR(1)  ,
	holiday_name         CHAR(9)  ,
	week_day_ind         CHAR(1)  ,
	end_of_month_ind     CHAR(1)  ,
	economic_release_desc VARCHAR(20)  ,
	economic_event_desc  VARCHAR(20)  ,
	CONSTRAINT PKX01_DATE_KEY PRIMARY KEY CLUSTERED (date_key))
GO

CREATE UNIQUE  INDEX AKX02_CALENDAR_DATE ON SCHCORE.FSC_DATE_DIM
(
	calendar_date_dmy ASC
)
GO

CREATE UNIQUE  INDEX AKX01_CALENDAR_DATE ON SCHCORE.FSC_DATE_DIM
(
	calendar_date ASC
)
GO

CREATE UNIQUE  INDEX AKX03_CALENDAR_DATE ON SCHCORE.FSC_DATE_DIM
(
	calendar_date_sas ASC
)
GO

CREATE TABLE SCHCORE.FSC_TIME_DIM
(
	time_key             DECIMAL(6) NOT NULL ,
	time_hhmmss          CHAR(6)  ,
	time_hh              CHAR(2)  ,
	time_mm              CHAR(2)  ,
	time_ss              CHAR(2)  ,
	time_am_pm           CHAR(2)  ,
	CONSTRAINT XPKFSC_TIME_DIM PRIMARY KEY CLUSTERED (time_key))
GO

CREATE INDEX XIE1FSC_TIME_DIM ON SCHCORE.FSC_TIME_DIM
(
	time_hhmmss ASC
)
GO

CREATE TABLE SCHCORE.FSC_BRANCH_DIM
(
	branch_key           DECIMAL(12) NOT NULL ,
	branch_type_desc     VARCHAR(10)  ,
	branch_number        VARCHAR(40)  ,
	branch_name          VARCHAR(100)  ,
	street_address_1     VARCHAR(35)  ,
	street_address_2     VARCHAR(35)  ,
	street_city_name     VARCHAR(35)  ,
	street_state_code    CHAR(3)  ,
	street_state_name    VARCHAR(35)  ,
	street_postal_code   CHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_BRANCH_DIM PRIMARY KEY CLUSTERED (branch_key))
GO

CREATE INDEX XIE2FSC_BRANCH_DIM ON SCHCORE.FSC_BRANCH_DIM
(
	branch_name ASC
)
GO

CREATE INDEX XIE3FSC_BRANCH_DIM ON SCHCORE.FSC_BRANCH_DIM
(
	branch_number ASC
)
GO

CREATE TABLE SCHCORE.FSC_TRANSACTION_TYPE_DIM
(
	transaction_type_key DECIMAL(12) NOT NULL ,
	funds_securities_code CHAR(1)  ,
	funds_securities_desc VARCHAR(20)  ,
	transaction_cdi_code CHAR(1)  ,
	transaction_cdi_desc VARCHAR(20)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	tertiary_medium_desc VARCHAR(30)  ,
	mechanism_desc       VARCHAR(20)  ,
	CONSTRAINT XPKFSC_TRANSACTION_TYPE_DIM PRIMARY KEY CLUSTERED (transaction_type_key))
GO

CREATE INDEX XIE1FSC_TRANSACTION_TYPE_DIM ON SCHCORE.FSC_TRANSACTION_TYPE_DIM
(
	funds_securities_code ASC, 	funds_securities_desc ASC
)
GO

CREATE INDEX XIE2FSC_TRANSACTION_TYPE_DIM ON SCHCORE.FSC_TRANSACTION_TYPE_DIM
(
	transaction_cdi_code ASC, 	transaction_cdi_desc ASC
)
GO

CREATE INDEX XIE3FSC_TRANSACTION_TYPE_DIM ON SCHCORE.FSC_TRANSACTION_TYPE_DIM
(
	primary_medium_desc ASC, 	secondary_medium_desc ASC
)
GO

CREATE TABLE SCHCORE.FSC_CURRENCY_DIM
(
	currency_key         DECIMAL(5) NOT NULL ,
	currency_code        CHAR(3)  ,
	currency_name        VARCHAR(100)  ,
	CONSTRAINT XPKFSC_CURRENCY_DIM PRIMARY KEY CLUSTERED (currency_key))
GO

CREATE INDEX XIE1FSC_CURRENCY_DIM ON SCHCORE.FSC_CURRENCY_DIM
(
	currency_code ASC
)
GO

CREATE INDEX XIE2FSC_CURRENCY_DIM ON SCHCORE.FSC_CURRENCY_DIM
(
	currency_name ASC
)
GO

CREATE TABLE SCHCORE.FSC_ASSOCIATE_DIM
(
	associate_key        DECIMAL(12) NOT NULL ,
	associate_number     VARCHAR(20)  ,
	associate_first_name VARCHAR(50)  ,
	associate_last_name  VARCHAR(50)  ,
	associate_middle_name VARCHAR(100)  ,
	associate_title_desc VARCHAR(50)  ,
	associate_status_desc VARCHAR(35)  ,
	street_address_1     VARCHAR(35)  ,
	street_address_2     VARCHAR(35)  ,
	street_city_name     VARCHAR(35)  ,
	street_state_code    CHAR(3)  ,
	street_state_name    VARCHAR(35)  ,
	street_postal_code   CHAR(10)  ,
	street_country_name  VARCHAR(100)  ,
	street_country_code  CHAR(3)  ,
	work_phone_number    VARCHAR(25)  ,
	email_address        VARCHAR(35)  ,
	branch_number        VARCHAR(25)  ,
	branch_name          VARCHAR(35)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_ASSOCIATE_DIM PRIMARY KEY CLUSTERED (associate_key))
GO

CREATE INDEX XIE1FSC_ASSOCIATE_DIM ON SCHCORE.FSC_ASSOCIATE_DIM
(
	associate_number ASC
)
GO

CREATE INDEX XIE6FSC_ASSOCIATE_DIM ON SCHCORE.FSC_ASSOCIATE_DIM
(
	associate_last_name ASC
)
GO

CREATE TABLE SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	ext_party_account_key DECIMAL(12) NOT NULL ,
	external_party_number VARCHAR(100)  ,
	ext_party_type_desc  VARCHAR(20)  ,
	full_name            VARCHAR(200)  ,
	last_name            VARCHAR(50)  ,
	first_name           VARCHAR(50)  ,
	middle_name          VARCHAR(100)  ,
	birth_date           DATETIME  ,
	party_tax_id         VARCHAR(35)  ,
	party_tax_id_type_code CHAR(1)  ,
	match_code_organization VARCHAR(100)  ,
	match_code_individual VARCHAR(80)  ,
	match_code_street_address VARCHAR(140)  ,
	match_code_street_addr_lines VARCHAR(80)  ,
	match_code_street_city VARCHAR(30)  ,
	match_code_street_state VARCHAR(15)  ,
	match_code_street_country VARCHAR(15)  ,
	street_address_1     VARCHAR(35)  ,
	street_address_2     VARCHAR(35)  ,
	street_city_name     VARCHAR(35)  ,
	street_state_code    CHAR(3)  ,
	street_state_name    VARCHAR(35)  ,
	street_postal_code   CHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	account_number       VARCHAR(50)  ,
	bank_key             DECIMAL(12)  ,
	branch_number        VARCHAR(25)  ,
	branch_name          VARCHAR(35)  ,
	citizenship_country_code CHAR(3)  ,
	citizenship_country_name VARCHAR(100)  ,
	residence_country_code CHAR(3)  ,
	residence_country_name VARCHAR(100)  ,
	phone_number_1       VARCHAR(25)  ,
	phone_number_2       VARCHAR(25)  ,
	identification_id    VARCHAR(35)  ,
	identification_type_desc CHAR(4)  ,
	identification_state_code CHAR(3)  ,
	identification_country_code CHAR(3)  ,
	identification_country_name VARCHAR(100)  ,
	create_dttm          DATETIME NOT NULL ,
	CONSTRAINT XPKFSC_EXT_PARTY_ACCOUNT_DIM PRIMARY KEY CLUSTERED (ext_party_account_key))
GO

CREATE INDEX XIE1FSC_EXT_PARTY_ACCOUNT_DIM ON SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	external_party_number ASC
)
GO

CREATE INDEX XIE2FSC_EXT_PARTY_ACCOUNT_DIM ON SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	last_name ASC
)
GO

CREATE INDEX XIE4FSC_EXT_PARTY_ACCOUNT_DIM ON SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	account_number ASC
)
GO

CREATE INDEX XIE5FSC_EXT_PARTY_ACCOUNT_DIM ON SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	full_name ASC
)
GO

CREATE TABLE SCHCORE.FSC_CASH_FLOW_FACT
(
	transaction_key      DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	country_key          DECIMAL(5) NOT NULL ,
	transaction_type_key DECIMAL(12) NOT NULL ,
	time_key             DECIMAL(6) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	transaction_status_key DECIMAL(5) NOT NULL ,
	transaction_currency_key DECIMAL(5) NOT NULL ,
	branch_key           DECIMAL(12) NOT NULL ,
	remitter_ext_party_key DECIMAL(12) NOT NULL ,
	beneficiary_ext_party_key DECIMAL(12) NOT NULL ,
	posted_date_key      DECIMAL(8)  ,
	associate_key        DECIMAL(12) NOT NULL ,
	executing_party_key  DECIMAL(12) NOT NULL ,
	executing_ext_party_key DECIMAL(12)  ,
	currency_amount      DECIMAL(18,5) NOT NULL ,
	currency_amount_in_txn_ccy DECIMAL(18,5) NOT NULL ,
	currency_amount_in_account_ccy DECIMAL(18,5) NOT NULL ,
	secondary_account_key DECIMAL(12) NOT NULL ,
	related_ind          CHAR(1) DEFAULT 'U' NOT NULL ,
	third_party_ind      CHAR(1)  ,
	CONSTRAINT XPKFSC_CASH_FLOW_FACT PRIMARY KEY CLUSTERED (transaction_key))
GO

CREATE INDEX XIF5ACCOUNT_CREDITS_FACT ON SCHCORE.FSC_CASH_FLOW_FACT
(
	date_key ASC
)
GO

CREATE INDEX CASH_FLOW_SECONDARY_IDX ON SCHCORE.FSC_CASH_FLOW_FACT
(
	secondary_account_key ASC
)
GO

CREATE INDEX XIF1FSC_CASH_FLOW_FACT ON SCHCORE.FSC_CASH_FLOW_FACT
(
	account_key ASC
)
GO

CREATE INDEX XIF12FSC_CASH_FLOW_FACT ON SCHCORE.FSC_CASH_FLOW_FACT
(
	executing_party_key ASC
)
GO

CREATE INDEX XIF15FSC_CASH_FLOW_FACT ON SCHCORE.FSC_CASH_FLOW_FACT
(
	remitter_ext_party_key ASC
)
GO

CREATE INDEX XIF16FSC_CASH_FLOW_FACT ON SCHCORE.FSC_CASH_FLOW_FACT
(
	beneficiary_ext_party_key ASC
)
GO

CREATE INDEX XIF17FSC_CASH_FLOW_FACT ON SCHCORE.FSC_CASH_FLOW_FACT
(
	executing_ext_party_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_BANK_DIM
(
	bank_key             DECIMAL(12) NOT NULL ,
	bank_number          VARCHAR(25)  ,
	bank_chips_number    VARCHAR(25)  ,
	bank_swift_number    VARCHAR(25)  ,
	bank_name            VARCHAR(35)  ,
	bank_address_1       VARCHAR(35)  ,
	bank_address_2       VARCHAR(35)  ,
	bank_city_name       VARCHAR(35)  ,
	bank_state_code      CHAR(3)  ,
	bank_state_name      VARCHAR(35)  ,
	bank_postal_code     CHAR(10)  ,
	bank_country_code    CHAR(3)  ,
	bank_country_name    CHAR(35)  ,
	bank_phone_number    VARCHAR(25)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_BANK_DIM PRIMARY KEY CLUSTERED (bank_key))
GO

CREATE INDEX XIE1FSC_BANK_DIM ON SCHCORE.FSC_BANK_DIM
(
	bank_number ASC
)
GO

CREATE TABLE SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key             DECIMAL(12) NOT NULL ,
	transaction_key      DECIMAL(12) NOT NULL ,
	role_desc            VARCHAR(20)  ,
	sequence_number      DECIMAL(2)  ,
	CONSTRAINT XPKFSC_CASH_FLOW_BANK_BRIDGE PRIMARY KEY CLUSTERED (bank_key,transaction_key))
GO

CREATE INDEX XIF1FSC_CASH_FLOW_BANK_BRIDGE ON SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key ASC
)
GO

CREATE INDEX XIF2FSC_CASH_FLOW_BANK_BRIDGE ON SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	transaction_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_CLASSIFIER_FACT
(
	party_number         VARCHAR(50) NOT NULL ,
	month_key            DECIMAL(6,0) NOT NULL ,
	rc_pep               DECIMAL(1)  ,
	rc_foreign_financial_inst DECIMAL(1)  ,
	rc_non_bank_financial_inst DECIMAL(1)  ,
	rc_foreign_corporation DECIMAL(1)  ,
	rc_deposit_broker    DECIMAL(1)  ,
	rc_cash_intensive_business DECIMAL(1)  ,
	rc_professional_svcs_provider DECIMAL(1)  ,
	rc_private_banking   DECIMAL(1)  ,
	rc_trust_or_asset_mgmt_acct DECIMAL(1)  ,
	rc_foreign_correspondent_acct DECIMAL(1)  ,
	rc_trade_finance     DECIMAL(1)  ,
	rc_special_use_account DECIMAL(1)  ,
	rc_lending_activity  DECIMAL(1)  ,
	rc_nondeposit_account DECIMAL(1)  ,
	rc_wires_count       DECIMAL(6)  ,
	rc_funds_transfer_count DECIMAL(6)  ,
	rc_non_profit_org    DECIMAL(1)  ,
	rc_funds_payment_svcs_count DECIMAL(6)  ,
	rc_internal_pep      DECIMAL(1)  ,
	rc_high_risk_geography DECIMAL(1)  ,
	rc_monetary_instrument_count DECIMAL(6)  ,
	CONSTRAINT XPKFSC_CLASSIFIER_FACT PRIMARY KEY CLUSTERED (party_number,month_key))
GO

CREATE INDEX XIE1FSC_CLASSIFIER_FACT ON SCHCORE.FSC_CLASSIFIER_FACT
(
	rc_pep ASC
)
GO

CREATE TABLE SCHCORE.FSC_COUNTRY_DIM
(
	country_key          DECIMAL(5) NOT NULL ,
	country_code_2       CHAR(2)  ,
	country_code_3       CHAR(3)  ,
	country_name         VARCHAR(100)  ,
	CONSTRAINT XPKFSC_COUNTRY_DIM PRIMARY KEY CLUSTERED (country_key))
GO

CREATE INDEX XIE1FSC_COUNTRY_DIM ON SCHCORE.FSC_COUNTRY_DIM
(
	country_name ASC
)
GO

CREATE INDEX XIE2FSC_COUNTRY_DIM ON SCHCORE.FSC_COUNTRY_DIM
(
	country_code_2 ASC
)
GO

CREATE INDEX XIE3FSC_COUNTRY_DIM ON SCHCORE.FSC_COUNTRY_DIM
(
	country_code_3 ASC
)
GO

CREATE TABLE SCHCORE.FSC_ENTITY_PEER_GROUP
(
	entity_number        VARCHAR(50) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	peer_group_id        VARCHAR(50) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PEER_GROUP_ASSIGNMENT PRIMARY KEY CLUSTERED (entity_number,entity_level_code,peer_group_id,change_begin_date))
GO

CREATE TABLE SCHCORE.FSC_HOUSEHOLD_DIM
(
	household_key        DECIMAL(12) NOT NULL ,
	household_number     VARCHAR(50)  ,
	household_type_desc  VARCHAR(20)  ,
	street_address_1     VARCHAR(35)  ,
	street_address_2     VARCHAR(35)  ,
	street_city_name     VARCHAR(35)  ,
	street_state_code    CHAR(3)  ,
	street_state_name    VARCHAR(35)  ,
	street_postal_code   VARCHAR(10)  ,
	street_country_code  CHAR(3)  ,
	street_country_name  VARCHAR(100)  ,
	phone_number_1       VARCHAR(25)  ,
	phone_number_2       VARCHAR(25)  ,
	head_of_household_name VARCHAR(35)  ,
	employee_ind         CHAR(1)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_HOUSEHOLD_DIM PRIMARY KEY CLUSTERED (household_key))
GO

CREATE INDEX XIE1FSC_HOUSEHOLD_DIM ON SCHCORE.FSC_HOUSEHOLD_DIM
(
	household_number ASC, 	change_current_ind ASC
)
GO

CREATE INDEX XIE3FSC_HOUSEHOLD_DIM ON SCHCORE.FSC_HOUSEHOLD_DIM
(
	head_of_household_name ASC
)
GO

CREATE INDEX XIE4FSC_HOUSEHOLD_DIM ON SCHCORE.FSC_HOUSEHOLD_DIM
(
	phone_number_1 ASC
)
GO

CREATE INDEX XIE5FSC_HOUSEHOLD_DIM ON SCHCORE.FSC_HOUSEHOLD_DIM
(
	phone_number_2 ASC
)
GO

CREATE TABLE SCHCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key            DECIMAL(12) NOT NULL ,
	household_key        DECIMAL(12) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	hhd_head_flg         CHAR(1) NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_HOUSEHOLD_PARTY_BRIDGE PRIMARY KEY CLUSTERED (party_key,household_key,change_begin_date))
GO

CREATE INDEX XIF1FSC_HOUSEHOLD_PARTY_BRIDGE ON SCHCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key ASC
)
GO

CREATE INDEX XIF2FSC_HOUSEHOLD_PARTY_BRIDGE ON SCHCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	household_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_LOCATION_WATCH_LIST_DIM
(
	location_watch_list_key DECIMAL(12) NOT NULL ,
	location_watch_list_number VARCHAR(35) NOT NULL ,
	watch_list_name      CHAR(4) NOT NULL ,
	program              VARCHAR(20)  ,
	country_code         CHAR(3)  ,
	country_name         VARCHAR(255)  ,
	match_code_country_name VARCHAR(15)  ,
	create_date          DATETIME  ,
	update_date          DATETIME  ,
	exclude_ind          CHAR(1) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_LOCATION_WATCH_LIST_DIM PRIMARY KEY CLUSTERED (location_watch_list_key))
GO

CREATE TABLE SCHCORE.FSC_PARTY_PROFILE_FACT
(
	party_number         VARCHAR(50) NOT NULL ,
	month_key            DECIMAL(6,0) NOT NULL ,
	aggregate_assets_amount DECIMAL(18,5)  ,
	transactions_count   DECIMAL(10,0)  ,
	deposits_count       DECIMAL(10,0)  ,
	withdrawals_count    DECIMAL(10,0)  ,
	wires_count          DECIMAL(10,0)  ,
	cash_transactions_count DECIMAL(10,0)  ,
	account_value_amount DECIMAL(18,5)  ,
	total_transactions_amount DECIMAL(18,5)  ,
	total_credits_amount DECIMAL(18,5)  ,
	total_debits_amount  DECIMAL(18,5)  ,
	total_cash_debits_amount DECIMAL(18,5)  ,
	total_cash_credits_amount DECIMAL(18,5)  ,
	total_wire_credits_amount DECIMAL(18,5)  ,
	total_wire_debits_amount DECIMAL(18,5)  ,
	largest_credit_amount DECIMAL(18,5)  ,
	largest_debit_amount DECIMAL(18,5)  ,
	funds_payment_svcs_count DECIMAL(10,0)  ,
	funds_transfer_count DECIMAL(10)  ,
	monetary_instrument_count DECIMAL(10)  ,
	CONSTRAINT XPKFSC_PARTY_PROFILE_FACT PRIMARY KEY CLUSTERED (party_number,month_key))
GO

CREATE INDEX XIF1FSC_PARTY_PROFILE_FACT ON SCHCORE.FSC_PARTY_PROFILE_FACT
(
	month_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_PARTY_SEQUENCE
(
	next_sequence_id     DECIMAL(12) NOT NULL )
GO

CREATE TABLE SCHCORE.FSC_PEER_GROUP_PROFILE_HISTORY
(
	history_period_code  CHAR(1) NOT NULL ,
	peer_group_id        VARCHAR(50) NOT NULL ,
	profile_group_id     VARCHAR(50) NOT NULL ,
	history_begin_date_key DECIMAL(8) NOT NULL ,
	history_end_date_key DECIMAL(8) NOT NULL ,
	history_period_count DECIMAL(5)  ,
	entity_count         DECIMAL(5)  ,
	entity_sufficiency_count DECIMAL(5)  ,
	avg_trans_count      DECIMAL(10)  ,
	avg_trans_amount     DECIMAL(18,5)  ,
	avg_max_trans_amount DECIMAL(18,5)  ,
	max_trans_count      DECIMAL(10)  ,
	max_trans_amount     DECIMAL(18,5)  ,
	max_max_trans_amount DECIMAL(18,5)  ,
	std_trans_count      DECIMAL(10)  ,
	std_trans_amount     DECIMAL(18,5)  ,
	std_max_trans_amount DECIMAL(18,5)  ,
	avg_log10_trans_count DECIMAL(12,10)  ,
	avg_log10_trans_amount DECIMAL(12,10)  ,
	avg_log10_max_trans_amount DECIMAL(12,10)  ,
	max_log10_trans_count DECIMAL(12,10)  ,
	max_log10_trans_amount DECIMAL(12,10)  ,
	max_log10_max_trans_amount DECIMAL(12,10)  ,
	std_log10_trans_count DECIMAL(12,10)  ,
	std_log10_trans_amount DECIMAL(12,10)  ,
	std_log10_max_trans_amount DECIMAL(12,10)  ,
	CONSTRAINT XPKFSC_PEER_GROUP_HISTORY PRIMARY KEY CLUSTERED (history_period_code,peer_group_id,profile_group_id,history_begin_date_key))
GO

CREATE TABLE SCHCORE.FSC_PROFILE_GROUP
(
	profile_group_key    DECIMAL(12) NOT NULL ,
	profile_group_id     VARCHAR(50)  ,
	profile_group_name   VARCHAR(50)  ,
	profile_group_desc   VARCHAR(200)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PROFILE_GROUP PRIMARY KEY CLUSTERED (profile_group_key))
GO

CREATE TABLE SCHCORE.FSC_ENTITY_PROFILE_AGG
(
	entity_number        VARCHAR(50) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	summary_period_code  CHAR(1) NOT NULL ,
	profile_group_id     VARCHAR(50) NOT NULL ,
	summary_begin_date_key DECIMAL(8) NOT NULL ,
	summary_end_date_key DECIMAL(8) NOT NULL ,
	trans_count          DECIMAL(10)  ,
	trans_amount         DECIMAL(18,5)  ,
	max_trans_amount     DECIMAL(18,5)  ,
	round_trans_amount   DECIMAL(18,5)  ,
	round_trans_count    DECIMAL(10)  ,
	non_monetary_trans_count DECIMAL(10)  ,
	log10_trans_amount   DECIMAL(12,10)  ,
	log10_trans_count    DECIMAL(12,10)  ,
	log10_max_trans_amount DECIMAL(12,10)  ,
	log10_round_trans_count DECIMAL(12,10)  ,
	log10_round_trans_amount DECIMAL(12,10)  ,
	CONSTRAINT XPKFSC_ENTITY_PROFILE_AGG PRIMARY KEY CLUSTERED (entity_number,entity_level_code,summary_period_code,profile_group_id,summary_begin_date_key))
GO

CREATE TABLE SCHCORE.FSC_ENTITY_PROFILE_HISTORY
(
	history_period_code  CHAR(1) NOT NULL ,
	profile_group_id     VARCHAR(50) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	entity_number        VARCHAR(50) NOT NULL ,
	history_begin_date_key DECIMAL(8) NOT NULL ,
	history_period_count DECIMAL(5)  ,
	history_end_date_key DECIMAL(8)  ,
	period_count         DECIMAL(5)  ,
	period_sufficiency_count DECIMAL(5)  ,
	avg_trans_count      DECIMAL(10)  ,
	avg_trans_amount     DECIMAL(18,5)  ,
	avg_max_trans_amount DECIMAL(18,5)  ,
	max_trans_count      DECIMAL(10)  ,
	max_trans_amount     DECIMAL(18,5)  ,
	max_max_trans_amount DECIMAL(18,5)  ,
	std_trans_count      DECIMAL(10)  ,
	std_trans_amount     DECIMAL(18,5)  ,
	std_max_trans_amount DECIMAL(18,5)  ,
	avg_log10_trans_count DECIMAL(12,10)  ,
	avg_log10_trans_amount DECIMAL(12,10)  ,
	avg_log10_max_trans_amount DECIMAL(12,10)  ,
	max_log10_trans_count DECIMAL(12,10)  ,
	max_log10_trans_amount DECIMAL(12,10)  ,
	max_log10_max_trans_amount DECIMAL(12,10)  ,
	std_log10_trans_count DECIMAL(12,10)  ,
	std_log10_trans_amount DECIMAL(12,10)  ,
	std_log10_max_trans_amount DECIMAL(12,10)  ,
	CONSTRAINT XPKFSC_PEER_GROUP_ENTITY_HISTO PRIMARY KEY CLUSTERED (history_period_code,profile_group_id,entity_level_code,entity_number,history_begin_date_key))
GO

CREATE TABLE SCHCORE.FSC_PROFILE_SUMMARY_BRIDGE
(
	profile_group_key    DECIMAL(12) NOT NULL ,
	summary_group_key    DECIMAL(12) NOT NULL ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PROFILE_SUMMARY_BRIDGE PRIMARY KEY CLUSTERED (profile_group_key,summary_group_key))
GO

CREATE TABLE SCHCORE.FSC_SUMMARY_GROUP
(
	summary_group_key    DECIMAL(12) NOT NULL ,
	summary_group_id     VARCHAR(50)  ,
	summary_group_name   VARCHAR(50)  ,
	summary_group_desc   VARCHAR(200)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_SUMMARY_GROUP PRIMARY KEY CLUSTERED (summary_group_key))
GO

CREATE TABLE SCHCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG
(
	entity_number        VARCHAR(50) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	summary_period_code  CHAR(1) NOT NULL ,
	profile_group_id     VARCHAR(50) NOT NULL ,
	summary_group_id     VARCHAR(50) NOT NULL ,
	summary_begin_date_key DECIMAL(8) NOT NULL ,
	summary_end_date_key DECIMAL(8) NOT NULL ,
	trans_count          DECIMAL(10)  ,
	trans_amount         DECIMAL(18,5)  ,
	max_trans_amount     DECIMAL(18,5)  ,
	round_trans_amount   DECIMAL(18,5)  ,
	round_trans_count    DECIMAL(10)  ,
	non_monetary_trans_count DECIMAL(10)  ,
	log10_trans_amount   DECIMAL(12,10)  ,
	log10_trans_count    DECIMAL(12,10)  ,
	log10_max_trans_amount DECIMAL(12,10)  ,
	log10_round_trans_count DECIMAL(12,10)  ,
	log10_round_trans_amount DECIMAL(12,10)  ,
	CONSTRAINT XPKFSC_PEER_GROUP_ENTITY_SUMMA PRIMARY KEY CLUSTERED (entity_number,entity_level_code,summary_period_code,profile_group_id,summary_group_id,summary_begin_date_key))
GO

CREATE TABLE SCHCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_key DECIMAL(12) NOT NULL ,
	entity_watch_list_number VARCHAR(35) NOT NULL ,
	watch_list_name      CHAR(4) NOT NULL ,
	category_desc        VARCHAR(50)  ,
	type_desc            VARCHAR(20)  ,
	programs             VARCHAR(250)  ,
	tax_id               VARCHAR(35)  ,
	tax_id_type_code     CHAR(1)  ,
	identification_id    VARCHAR(255)  ,
	identification_type_desc VARCHAR(255)  ,
	date_of_birth        DATETIME  ,
	year_of_birth        DECIMAL(4)  ,
	place_of_birth       VARCHAR(100)  ,
	deceased_ind         CHAR(1)  ,
	first_name           VARCHAR(350)  ,
	last_name            VARCHAR(350)  ,
	middle_name          VARCHAR(255)  ,
	entity_name          VARCHAR(800)  ,
	match_code_individual VARCHAR(80)  ,
	match_code_organization VARCHAR(100)  ,
	match_code_addr_lines VARCHAR(80)  ,
	match_code_city      VARCHAR(30)  ,
	match_code_state     VARCHAR(15)  ,
	match_code_country   VARCHAR(15)  ,
	entity_title         VARCHAR(200)  ,
	occupation_desc      VARCHAR(500)  ,
	address              VARCHAR(750)  ,
	city_name            VARCHAR(255)  ,
	state_name           VARCHAR(50)  ,
	postal_code          CHAR(30)  ,
	country_code         CHAR(3)  ,
	country_name         VARCHAR(255)  ,
	full_address         VARCHAR(1200)  ,
	match_code_full_address VARCHAR(140)  ,
	citizenship_country_code CHAR(3)  ,
	citizenship_country_name VARCHAR(100)  ,
	match_code_citizenship VARCHAR(15)  ,
	nationality_country_code CHAR(3)  ,
	nationality_country_name VARCHAR(100)  ,
	match_code_nationality VARCHAR(15)  ,
	org_country_of_business_code VARCHAR(3)  ,
	org_country_of_business_name VARCHAR(100)  ,
	match_code_org_country VARCHAR(15)  ,
	politically_exposed_person_ind CHAR(1)  ,
	create_date          DATETIME  ,
	update_date          DATETIME  ,
	exclude_ind          CHAR(1) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_ENTITY_WATCH_LIST_DIM PRIMARY KEY CLUSTERED (entity_watch_list_key))
GO

CREATE INDEX XIE1FSC_ENTITY_WATCH_LIST_DIM ON SCHCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_number ASC
)
GO

CREATE INDEX XIE4FSC_ENTITY_WATCH_LIST_DIM ON SCHCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	last_name ASC
)
GO

CREATE INDEX XIE2FSC_ENTITY_WATCH_LIST_DIM ON SCHCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	watch_list_name ASC
)
GO

CREATE TABLE SCHCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key        DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_HOUSEHOLD_ACCOUNT_BRIDG PRIMARY KEY CLUSTERED (household_key,account_key,change_begin_date))
GO

CREATE INDEX XIF1FSC_HOUSEHOLD_ACCOUNT_BRID ON SCHCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key ASC
)
GO

CREATE INDEX XIF2FSC_HOUSEHOLD_ACCOUNT_BRID ON SCHCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	account_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_LOOKUP_DIM
(
	lookup_key           DECIMAL(12) NOT NULL ,
	lookup_level_1_type_code VARCHAR(3) NOT NULL ,
	lookup_level_2_type_code VARCHAR(28) NOT NULL ,
	lookup_code          VARCHAR(35) NOT NULL ,
	lookup_char_value    VARCHAR(50)  ,
	lookup_num_value     DECIMAL(18,5)  ,
	lookup_date_value    DATETIME  ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_LOOKUP_DIM PRIMARY KEY CLUSTERED (lookup_key))
GO

CREATE TABLE SCHCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key          DECIMAL(12) NOT NULL ,
	party_key            DECIMAL(12) NOT NULL ,
	role_key             DECIMAL(2) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	role_desc            VARCHAR(20)  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PARTY_ACCOUNT_BRIDGE PRIMARY KEY CLUSTERED (account_key,party_key,role_key,change_begin_date))
GO

CREATE INDEX XIF1FSC_PARTY_ACCOUNT_BRIDGE ON SCHCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	party_key ASC
)
GO

CREATE INDEX XIF2FSC_PARTY_ACCOUNT_BRIDGE ON SCHCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_PARTY_ASSOC
(
	party_number         VARCHAR(50) NOT NULL ,
	related_party_number VARCHAR(50) NOT NULL ,
	relationship_type_code VARCHAR(20) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PARTY_ASSOC PRIMARY KEY CLUSTERED (party_number,related_party_number,relationship_type_code,change_begin_date))
GO

CREATE TABLE SCHCORE.FSC_PARTY_ASSOC_ATTRIBUTE
(
	party_number         VARCHAR(50) NOT NULL ,
	related_party_number VARCHAR(50) NOT NULL ,
	relationship_type_code VARCHAR(20) NOT NULL ,
	attribute_type_code  VARCHAR(35) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	attribute_char_value VARCHAR(32)  ,
	attribute_num_value  DECIMAL(18,5)  ,
	attribute_date_value DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PARTY_ASSOC_ATTRIBUTE PRIMARY KEY CLUSTERED (party_number,related_party_number,relationship_type_code,attribute_type_code,change_begin_date))
GO

CREATE TABLE SCHCORE.FSC_PEER_GROUP
(
	peer_group_key       DECIMAL(12) NOT NULL ,
	peer_group_id        VARCHAR(50)  ,
	peer_group_name      VARCHAR(50)  ,
	peer_group_desc      VARCHAR(200)  ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_PEER_GROUP PRIMARY KEY CLUSTERED (peer_group_key))
GO

CREATE TABLE SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE
(
	transaction_type_key DECIMAL(12) NOT NULL ,
	summary_group_key    DECIMAL(12) NOT NULL ,
	change_begin_date    DATETIME  ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_SUMMARY_TRANS_TYPE_BRID PRIMARY KEY CLUSTERED (transaction_type_key,summary_group_key))
GO

CREATE TABLE SCHCORE.FSC_TRANSACTION_DIM
(
	transaction_key      DECIMAL(12) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	transaction_reference_number VARCHAR(50) NOT NULL ,
	transaction_description VARCHAR(255)  ,
	security_name        VARCHAR(35)  ,
	deal_number          VARCHAR(35)  ,
	check_number         VARCHAR(10)  ,
	mechanism_id         VARCHAR(40)  ,
	CONSTRAINT XPKFSC_TRANSACTION_DIM PRIMARY KEY CLUSTERED (transaction_key))
GO

CREATE UNIQUE  INDEX XAK1FSC_TRANSACTION_DIM ON SCHCORE.FSC_TRANSACTION_DIM
(
	transaction_reference_number ASC
)
GO

CREATE INDEX XIE1FSC_TRANSACTION_DIM ON SCHCORE.FSC_TRANSACTION_DIM
(
	date_key ASC
)
GO

CREATE TABLE SCHCORE.FSC_TRANSPORT_WATCH_LIST_DIM
(
	transport_watch_list_key DECIMAL(12) NOT NULL ,
	transport_watch_list_number VARCHAR(35) NOT NULL ,
	watch_list_name      CHAR(4) NOT NULL ,
	type_desc            VARCHAR(20)  ,
	programs             VARCHAR(250)  ,
	identification_id    VARCHAR(255)  ,
	identification_type_desc VARCHAR(255)  ,
	entity_name          VARCHAR(800)  ,
	entity_model_type    VARCHAR(200)  ,
	entity_owner_operator VARCHAR(200)  ,
	entity_flag          VARCHAR(200)  ,
	address              VARCHAR(750)  ,
	city_name            VARCHAR(155)  ,
	state_name           VARCHAR(50)  ,
	country_code         CHAR(3)  ,
	country_name         VARCHAR(255)  ,
	create_date          DATETIME  ,
	update_date          DATETIME  ,
	exclude_ind          CHAR(1) NOT NULL ,
	change_begin_date    DATETIME NOT NULL ,
	change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00'
 NOT NULL ,
	change_current_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSC_TRANSPORT_WATCH_LIST_DI PRIMARY KEY CLUSTERED (transport_watch_list_key))
GO

CREATE INDEX XIE1FSC_TRANSPORT_WATCH_LIST_D ON SCHCORE.FSC_TRANSPORT_WATCH_LIST_DIM
(
	transport_watch_list_number ASC
)
GO

CREATE INDEX XIE2FSC_TRANSPORT_WATCH_LIST_D ON SCHCORE.FSC_TRANSPORT_WATCH_LIST_DIM
(
	watch_list_name ASC
)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_165 FOREIGN KEY (account_key) REFERENCES SCHCORE.FSC_ACCOUNT_DIM (account_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_166 FOREIGN KEY (branch_key) REFERENCES SCHCORE.FSC_BRANCH_DIM (branch_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_167 FOREIGN KEY (trade_date_key) REFERENCES SCHCORE.FSC_DATE_DIM (date_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_168 FOREIGN KEY (execution_time_key) REFERENCES SCHCORE.FSC_TIME_DIM (time_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_169 FOREIGN KEY (transaction_currency_key) REFERENCES SCHCORE.FSC_CURRENCY_DIM (currency_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_170 FOREIGN KEY (transaction_type_key) REFERENCES SCHCORE.FSC_TRANSACTION_TYPE_DIM (transaction_type_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_171 FOREIGN KEY (transaction_status_key) REFERENCES SCHCORE.FSC_TRANSACTION_STATUS_DIM (transaction_status_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_184 FOREIGN KEY (transaction_key) REFERENCES SCHCORE.FSC_TRANSACTION_DIM (transaction_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_TRADE_FACT
	ADD  CONSTRAINT R_186 FOREIGN KEY (associate_key) REFERENCES SCHCORE.FSC_ASSOCIATE_DIM (associate_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_131 FOREIGN KEY (account_key) REFERENCES SCHCORE.FSC_ACCOUNT_DIM (account_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_132 FOREIGN KEY (date_key) REFERENCES SCHCORE.FSC_DATE_DIM (date_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_140 FOREIGN KEY (time_key) REFERENCES SCHCORE.FSC_TIME_DIM (time_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_157 FOREIGN KEY (transaction_key) REFERENCES SCHCORE.FSC_TRANSACTION_DIM (transaction_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_158 FOREIGN KEY (branch_key) REFERENCES SCHCORE.FSC_BRANCH_DIM (branch_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_161 FOREIGN KEY (country_key) REFERENCES SCHCORE.FSC_COUNTRY_DIM (country_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_133 FOREIGN KEY (transaction_type_key) REFERENCES SCHCORE.FSC_TRANSACTION_TYPE_DIM (transaction_type_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_EVENT_FACT
	ADD  CONSTRAINT R_160 FOREIGN KEY (transaction_status_key) REFERENCES SCHCORE.FSC_TRANSACTION_STATUS_DIM (transaction_status_key)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_PROFILE_FACT
	ADD  CONSTRAINT R_6 FOREIGN KEY (month_key) REFERENCES SCHCORE.FSC_MONTH_DIM (month_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT FK_ACCOUNT_CREDIT FOREIGN KEY (account_key) REFERENCES SCHCORE.FSC_ACCOUNT_DIM (account_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_111 FOREIGN KEY (transaction_type_key) REFERENCES SCHCORE.FSC_TRANSACTION_TYPE_DIM (transaction_type_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_113 FOREIGN KEY (transaction_key) REFERENCES SCHCORE.FSC_TRANSACTION_DIM (transaction_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_149 FOREIGN KEY (executing_party_key) REFERENCES SCHCORE.FSC_PARTY_DIM (party_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_154 FOREIGN KEY (associate_key) REFERENCES SCHCORE.FSC_ASSOCIATE_DIM (associate_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_159 FOREIGN KEY (transaction_status_key) REFERENCES SCHCORE.FSC_TRANSACTION_STATUS_DIM (transaction_status_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_178 FOREIGN KEY (remitter_ext_party_key) REFERENCES SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM (ext_party_account_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_179 FOREIGN KEY (beneficiary_ext_party_key) REFERENCES SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM (ext_party_account_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT FK_BRANCH_CREDIT FOREIGN KEY (branch_key) REFERENCES SCHCORE.FSC_BRANCH_DIM (branch_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT FK_DATE_CREDIT FOREIGN KEY (date_key) REFERENCES SCHCORE.FSC_DATE_DIM (date_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT FK_TIME_CREDIT FOREIGN KEY (time_key) REFERENCES SCHCORE.FSC_TIME_DIM (time_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_85 FOREIGN KEY (transaction_currency_key) REFERENCES SCHCORE.FSC_CURRENCY_DIM (currency_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_126 FOREIGN KEY (country_key) REFERENCES SCHCORE.FSC_COUNTRY_DIM (country_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_FACT
	ADD  CONSTRAINT R_389 FOREIGN KEY (executing_ext_party_key) REFERENCES SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM (ext_party_account_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD  CONSTRAINT R_175 FOREIGN KEY (bank_key) REFERENCES SCHCORE.FSC_BANK_DIM (bank_key)
GO

ALTER TABLE SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD  CONSTRAINT R_176 FOREIGN KEY (transaction_key) REFERENCES SCHCORE.FSC_CASH_FLOW_FACT (transaction_key)
GO

ALTER TABLE SCHCORE.FSC_CLASSIFIER_FACT
	ADD  CONSTRAINT R_181 FOREIGN KEY (month_key) REFERENCES SCHCORE.FSC_MONTH_DIM (month_key)
GO

ALTER TABLE SCHCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
	ADD  CONSTRAINT FK_CUST_HH_BRIDGE FOREIGN KEY (party_key) REFERENCES SCHCORE.FSC_PARTY_DIM (party_key)
GO

ALTER TABLE SCHCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
	ADD  CONSTRAINT R_47 FOREIGN KEY (household_key) REFERENCES SCHCORE.FSC_HOUSEHOLD_DIM (household_key)
GO

ALTER TABLE SCHCORE.FSC_PARTY_PROFILE_FACT
	ADD  CONSTRAINT R_155 FOREIGN KEY (month_key) REFERENCES SCHCORE.FSC_MONTH_DIM (month_key)
GO

ALTER TABLE SCHCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
	ADD  CONSTRAINT R_162 FOREIGN KEY (household_key) REFERENCES SCHCORE.FSC_HOUSEHOLD_DIM (household_key)
GO

ALTER TABLE SCHCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
	ADD  CONSTRAINT R_163 FOREIGN KEY (account_key) REFERENCES SCHCORE.FSC_ACCOUNT_DIM (account_key)
GO

ALTER TABLE SCHCORE.FSC_PARTY_ACCOUNT_BRIDGE
	ADD  CONSTRAINT FK_CUST_ACCT_BRIDGE FOREIGN KEY (party_key) REFERENCES SCHCORE.FSC_PARTY_DIM (party_key)
GO

ALTER TABLE SCHCORE.FSC_PARTY_ACCOUNT_BRIDGE
	ADD  CONSTRAINT R_8 FOREIGN KEY (account_key) REFERENCES SCHCORE.FSC_ACCOUNT_DIM (account_key)
GO

ALTER TABLE SCHCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE
	ADD  CONSTRAINT R_412 FOREIGN KEY (transaction_type_key) REFERENCES SCHCORE.FSC_TRANSACTION_TYPE_DIM (transaction_type_key)
GO
