
/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_custom_sample_gen_input_form
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Sample program to demonstrate how to use the form configuration data defined in  
|          RC_CFG.FORM_EFLE_FIELD_CONFIG table to generate html form for data entry.  
+------------------------------------------------------------------------------+
| PARAMETER:
|          form_config_key      = form key  (form key of the shipped sample is 901) 
|          form_type_code       = form type (form type of the shipped sample is SAMPLE)
|          form_efile_record_id = form record type (record type of the shipped sample is 3A)
|          report_status_includedYN = Y or N to indicate whether the form supports editing of REPORT_STATUS_CODE. 
|                                 Y for the shipped sample.
| NOTE:    This program is called by rc_custom_config_sample.sas when 
|          the sample form is configured. 
|          This sample has only one record type (3A). 
|          A more complicated program is needed to handle multiple record types.          
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/



%macro rc_custom_sample_gen_input_form(  form_config_key=
                                       , form_type_code=
                                       , form_efile_record_id=
                                       , report_status_includedYN=);

  
     
    /* get all the look up values for the form */
    data lov (index=(lov_type_name));
    set seg_kc.fsk_lov;
    where (scan(lov_type_name,1,'.')="&form_type_code"
          and scan(lov_type_name,2,'.')="&form_efile_record_id") or
          lov_type_name in ('FCF_REPORT_STATUS' 'STATE_US')
          and active_flg='Y' 
          and lov_language_desc='en';
    run;

    /* Get the column attributes */
      
    proc sql;
    create table form_efile_field_config as
    select *
    from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
    where form_config_key=&form_config_key
          and form_efile_record_id="&form_efile_record_id"
          and source_field_name ne ''
    order form_efile_record_id, form_efile_field_seq_number

    ;
    quit;


/* generate html form for data entry */
data _null_;
     set form_efile_field_config end=eof;
     by form_efile_record_id form_efile_field_seq_number;

     
    length stmt   element elementAttr inputType $ 512;
    length lov_type_name $ 256;
    file rc_tmplt(&form_type_code._&form_efile_record_id._input_form.htm);
     
    
    element='input';
    elementAttr='';

    if first.form_efile_field_seq_number then
    do;
        select (source_field_type);   
            when ('DATE')
            do;
                inputType='date';     
            end;
            when ('BOOLEAN')
            do;
                inputType='checkbox';                
            end;
 
            when ('CODE')
            do;
                element='select';
                inputType=''; 
                lov_type_name="&form_type_code"||'.'||strip(form_efile_record_id)||'.'||strip(target_field_name); 
            end;

            
            when ('DIGIT')
            do;
                inputType='text';    
                elementAttr=  ' size="'||strip(put(min(target_field_length,100),best.))||'"' 
                            ||' max="'||strip(put(target_field_length,best.))||'"'
                            ||' pattern="[\d]*"'
                            ||' title="Digits only"'
                            
                            ;
            end;


            when ('STATE_CODE')
            do;
                element='select';
                inputType=''; 
                lov_type_name='STATE_US'; 
            end;
  
            otherwise
            do;
                if target_field_length <= 100 then 
                do;
                    inputType='text';    
                    elementAttr=' size="'||strip(put(min(target_field_length,100),best.))||'"' 
                              ||' max="'||strip(put(target_field_length,best.))||'"';
                end;
                else
                do;
                    inputType='';
                    element='textarea'; 
                    elementAttr=' cols="100"'||' rows="'||strip(put(ceil(target_field_length/100),best.))||'"';
                end; 
            end;
         
        end;
        link WRT;
    end;
    if eof then link TERM;

     
return;

WRT:
    put;
    put  '<div class="labelValueRow">';
    stmt='<div><label for="'||strip(source_field_name)||'">'||strip(target_field_short_desc)||':<label></div>';
    put stmt; stmt='';
    
    put  '<div>';
    stmt='<'||strip(element);

    if elementAttr ne '' then stmt=strip(stmt)||' '||strip(elementAttr);

   
    if inputType ne '' then  stmt=strip(stmt)||' type="'||strip(inputType)||'"';
    
    stmt=strip(stmt)||' id="'||strip(source_field_name)||'"'||' name="'||strip(target_field_name)||'">';
    put stmt; stmt='';   
   
    if element='select' then 
    do; 
        link WRTLIST; 
    end;

    stmt= '</'||strip(element)||'>';
    put stmt; stmt='';
     
    put '</div>';
    put '</div>';
return;

 
WRTLIST:

 /*
        <option value="A" >Intial Filing </option>
        <option value="B">Correction <option>
 */

     stmt='<option value=" " > (none selected) </option>';
     put stmt; stmt='';     
      
    do until (_IORC_ NE 0);
       set lov  
           (keep = lov_type_name lov_type_code lov_type_desc) key=lov_type_name;
            error=0;
            if _IORC_ = 0 then 
            do;
                
                stmt='<option value="'||strip(lov_type_code)||'" > '||strip(lov_type_desc)||'</option>';
                put stmt; stmt=''; 
            end; 
            else 
            do;
               lov_type_name='';
               lov_type_code='';
               lov_type_desc='';
            end;
            _ERROR_=0;
    end;

     
return;

TERM:

      %if %upcase(&report_status_includedYN)=Y %then
      %do;
             source_field_name='reportStatusCode';
             target_field_name='REPORT_STATUS_CODE';
             target_field_short_desc='Report Status';
             element='select';
             inputType=''; 
             lov_type_name="FCF_REPORT_STATUS";
             link WRT;

      %end; 
    
return;

run;



%mend;

%let form_config_key=901;
%let form_type_code=SAMPLE;
%let form_efile_record_id=3A;

%rc_custom_sample_gen_input_form(   form_config_key=&form_config_key
                                  , form_type_code=&form_type_code
                                  , form_efile_record_id=&form_efile_record_id
                                  , report_status_includedYN=Y
                                 );


