/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_custom_sample_init_data
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Sample program to demonstrate how to retrieve custom form data.  
+------------------------------------------------------------------------------+
| PARAMETERS:  form_config_key      = form key  (form key of the shipped sample is 901) 
|              form_type_code       = form type (form type of the shipped sample is SAMPLE)
|              report_key           = report key
|              outdsn_var           = macro variable name to return output dataset name
|              form_efile_record_id_var= macro variable name to return record type.
|              report_status_includedYN = Y or N to indicate whether the form supports editing of REPORT_STATUS_CODE. 
|                                          Y for the shipped sample.
|
| NOTE:   This program is called by rc_custom_sample_stp_driver.sas  
|         This program define the record type of the starting data entry screen. 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
  

%macro rc_custom_sample_init_data(  form_config_key=901 
                                  , form_type_code=SAMPLE
                                  , report_key= 
                                  , outdsn_var=out_dsn
                                  , form_efile_record_id_var=form_efile_record_id
                      );

 
%global report_status_code;
%let report_status_code=;

proc sql noprint; 
     select report_status_code into :report_status_code
     from seg_kc.fsk_rc_report
     where report_key=&report_key
;
quit;

 
%let record_cnt=0;
%let form_efile_record_id=3A;


proc sql noprint;
     create table &form_type_code._&form_efile_record_id as
     select *
     from rc_db.&form_type_code._&form_efile_record_id(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&form_efile_record_id))
     where report_key=&report_key           
     ;
     %let record_cnt=&sqlobs;
quit;

%if &record_cnt=0 %then 
%do;
    /* If no user has edited this report before, create an entry in RC_DB libary. */

    /* Populate party data */ 
    %let pty_cnt=0;
    proc sql;
     create table party_info as
     select distinct pty.party_name as name,
            pty.party_tax_id as tax_id,
            case (pty.party_tax_id_type_code)
            when 'E' then 'A'
            when 'S' then 'B'
            else ' '
            end as tax_id_type_code,
            case (pty.party_type_desc)             
            when 'ORGANIZATION' then 'X'
            else ' '
            end as entity_flg,
            pty.street_address_1 as address,
            pty.street_city_name as city_nm,
            pty.street_state_code as state_code,
            pty.street_postal_code as postal_code,
            pty.email_address as email_address,
            pty.phone_number_1 as phone_no,
            pty.occupation_desc as occupation         
     from  seg_kc.fsk_rc_report as rpt,
           seg_kc.fsk_rc_report_entity as rptenty,
           seg_kc.fsc_party_dim as pty           
     where rpt.report_key=&report_key
           and rpt.report_key=rptenty.report_key
           and rptenty.entity_level_code='PTY'          
           and rptenty.entity_key=pty.party_key       
    ;
    %let pty_cnt=&sqlobs; 
quit;
   
    data &form_type_code._&form_efile_record_id;
         if 0 then set rc_db.&form_type_code._&form_efile_record_id(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&form_efile_record_id));
         %if &pty_cnt ne 0 %then
         %do;
             set party_info (obs=1);
         %end;
         report_key=&report_key;
         record_type="&form_efile_record_id";
         type_filing_code='A';
         entity_level_code="REPORT";
         entity_key=&report_key;
         activity_date=today();
         row_seq_number=1;
         output;
    run;

    proc append base=rc_db.&form_type_code._&form_efile_record_id(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._&form_efile_record_id, output_ds=Y))
                data=sample_3a force;
    run;
    

%end;


%let &outdsn_var=&form_type_code._&form_efile_record_id;
%let &form_efile_record_id_var=&form_efile_record_id;

 
%mend;


 
