<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>
	<!-- Sample XLST file to validate DOEPX Report UI data and display FinCEN provided error code              -->
	<!-- and item number. The error codes will be joined with another lookup table for the                    -->
	<!-- error level and full error message.                                                                  -->
	<!-- Output format:
       <ReportValidations>
            <ReportValidation>
                 <entityName>
                 <entityKey>
                 <errorCode>
                 <itemNumber>
				 <targetFieldName>
				 <errorRecordType>
            </ReportValidation>
       </ReportValidations>
    -->

	<!-- Define some Global variables to use in validations -->
	<!-- Validate Country/State Lookups to help with C10 fatal errors -->
	<!-- These include the military bases, such as AE, AA and AP -->
	<xsl:variable name='us_state_codes' 
	 select="'AL-AK-AE-AA-AP-AZ-AR-CA-CO-CT-DE-DC-FL-GA-HI-ID-IL-IN-IA-KS-KY-LA-ME-MD-MA-MI-MN-MS-MO-MT-NE-NV-NH-NJ-NM-NY-NC-ND-OH-OK-OR-PA-RI-SC-SD-TN-TX-UT-VT-VA-WA-WV-WI-WY'"/>
	<xsl:variable name='as_state_codes' select="'AS'"/>
	<xsl:variable name='fm_state_codes' select="'FM'"/>
	<xsl:variable name='gu_state_codes' select="'GU'"/>
	<xsl:variable name='mp_state_codes' select="'MP'"/>
	<xsl:variable name='mh_state_codes' select="'MH'"/>
	<xsl:variable name='pr_state_codes' select="'PR'"/>
	<xsl:variable name='pw_state_codes' select="'PW'"/>
	<xsl:variable name='vi_state_codes' select="'VI'"/>

	<xsl:variable name="convertedCurrentDate" select="10000 * substring(/EfileCollection/currentDate, 1, 4) + 100 * substring(/EfileCollection/currentDate, 6, 2) + substring(/EfileCollection/currentDate, 9, 2)"/>


	<xsl:template match="/EfileCollection">
		<!--
        <xsl:text>&#xd;</xsl:text>
		-->
		<ReportValidations>

			<xsl:variable name='fincenFiler_count' select="count(fincenFiler)"/>

			<!-- Fatal - No FINCEN_INSTITUTION found -->
			<xsl:choose>
				<xsl:when test="$fincenFiler_count = 0">
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'D14'"/>
						<xsl:with-param name="target_field_name" select="''"/>
						<xsl:with-param name="error_record_type" select="'Filer'"/>
						<xsl:with-param name="entity_name" select="'fincenFiler'"/>
						<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
						<xsl:with-param name="item_number" select="'45'"/>
					</xsl:call-template>
					<!--
                    <xsl:variable name='item_number' select="'Filing'"/>
                    <xsl:variable name='error_code' select='D14'/>
                    <xsl:variable name='target_field_name' select='Institution'/>
                    <xsl:variable name='error_record_type' select='batch'/>
                    <ReportValidation>
                        <entityName>fincenFiler</entityName>
                        <errorCode><xsl:value-of select="$error_code"/></errorCode>
                        <entityKey><xsl:value-of select="reportCollections/reportCollection/report/reportKey"/></entityKey>
                        <itemNumber><xsl:value-of select="$item_number"/></itemNumber>
                        <targetFieldName><xsl:value-of select="$target_field_name"/></targetFieldName>
                        <errorRecordType><xsl:value-of select="$error_record_type"/></errorRecordType>
                    </ReportValidation>
                    -->
				</xsl:when>
				<!-- Only 1 fincenFiler on report -->
				<xsl:when test="$fincenFiler_count > 1">
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'D15'"/>
						<xsl:with-param name="target_field_name" select="''"/>
						<xsl:with-param name="error_record_type" select="'Filer'"/>
						<xsl:with-param name="entity_name" select="'fincenFiler'"/>
						<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
						<xsl:with-param name="item_number" select="'45'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<!-- removed because this is validated in rc_fincen_inst_data_validation_doepx_macro.sas -->
					<!-- xsl:call-template name=fincenFiler/-->
				</xsl:otherwise>
			</xsl:choose>

			<!-- D07: The date of signature is greater than the current date or less than January 1, 2000.-->
			<xsl:if test="not($convertedCurrentDate >= 20000101)">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D07'"/>
					<xsl:with-param name="target_field_name" select="'Signature Date'"/>
					<xsl:with-param name="error_record_type" select="'report'"/>
					<xsl:with-param name="entity_name" select="concat('Signature Date: ',$convertedCurrentDate)"/>
					<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'30'"/>
				</xsl:call-template>
			</xsl:if>

			<xsl:variable name='fincenTransmitter_count' select="count(fincenTransmitter)"/>

			<xsl:choose>
				<!--D08: Missing Transmitter party type-->
				<xsl:when test="$fincenTransmitter_count = 0">
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'D08'"/>
						<xsl:with-param name="target_field_name" select="''"/>
						<xsl:with-param name="error_record_type" select="'Filer'"/>
						<xsl:with-param name="entity_name" select="'fincenTransmitter'"/>
						<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
						<xsl:with-param name="item_number" select="'35'"/>
					</xsl:call-template>
				</xsl:when>
				<!--D09: More than one Transmitter party type is recorded.-->
				<xsl:when test="$fincenTransmitter_count > 1">
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'D09'"/>
						<xsl:with-param name="target_field_name" select="''"/>
						<xsl:with-param name="error_record_type" select="'Filer'"/>
						<xsl:with-param name="entity_name" select="'fincenTransmitter'"/>
						<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
						<xsl:with-param name="item_number" select="'35'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="fincenTransmitter"/>
				</xsl:otherwise>
			</xsl:choose>

			<!-- Only 1 subject on report -->
			<xsl:variable name='subject_count' select="count(reportCollections/reportCollection/report/subjects)"/>

			<!-- D12: Missing Exempt Party party type.-->
			<xsl:if test="$subject_count = 0">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D12'"/>
					<xsl:with-param name="target_field_name" select="'Report'"/>
					<xsl:with-param name="error_record_type" select="'party'"/>
					<xsl:with-param name="entity_name" select="'fincenFiler'"/>
					<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'Subject'"/>
				</xsl:call-template>
			</xsl:if>

			<!-- Maximum subjects -->
			<!-- D13: More than one Exempt Party party type is recorded.-->
			<xsl:if test="$subject_count &gt; 1">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D13'"/>
					<xsl:with-param name="target_field_name" select="'Report'"/>
					<xsl:with-param name="error_record_type" select="'party'"/>
					<xsl:with-param name="entity_name" select="'fincenFiler'"/>
					<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'Subject'"/>
				</xsl:call-template>
			</xsl:if>

			<xsl:apply-templates select="reportCollections/reportCollection/report/subjects/entityUiJSON"/>

			<xsl:apply-templates select="reportCollections/reportCollection/report/reportUiJSON"/>



		</ReportValidations>
	</xsl:template>


	<xsl:template name="fincenFiler">

		<!-- B01: The primary regulator of the bank is not provided.-->
		<xsl:if test="not( institutionPrimFedRegCode != '' )">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'B01'"/>
				<xsl:with-param name="target_field_name" select="'PrimaryRegulatorTypeCode'"/>
				<xsl:with-param name="error_record_type" select="'filer'"/>
				<xsl:with-param name="entity_name" select="concat('PrimaryRegulatorTypeCode: ',institutionPrimFedRegCode)"/>
				<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
				<xsl:with-param name="item_number" select="'24'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- B02: The legal name of the bank is not provided.-->
		<xsl:if test="not( institutionLegalName != '' )">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'B02'"/>
				<xsl:with-param name="target_field_name" select="'PartyName RawPartyFullName'"/>
				<xsl:with-param name="error_record_type" select="'filer'"/>
				<xsl:with-param name="entity_name" select="concat('PartyName RawPartyFullName: ',institutionLegalName)"/>
				<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
				<xsl:with-param name="item_number" select="'17'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 20 Address -->
		<!-- B04 The street address of the bank is not provided. -->

		<xsl:if test="not(institutionAddress !='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'B04'"/>
				<xsl:with-param name="target_field_name" select="'Address'"/>
				<xsl:with-param name="error_record_type" select="'filer'"/>
				<xsl:with-param name="entity_name" select="concat('Address: ',institutionAddress)"/>
				<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
				<xsl:with-param name="item_number" select="'20'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 21 City -->
		<!-- B05: The city of the bank is not provided. -->
		<xsl:if test="not(institutionCityName !='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'B05'"/>
				<xsl:with-param name="target_field_name" select="'City'"/>
				<xsl:with-param name="error_record_type" select="'filer'"/>
				<xsl:with-param name="entity_name" select="concat('City: ',institutionCityName)"/>
				<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
				<xsl:with-param name="item_number" select="'21'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Variable for B06 validation -->
		<xsl:variable name="resultCode" select="translate(institutionStateCode,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','XXXXXXXXXXXXXXXXXXXXXXXXXX')"/>

		<xsl:choose>
			<!-- Item 22 StateCode -->
			<!-- B06: The state/territory of the bank is not provided. -->
			<xsl:when test="not(institutionStateCode !='')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'B06'"/>
					<xsl:with-param name="target_field_name" select="'State'"/>
					<xsl:with-param name="error_record_type" select="'filer'"/>
					<xsl:with-param name="entity_name" select="concat('State: ',institutionStateCode)"/>
					<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'22'"/>
				</xsl:call-template>
			</xsl:when>
			<!-- B07: The state/territory code of the bank is invalid. -->
			<xsl:when test="not($resultCode='XX')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'B07'"/>
					<xsl:with-param name="target_field_name" select="'State'"/>
					<xsl:with-param name="error_record_type" select="'filer'"/>
					<xsl:with-param name="entity_name" select="concat('State: ',institutionStateCode)"/>
					<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'22'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<!-- Item 23 postalCode -->
		<!-- B08: The ZIP Code of the bank is not provided. -->
		<xsl:choose>
			<xsl:when test="not(institutionZipCode!='')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'B08'"/>
					<xsl:with-param name="target_field_name" select="'ZIP Code'"/>
					<xsl:with-param name="error_record_type" select="'filer'"/>
					<xsl:with-param name="entity_name" select="concat('ZIP Code: ',institutionZipCode)"/>
					<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'23'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!-- B09: The ZIP Code of the bank is invalid.-->
				<xsl:variable name='lenZipCode' select="string-length(institutionZipCode)"/>
				<xsl:if test="($lenZipCode != 5) and ($lenZipCode != 9)" >
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'B09'"/>
						<xsl:with-param name="target_field_name" select="'ZIP Code'"/>
						<xsl:with-param name="error_record_type" select="'filer'"/>
						<xsl:with-param name="entity_name" select="concat('ZIP Code: ',institutionZipCode)"/>
						<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
						<xsl:with-param name="item_number" select="'23'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Item 18 EIN -->
		<!-- P14 The TIN of the exempt person is not provided. -->

		<xsl:if test="not(institutionTaxId!='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'B10'"/>
				<xsl:with-param name="target_field_name" select="'EIN'"/>
				<xsl:with-param name="error_record_type" select="'filer'"/>
				<xsl:with-param name="entity_name" select="concat('EIN: ',institutionTaxId)"/>
				<xsl:with-param name="entity_key" select="reportCollections/reportCollection/report/reportKey"/>
				<xsl:with-param name="item_number" select="'18'"/>
			</xsl:call-template>
		</xsl:if>

	</xsl:template>

	<!-- Drill down into the subjects Detail -->
	<xsl:template match="entityUiJSON">

	    <xsl:variable name='subject_entity_key' select="../../reportKey"/>

		<!-- Item 3 Last Name -->
		<!-- P01: The last name/entity legal name of the exempt person is not provided.-->
		<xsl:if test="not(lastName != '')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P01'"/>
				<xsl:with-param name="target_field_name" select="'Subject Last Name'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('LastName: ',lastName)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'3'"/>
			</xsl:call-template>

		</xsl:if>

		<!-- Item 4 First Name -->
		<!-- P02 The exempt person is an individual and first name is not provided. -->
		<xsl:if test="not(firstName !='') and   not(entityFlag='true')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P02'"/>
				<xsl:with-param name="target_field_name" select="'Subject First Name'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('First Name: ',firstName)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'4'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 4 First Name  -->
		<!-- P03 The exempt person is an entity and first name is provided. -->
		<xsl:if test="firstName !='' and  entityFlag='true'">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P03'"/>
				<xsl:with-param name="target_field_name" select="'Subject First Name'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('First Name: ',firstName)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'4'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 5 Middle Name or Suffix -->
		<!-- P04 The exempt person is an entity and middle name or suffix is provided. -->
		<xsl:if test="middleName !='' and  entityFlag='true'">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P04'"/>
				<xsl:with-param name="target_field_name" select="'Subject Middle Name'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('Middle Name: ',middleName)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'5'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- P05 The exempt person is an entity and middle name or suffix is provided. -->
		<xsl:if test="suffix !='' and  entityFlag='true'">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P05'"/>
				<xsl:with-param name="target_field_name" select="'Subject Suffix'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('Suffix: ',suffix)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'5'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 8 Address -->
		<!-- P07 The street address of the exempt person is not provided. -->

		<xsl:if test="not(address !='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P07'"/>
				<xsl:with-param name="target_field_name" select="'Address'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('Address: ',address)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'8'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 9 City -->
		<!-- P08 The city of the exempt person is not provided. -->

		<xsl:if test="not(city !='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P08'"/>
				<xsl:with-param name="target_field_name" select="'City'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('City: ',city)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'9'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Variable for P10 validation -->
		<xsl:variable name="resultCode" select="translate(stateCode,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','XXXXXXXXXXXXXXXXXXXXXXXXXX')"/>

		<xsl:choose>
		<!-- Item 10 StateCode -->
		<!-- P09 The state/territory of the exempt person is not provided. -->
			<xsl:when test="not(stateCode !='')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'P09'"/>
					<xsl:with-param name="target_field_name" select="'State'"/>
					<xsl:with-param name="error_record_type" select="'party'"/>
					<xsl:with-param name="entity_name" select="concat('State: ',stateCode)"/>
					<xsl:with-param name="entity_key" select="$subject_entity_key"/>
					<xsl:with-param name="item_number" select="'10'"/>
				</xsl:call-template>
			</xsl:when>
			<!-- P10: The state/territory code of the exempt person is invalid. -->
			<xsl:when test="not($resultCode='XX')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'P10'"/>
					<xsl:with-param name="target_field_name" select="'State'"/>
					<xsl:with-param name="error_record_type" select="'party'"/>
					<xsl:with-param name="entity_name" select="concat('State: ',stateCode)"/>
					<xsl:with-param name="entity_key" select="$subject_entity_key"/>
					<xsl:with-param name="item_number" select="'10'"/>
				</xsl:call-template>
			</xsl:when>
			<!-- P11: The state/territory/country code mismatch. -->
			<xsl:otherwise>
				<xsl:if test="not(contains($us_state_codes,stateCode) or contains($as_state_codes,stateCode) or contains($fm_state_codes,stateCode)
				 or contains($gu_state_codes,stateCode) or contains($mp_state_codes,stateCode) or contains($pr_state_codes,stateCode)
				 or contains($pw_state_codes,stateCode) or contains($vi_state_codes,stateCode) or contains($mh_state_codes,stateCode))">
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'P11'"/>
						<xsl:with-param name="target_field_name" select="'State'"/>
						<xsl:with-param name="error_record_type" select="'party'"/>
						<xsl:with-param name="entity_name" select="concat('State: ',stateCode)"/>
						<xsl:with-param name="entity_key" select="$subject_entity_key"/>
						<xsl:with-param name="item_number" select="'10'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Item 11 postalCode -->
		<!-- P12 The ZIP Code of the exempt person is not provided. -->
		<xsl:choose>
			<xsl:when test="not(postalCode!='')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'P12'"/>
					<xsl:with-param name="target_field_name" select="'ZIP Code'"/>
					<xsl:with-param name="error_record_type" select="'party'"/>
					<xsl:with-param name="entity_name" select="concat('ZIP Code: ',postalCode)"/>
					<xsl:with-param name="entity_key" select="$subject_entity_key"/>
					<xsl:with-param name="item_number" select="'11'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!-- P13: The ZIP Code of the exempt person is invalid.-->
				<xsl:variable name='lenZipCode' select="string-length(postalCode)"/>
				<xsl:if test="($lenZipCode != 5) and ($lenZipCode != 9)" >
					<xsl:call-template name="LogError">
						<xsl:with-param name="error_code" select="'P13'"/>
						<xsl:with-param name="target_field_name" select="'ZIP Code'"/>
						<xsl:with-param name="error_record_type" select="'party'"/>
						<xsl:with-param name="entity_name" select="concat('ZIP Code: ',postalCode)"/>
						<xsl:with-param name="entity_key" select="$subject_entity_key"/>
						<xsl:with-param name="item_number" select="'11'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Item 12 TaxID or TIN -->
		<!-- P14 The TIN of the exempt person is not provided. -->

		<xsl:if test="not(TaxID!='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P14'"/>
				<xsl:with-param name="target_field_name" select="'TIN'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('TIN: ',TaxID)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'12'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 12 TaxID and 13 TaxIDType -->
		<!-- only TaxIDType is validated because P14 validates TaxID, and regex in frontend-->
		<!-- P15 The TIN of the exempt person is invalid. -->

		<xsl:if test="not(TaxIDType!='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P15'"/>
				<xsl:with-param name="target_field_name" select="'TIN Type'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('TIN Type: ',TaxIDType)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'13'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 14 Email Address -->
		<!-- P16 The email address of the exempt person is invalid. -->
		<xsl:variable name="email1" select="substring-before(emailAddress,'@')" />
		<xsl:variable name="email2" select="substring-after(emailAddress,'@')" />
		<xsl:variable name="email3" select="substring-after($email2,'.')"/>
		<xsl:variable name="emailMask1" select="translate($email1,'.!#$%&amp;&quot;*+/=?^_`{|}~-1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz','')"/>
		<xsl:variable name="emailMask2" select="translate($email2,'!#$%&amp;&quot;*+/=?^_`{|}~-1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz','')"/>

		<xsl:if test="(emailAddress) and (
			string-length($email1) = 0 or substring($email1,1,1)='.' or $emailMask1 != ''
			or substring($email1,string-length($email1),1)='.'
			or string-length($email2) = 0 or $emailMask2 != '.'
			or string-length($email3) &gt; 3 or string-length($email3) = 0
		)">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P16'"/>
				<xsl:with-param name="target_field_name" select="'Email Address'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('Email Address: ',emailAddress)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'14'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 15 Phone Number -->
		<!-- P17 The phone number of the exempt person is invalid. -->

		<xsl:variable name="phoneNumberNotNumber" select="translate(phoneNumber,'1234567890','')"/>

		<xsl:if test="(phoneNumber) and (
			not(string-length(phoneNumber) = 10) or not(string-length($phoneNumberNotNumber)=0)
		 	)">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'P17'"/>
				<xsl:with-param name="target_field_name" select="'Phone Number'"/>
				<xsl:with-param name="error_record_type" select="'party'"/>
				<xsl:with-param name="entity_name" select="concat('Phone Number: ',phoneNumber)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'15'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Item 16 exemptPersonTypeCode -->
		<!-- A00 Schema Validation Failure -->
		<!-- D12 Missing Exempt Party party type is take as A00 by fincen -->

		<xsl:if test="not(exemptPersonTypeCode!='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'A00'"/>
				<xsl:with-param name="target_field_name" select="'Exempt Person Type Code'"/>
				<xsl:with-param name="error_record_type" select="'batch'"/>
				<xsl:with-param name="entity_name" select="concat('Exempt Person Type Code: ',exemptPersonTypeCode)"/>
				<xsl:with-param name="entity_key" select="$subject_entity_key"/>
				<xsl:with-param name="item_number" select="'16'"/>
			</xsl:call-template>
		</xsl:if>


	</xsl:template>


	<!-- Report level information -->
	<xsl:template match="reportUiJSON">

   		<xsl:variable name='report_key' select="../reportKey"/>

		<!-- Check the filing type and the DCN Number -->
		<xsl:choose>
		<xsl:when test="not(filingTypeCode!='')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'D01'"/>
				<xsl:with-param name="target_field_name" select="'Filing Type Code'"/>
				<xsl:with-param name="error_record_type" select="'report'"/>
				<xsl:with-param name="entity_name" select="concat('FilingTypeCode',filingTypeCode)"/>
				<xsl:with-param name="entity_key" select="$report_key"/>
				<xsl:with-param name="item_number" select="'1'"/>
			</xsl:call-template>
		</xsl:when>
		</xsl:choose>

		<xsl:variable name="bsa_id" select="../priorAgencyRefId"/>

		<!-- A08: The value recorded is a numeric entry not equal to 14 digits (with the exceptions of '0').-->
		<xsl:choose>
			<xsl:when test = "$bsa_id and not(translate($bsa_id,'1234567890','0000000000') = '00000000000000')
								and not($bsa_id = '0')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'A08'"/>
					<xsl:with-param name="target_field_name" select="'Prior report DCN'"/>
					<xsl:with-param name="error_record_type" select="'batch'"/>
					<xsl:with-param name="entity_name" select="concat('DCN: ',$bsa_id)"/>
					<xsl:with-param name="entity_key" select="$report_key"/>
					<xsl:with-param name="item_number" select="'1'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<!-- Check the filing type and the DCN Number -->
		<xsl:if test="filingTypeCode!='A' and not($bsa_id != '')">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'D03'"/>					
				<xsl:with-param name="target_field_name" select="'Prior report DCN'"/>
				<xsl:with-param name="error_record_type" select="'report'"/>
				<xsl:with-param name="entity_name" select="concat('DCN: ',$bsa_id)"/>
				<xsl:with-param name="entity_key" select="$report_key"/>
				<xsl:with-param name="item_number" select="'1'"/>
			</xsl:call-template>			
		</xsl:if>
		<xsl:if test="filingTypeCode = 'A' and ($bsa_id)">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'D04'"/>					
				<xsl:with-param name="target_field_name" select="'Prior report DCN'"/>
				<xsl:with-param name="error_record_type" select="'report'"/>
				<xsl:with-param name="entity_name" select="concat('DCN: ',$bsa_id)"/>
				<xsl:with-param name="entity_key" select="$report_key"/>
				<xsl:with-param name="item_number" select="'1'"/>
			</xsl:call-template>			 
		</xsl:if>

		<xsl:variable name="convertedDate" select="10000 * substring(effectiveDate, 1, 4) + 100 * substring(effectiveDate, 6, 2) + substring(effectiveDate, 9, 2)"/>
		<xsl:variable name="dateDelta" select="($convertedDate - $convertedCurrentDate)"/>

		<xsl:choose>
			<xsl:when test="not(effectiveDate!='')
			or not(translate(effectiveDate, '123456789', '000000000') = '0000-00-00T00:00:00.000Z')">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D05'"/>
					<xsl:with-param name="target_field_name" select="'Effective Date'"/>
					<xsl:with-param name="error_record_type" select="'report'"/>
					<xsl:with-param name="entity_name" select="concat('Effective Date: ',effectiveDate)"/>
					<xsl:with-param name="entity_key" select="$report_key"/>
					<xsl:with-param name="item_number" select="'2'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="not($convertedDate >= 20000101)">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D05'"/>
					<xsl:with-param name="target_field_name" select="'Effective Date'"/>
					<xsl:with-param name="error_record_type" select="'report'"/>
					<xsl:with-param name="entity_name" select="concat('Effective Date: ',$convertedDate)"/>
					<xsl:with-param name="entity_key" select="$report_key"/>
					<xsl:with-param name="item_number" select="'2'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="not(0 >= $dateDelta)">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D05'"/>
					<xsl:with-param name="target_field_name" select="'Effective Date'"/>
					<xsl:with-param name="error_record_type" select="'report'"/>
					<xsl:with-param name="entity_name" select="concat('Effective Date: ',$convertedDate)"/>
					<xsl:with-param name="entity_key" select="$report_key"/>
					<xsl:with-param name="item_number" select="'2'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:variable name="AOCant1" select="count(contactName)"/>
		<xsl:variable name="AOCant2" select="count(contactTitle)"/>
		<xsl:variable name="AOCant3" select="count(contactPhoneNumber)"/>
		<xsl:variable name="AOCant4" select="count(contactPhoneExtension)"/>

		<xsl:if test="not(1 >= $AOCant1) or not(1 >= $AOCant2)
			or not(1 >= $AOCant3) or not(1 >= $AOCant4)">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'D17'"/>
				<xsl:with-param name="target_field_name" select="'Authorized Oficial'"/>
				<xsl:with-param name="error_record_type" select="'report'"/>
				<xsl:with-param name="entity_name" select="'Authorized Oficial'"/>
				<xsl:with-param name="entity_key" select="$report_key"/>
				<xsl:with-param name="item_number" select="'26,27,29,29a'"/>
			</xsl:call-template>
		</xsl:if>

		<xsl:variable name="contactPhoneNumberNotNumber" select="translate(contactPhoneNumber,'1234567890','')"/>
		<xsl:variable name="contactPhoneExtensionNotNumber" select="translate(contactPhoneExtension,'1234567890','')"/>

		<!-- D06: The phone number recorded for the Authorized Official is invalid.-->
		<xsl:if test="(contactPhoneNumber) and (not(10 = string-length(contactPhoneNumber))
		 or not(string-length($contactPhoneNumberNotNumber)=0))">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'D06'"/>
				<xsl:with-param name="target_field_name" select="'Contact Phone Number'"/>
				<xsl:with-param name="error_record_type" select="'report'"/>
				<xsl:with-param name="entity_name" select="concat('Contact Phone Number: ',contactPhoneNumber)"/>
				<xsl:with-param name="entity_key" select="$report_key"/>
				<xsl:with-param name="item_number" select="'29'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- D06: The phone number recorded for the Authorized Official is invalid.-->
		<xsl:if test="(contactPhoneExtension) and (not(6 >= string-length(contactPhoneExtension))
		 or not(string-length($contactPhoneExtensionNotNumber)=0))">
			<xsl:call-template name="LogError">
				<xsl:with-param name="error_code" select="'D06'"/>
				<xsl:with-param name="target_field_name" select="'Contact Phone Number Extension'"/>
				<xsl:with-param name="error_record_type" select="'report'"/>
				<xsl:with-param name="entity_name" select="concat('Contact Phone Number Extension: ',contactPhoneExtension)"/>
				<xsl:with-param name="entity_key" select="$report_key"/>
				<xsl:with-param name="item_number" select="'29a'"/>
			</xsl:call-template>
		</xsl:if>


	</xsl:template>

	<xsl:template match="fincenTransmitter">
		<!-- D10: Missing Transmitter Contact party type. (only transmitterContactName field)-->
		<xsl:variable name="party37" select="count(transmitterContactName)"/>
		<xsl:choose>
			<xsl:when test="not(transmitterContactName) or $party37=0">
				<xsl:call-template name="LogError">
					<xsl:with-param name="error_code" select="'D10'"/>
					<xsl:with-param name="target_field_name" select="'Report'"/>
					<xsl:with-param name="error_record_type" select="'party'"/>
					<xsl:with-param name="entity_name" select="'fincenTransmitter'"/>
					<xsl:with-param name="entity_key" select="../reportCollections/reportCollection/report/reportKey"/>
					<xsl:with-param name="item_number" select="'Transmitter Contact'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>


	</xsl:template>


	<!-- Custom templates to be used to determine leading and trailing white space for fields. -->
	<!-- XLST 1.0 is limited in functions for this capability.                                 -->
	<xsl:variable name="whitespace" select="'&#09;&#10;&#13; '" />
	<!-- Strips trailing whitespace characters from 'string' -->
	<xsl:template name="string-rtrim">
		<xsl:param name="string" />
		<xsl:param name="trim" select="$whitespace" />

		<xsl:variable name="length" select="string-length($string)" />

		<xsl:if test="$length &gt; 0">
			<xsl:choose>
				<xsl:when test="contains($trim, substring($string, $length, 1))">
					<xsl:call-template name="string-rtrim">
						<xsl:with-param name="string" select="substring($string, 1, $length - 1)" />
						<xsl:with-param name="trim"   select="$trim" />
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$string" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<!-- Strips leading whitespace characters from 'string' -->
	<xsl:template name="string-ltrim">
		<xsl:param name="string" />
		<xsl:param name="trim" select="$whitespace" />

		<xsl:if test="string-length($string) &gt; 0">
			<xsl:choose>
				<xsl:when test="contains($trim, substring($string, 1, 1))">
					<xsl:call-template name="string-ltrim">
						<xsl:with-param name="string" select="substring($string, 2)" />
						<xsl:with-param name="trim"   select="$trim" />
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$string" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<!-- Strips leading and trailing whitespace characters from 'string' -->
	<xsl:template name="string-trim">
		<xsl:param name="string" />
		<xsl:param name="trim" select="$whitespace" />
		<xsl:call-template name="string-rtrim">
			<xsl:with-param name="string">
				<xsl:call-template name="string-ltrim">
					<xsl:with-param name="string" select="$string" />
					<xsl:with-param name="trim"   select="$trim" />
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="trim"   select="$trim" />
		</xsl:call-template>
	</xsl:template>

	<!-- Report error -->

	<xsl:template name="LogError">
		<xsl:param name="error_code" />
		<xsl:param name="target_field_name" />
		<xsl:param name="error_record_type" />
		<xsl:param name="entity_name" />
		<xsl:param name="entity_key" />
		<xsl:param name="item_number" />


		<ReportValidation>
			<entityName>
				<xsl:value-of select="$entity_name"/>
			</entityName>
			<entityKey>
				<xsl:value-of select="$entity_key"/>
			</entityKey>
			<errorCode>
				<xsl:value-of select="$error_code"/>
			</errorCode>			
			<itemNumber>
				<xsl:value-of select="$item_number"/>
			</itemNumber>
			<targetFieldName>
				<xsl:value-of select="$target_field_name"/>
			</targetFieldName>
			<errorRecordType>
				<xsl:value-of select="$error_record_type"/>
			</errorRecordType>
		</ReportValidation>
	</xsl:template>

</xsl:stylesheet>