/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_fincen_config_update_5.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Program to update regulatory console configuration data.
|          It includes 
|          1. disabling the old FinCEN forms (SAR, CTR, DOEP) 
+------------------------------------------------------------------------------+
| USAGE:   Run this program using UTF-8 SAS.
+-------------+----------------------------------------------------------------+
| COMMENTS    | This program is executed by the regulatory console deployment scripts.
+-------------+----------+----------+------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2020 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_updt_disable_old_form; 
    
    proc sql noprint; 
         update seg_kc.fsk_rc_form_config
         set logical_delete_ind='Y',
             effective_to_date='31DEC2018:00:00:00'dt 
         where form_type_code = 'SAR' and logical_delete_ind ne 'Y'
         ;
         update seg_kc.fsk_rc_form_config
         set logical_delete_ind='Y',
             effective_to_date='31MAY2018:00:00:00'dt  
         where form_type_code = 'CTR' and logical_delete_ind ne 'Y'
         ;   
         update seg_kc.fsk_rc_form_config
         set logical_delete_ind='Y',
             effective_to_date='16JAN2020:00:00:00'dt  
         where form_type_code = 'DOEP' and logical_delete_ind ne 'Y'
         ;       
     quit;
  
%mend;


%macro rc_updt_sarx_error_code;

/****************************************************************/
/* Fix SARX primary errors                                      */
/****************************************************************/


  proc sql;
       /* remove '*' from B49* because it is a fatal error */
       update rc_cfg.sarx_fincen_error_code (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=sarx_fincen_error_code))
       set error_code='B49'
       where error_code = 'B49*'
       ;
       
       update rc_cfg.sarx_fincen_error_code (%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=sarx_fincen_error_code))
       set error_type_code='P',
           error_type_text='Warning (Primary)',
           error_code=compress(error_code, '*')
       where error_type_code='S' and error_code contains '*'
       ;
  quit;

%mend;


%macro rc_updt_resp_constraint;

/*****************************************************************/
/* Update key constraint in RC_DB.RESP_FINCEN_ERROR_LIST         */
/*****************************************************************/

  %let upgraded_yn=N; 

  /* export data table content with encrption option */
  proc contents data=rc_db.resp_fincen_error_list (%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_error_list))
                out=resp_fincen_error_list_content             
                noprint;
  run; 
 
  /* Check whether TRANS_SEQ_NUMBER is included in the index */
  proc sql noprint;
       select ifc(idxusage='NONE','N','Y') into :upgraded_yn
       from resp_fincen_error_list_content
       where name='TRANS_SEQ_NUMBER'
        ;
     
   %if &upgraded_yn = N %then
   %do;
        /* remove the old primary key (RESPONSE_ID, LINE_NUMBER, ERROR_SEQ_NUMBER) */
        alter table rc_db.resp_fincen_error_list (%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_error_list ))
        drop constraint prim_key
        ;
        /* Add new unique key (RESPONSE_ID, TRANS_SEQ_NUMBER, LINE_NUMBER, ERROR_SEQ_NUMBER) */
        /* TRANS_SEQ_NUMBER or LINE_NUMBER can be null depending on the type of response     */
        alter table rc_db.resp_fincen_error_list (%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_error_list))
        add constraint unique_key unique (RESPONSE_ID, TRANS_SEQ_NUMBER, LINE_NUMBER,  ERROR_SEQ_NUMBER)
       ;
    %end;

       
  quit;

%mend;

 
%rc_updt_disable_old_form;
%rc_updt_sarx_error_code;
%rc_updt_resp_constraint;

 



