/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_fincen_config_update_7.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Program to update data for FinCEN reporting in hotfix 12.
|          1. rc_cfg.fincen_instittion
|          2. rc_cfg.sarx_fincen_error_code
+------------------------------------------------------------------------------+
| USAGE:   Run this program using UTF-8 SAS.
+-------------+----------------------------------------------------------------+
| COMMENTS    | This program is executed by the regulatory console deployment scripts.
+-------------+----------+----------+------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2021 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_updt_fincen_inst_flag;

    /* Add UNK flags to FINCEN_INSTITUTION  */
   
    proc contents data=RC_CFG.FINCEN_INSTITUTION(%fcf_get_ds_opts(lib_name=RC_CFG, ds_name=FINCEN_INSTITUTION))
                  out=rc_cfg_tab_cols(keep=name)
                  noprint;
     run;
    %let upgraded=N;
    proc sql noprint;
         select 'Y' into :upgraded
         from rc_cfg_tab_cols
         where upcase(name) eq 'INSTITUTION_TAX_ID_UNK_FLG'
         ;       
     quit;
    
 
    %if &upgraded=N %then
    %do;
       /* Upgrade table structure of RC_CFG.FINCEN_INSTITUTION */
       proc sql;
       alter table rc_cfg.fincen_institution(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_institution))
       add INSTITUTION_LEGAL_NAME_UNK_FLG char(1) label='Legal Name Unknown',
           INSTITUTION_TAX_ID_UNK_FLG char(1) label='Tax Id Unknown',
           INSTITUTION_ADDRESS_UNK_FLG char(1) label='Address Unknown',
           INSTITUTION_CITY_UNK_FLG char(1) label='City Unknown',
           INSTITUTION_ZIP_CODE_UNK_FLG char(1) label='Zip Code Unknown',
           INSTITUTION_COUNTRY_UNK_FLG char(1) label='Country Unknown',
           DEFAULT_NO_BRANCH_ACTIVITY_FLG char(1) label='Default No branch activity'  
       ; 
       quit;
    %end;

%mend;

%macro rc_updt_sarx_error_code;

/* Update SARX error code description per FinCEN SARX User's Guide  */

/* read the latest rc_fincen_sarx_error_code.csv to create work table */
data sarx_fincen_error_code ;

      attrib ERROR_RECORD_TYPE length=$32 label='Error record type'
             ERROR_CODE  length=$10 label='Error Type Code'
             ERROR_DESC length=$4000 label='Error Text'              
             ERROR_TYPE_CODE length=$1 label='Error Severity Code' 
             ERROR_TYPE_TEXT length=$32 label='Error Severity Description'
             ASSOC_ELEMENT length=$256 label='Associated Element(s)'
             FIELD_REFERENCE length=$4000 label='Field Reference'
      ;
   
     infile rc_tmplt(rc_fincen_sarx_error_code.csv)  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input error_record_type $
           error_code $          
           error_desc $             
           error_type_text $
           assoc_element $
           field_reference $
    ;
    error_desc=compress(error_desc,,'kw');
    assoc_element=compress(assoc_element,,'kw');
    field_reference=compress(field_reference,,'kw');
    select (error_type_text);
        when ('Fatal') error_type_code='F';    
        when ('Warning (Primary)') error_type_code='P';
        when ('Warning') error_type_code='S';
    otherwise;
  end;
run;

/* update error_desc by error_code without affecting any field implemented custom error codes */
proc sql feedback;
    
   update rc_cfg.sarx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=sarx_fincen_error_code, output_ds=Y)) 
          as curr
   set error_desc=coalesce ((select new.error_desc 
                                    from sarx_fincen_error_code as new 
                                    where curr.error_code=new.error_code
                             ),
                             curr.error_desc
                             )
  
   ;
   
%mend;
 

%rc_updt_sarx_error_code;

%rc_updt_fincen_inst_flag;
  
