/******************************************************************************/
/*                  S A S   S A M P L E   L I B R A R Y                       */
/*                                                                            */
/*    NAME: fcf_risk_class_list_extract.sas                                   */
/*   TITLE: fcf_risk_class_list_extract                                       */
/* PRODUCT: SAS Anti-Money Laundering                                         */
/*  SYSTEM: UNIX/WINDOWS                                                      */
/******************************************************************************/
/* ************************************************************************** */
/*  Copyright (c) 2015 by SAS Institute Inc., Cary, NC 27513 USA              */
/*  ---All Rights Reserved.                                                   */
/* ************************************************************************** */
/* USAGE EXAMPLES:
/* %fcf_risk_class_list_extract;
/*----------------------------------------------------------------------------*/
/* COMMENTS:
/*---------------------------------------------------------
 *  Host and Site specific customizations may be REQUIRED
 *---------------------------------------------------------*/
%macro fcf_risk_class_list_extract;

   /*----------------------------------------------------------------------------*/
   /* Set error code to 0 and message to blank
   /*----------------------------------------------------------------------------*/
    %let trans_rc = 0;
    %let _fcfmsg_=;

   /*--------------------------------------------------------------------------*/
   /* BEGIN RISK CLASSIFIER EXTRACT
   /*--------------------------------------------------------------------------*/

   /*--------------------------------------------------------------------------*/
   /*      Get risk classifiers by risk category 
   /*--------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..fsk_risk_classifier_category)) and 
        %sysfunc(exist(&seg_kc_libname..fsk_risk_classifier)) %then %do;
      proc sql noprint;
         create table fcf_rpt.risk_classifier_report_data %fcf_get_ds_opts(lib_name=fcf_rpt, ds_name=risk_classifier_report_data, output_ds=Y, add_parens=Y)  as 
         select
            cc.risk_classifier_category_name ,  
            cc.risk_classifier_category_desc ,
            rc.risk_classifier_name ,  
            rc.risk_classifier_short_desc ,
            rc.risk_classifier_desc ,
            rc.risk_classifier_type_code ,
            put(rc.risk_classifier_type_code,$classifier_type.) as type_desc  format=$50. ,
            rc.active_ind ,
            rc.weight ,
            rc.source_table ,  
            rc.source_column , 
            rc.source_value , 
            rc.classifier_fact_column,
            rc.operator_desc ,  
            rc.classifier_threshold , 
            datepart(rc.create_date)  as created FORMAT WORDDATE20.,
            rc.create_user_id ,   
            rc.version_number
         from  &seg_kc_libname..fsk_risk_classifier_category(%fcf_get_ds_opts(lib_name=&seg_kc_libname, ds_name=fsk_risk_classifier_category))  as cc ,
               &seg_kc_libname..fsk_risk_classifier(%fcf_get_ds_opts(lib_name=&seg_kc_libname, ds_name=fsk_risk_classifier)) as rc
         where cc.risk_classifier_category_id = rc.risk_classifier_category_id 
            and cc.logical_delete_ind = 'N'    
            and rc.logical_delete_ind = 'N'     
         order by cc.risk_classifier_category_name , cc.risk_classifier_category_desc ;
      quit;

      %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable create fcf_rpt.risk_classifier_report_data.;
           %fcf_put_error;
           %goto MACRO_END;
      %end;
    %end;
    %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: Required &seg_kc_libname..fsk_risk_classifier_category or &seg_kc_libname..fsk_risk_classifier table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* END RISK CLASSIFIER EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /* BEGIN LIST CATEGORY EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /*      Get list by list category  
   /*----------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..fsk_list_category)) and 
        %sysfunc(exist(&seg_kc_libname..fsk_list)) %then %do;
       proc sql noprint;
       create table fcf_rpt.list_report_data %fcf_get_ds_opts(lib_name=fcf_rpt, ds_name=list_report_data, output_ds=Y, add_parens=Y)  as 
       select lc.list_category_name ,  
              lc.list_category_desc ,
              rl.list_name ,  
              rl.list_desc ,  
              rl.validation_type_code , 
              datepart(rl.create_date) as created FORMAT WORDDATE20.,  
              rl.create_user_id 
         from  &seg_kc_libname..fsk_list_category(%fcf_get_ds_opts(lib_name=&seg_kc_libname, ds_name=fsk_list_category))  as lc ,
               &seg_kc_libname..fsk_list(%fcf_get_ds_opts(lib_name=&seg_kc_libname, ds_name=fsk_list)) as rl
         where lc.list_category_id = rl.list_category_id  
            and lc.logical_delete_ind = 'N'    
            and rl.logical_delete_ind = 'N'    
         order by lc.list_category_name, lc.list_category_desc, rl.list_name;
      quit;

      %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable create fcf_rpt.list_report_data.;
           %fcf_put_error;
           %goto MACRO_END;
      %end;
    %end;
    %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: Required &seg_kc_libname..fsk_list_category or &seg_kc_libname..fsk_list table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* END LIST CATEGORY EXTRACT 
   /*----------------------------------------------------------------------------*/

%MACRO_END:

%if &trans_rc in (3 5 900 909) %then
     %fcf_execute_macro(fcf_error);
%else %do;
     %fcf_execute_macro(fcf_success);
%end;

%mend fcf_risk_class_list_extract;
