/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    cdd_crr_process.sas
| PRODUCT: SAS Customer Due Diligence
| SYSTEM:  Windows Unix
| DESC:    Rank customer risk
+------------------------------------------------------------------------------+
| COMMENTS: INPUTS
|           testYN=      test flag. The content will be passed to CDD_ERROR and CDD_SUCESS macros.
|           test_obs=    number of observations should be included from the prep files
|                        to create the output table.
|                        It must be a valid number. If it is blank, all
|                        records will be used.
|           cdd_codegen_path= path where the generated CDD code can be found.
|           OUTPUT table:
|            cdd_scoring_event_all
| Called %cdd_crr_driver.
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro cdd_crr_process( testYN=
                        ,  test_obs=
                        , cdd_codegen_path=
                      );

   %if %str(&test_obs) ne %str() and %str(&test_obs) ne %str(0) %then %let obs_option=(%nrstr(obs=)&test_obs);
     %else %let obs_option=;

   %if %sysfunc(fileexist(&cdd_codegen_path/cdd_crr_process_code.sas)) %then %do;
          /* Define a sas table to save the return codes for each CRR execution step */
            data cdd_crr_process_step_log;
                 attrib label_name length=$32
                        label_desc length=$256
                      syserr     length=8
                      log_dttm   length=8 format=E8601DT24.2
                  ;
                  stop;
            run;
            /* call the CRR codes */
            %inc "&cdd_codegen_path/cdd_crr_process_code.sas";

      /* get the maximum return code */
      %let syserr_max=0;
        proc sql noprint;
             select max(syserr) into :syserr_max
           from cdd_crr_process_step_log
        ;
        quit;

       %if &syserr_max eq 3 or &syserr_max ge 5 %then %do;
             %fcf_rcset(&syserr_max);

               %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg
                                          ,CDD_CRR_PROCESS_CODE_ERROR
                                          ,NOQUOTE
                                          ,&sysmacroname
                                         ))  ;
             %fcf_put_error;
             %goto MACRO_END;
       %end;

   %end;
     %else %do;

         %fcf_rcset(5);
          %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg
                                          ,CDD_OBJECT_MISSING_ABORT
                                          ,NOQUOTE
                                          ,&sysmacroname
                                          ,"&cdd_codegen_path/cdd_crr_process_code.sas"))  ;
          %fcf_put_error;
          %goto MACRO_END;

    %end;


%MACRO_END:

      %if &trans_rc eq 3 or &trans_rc ge 5 %then
         %cdd_error(testYN=&testYN);
      %else
      %do;
         %cdd_success(testYN=&testYN);
      %end;


%mend;
