/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    cdd_prep.sas
| PRODUCT: SAS Customer Due Diligence
| SYSTEM:  Windows Unix
| DESC:    Build customer data files for CRR
+------------------------------------------------------------------------------+
| INPUTS:
|   cdd_prep_success_flg_mvar
|       name of macro variable to be used for returning the success flag.
|           1 for success and 0 for fail. 
|           This macro variable should be defined in the calling program 
|           The default name is cdd_prep_success_flg
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
 *       Host and Site specific customizations may be REQUIRED
 *-------------------------------------------------------------------*/

%macro cdd_prep(cdd_prep_success_flg_mvar=cdd_prep_success_flg);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

   %if %symexist(score_all_YN)=0 %then %do;
       %let _fcfmodule_=CDD_PREP;
       %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_MVAR_MISSING_ABORT,NOQUOTE
                              ,&sysmacroname,SCORE_ALL_YN))  ;
       %fcf_put_error;
       %goto MACRO_END;
   %end;

   %if %str(&cdd_run_asofdttm) = %str() or %str(&cdd_run_asofdttm) = %str(.)  %then %do;
       %let _fcfmodule_=CDD_PREP;
       %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_MVAR_MISSING_ABORT,NOQUOTE
                             ,&sysmacroname,CDD_RUN_ASOFDTTM))  ;
       %fcf_put_error;
       %goto MACRO_END;
   %end;

   %if %symexist(cdd_last_asofdttm)=0 %then %do;
       %let _fcfmodule_=CDD_PREP;
       %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_MVAR_MISSING_ABORT,NOQUOTE
                              ,&sysmacroname, CDD_LAST_ASOFDTTM))  ;
       %fcf_put_error;
       %goto MACRO_END;
   %end;

   %fcf_get_property_value(property=scoreExternalParties, output_property_value=score_ext_parties,
                           output_status=property_status
                          );

   %if &property_status ne 0 %then %do;
       %put WARNING: Unable to get property scoreExternalParties, excluding external parties from scoring;
       %let score_ext_parties=false;
   %end;



   /* Load FSC_LOOKUP_DIM data to sas formats */
   %cdd_section_header(Section=CDD_PREP_LOOKUP_FMT);

      %cdd_prep_lookup_fmt(lookup_level_1_type_code=CRR,datefmt=nldate10.);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmodule_=CDD_PREP_LOOKUP_FMT;
         %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_PGM_ABORT,NOQUOTE,cdd_prep_entit_list.sas))  ;
      %fcf_put_error;
         %goto MACRO_END;
      %end;

   %cdd_section_footer(Section=CDD_PREP_LOOKUP_FMT);

  

   %cdd_section_header(Section=CDD_PREP_ENTITY_LIST);

       %cdd_prep_entity_list(relationship_type_code_list='IDENTICAL'
                         ,stop_scoring_code_list="DEMARKET"
                         ,score_external_parties=&score_ext_parties
                         );

        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %let _fcfmodule_=CDD_PREP;
           %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_PGM_ABORT,NOQUOTE,cdd_prep_entit_list.sas))  ;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

      %cdd_section_footer(Section=CDD_PREP_ENTITY_LIST);

  

   %cdd_section_header(Section=CDD_PREP_COUNTRY_RISK);
    
      %cdd_prep_country_risk(relationship_type_code_list='BENE_OWNER' 'DIRECTOR' 'UBO' 'CNTR');

      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmodule_=CDD_CRR_PREP;
         %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_PGM_ABORT,NOQUOTE,cdd_prep_country_risk))  ;
         %fcf_put_error;
         %goto MACRO_END;
      %end;
   %cdd_section_footer(Section=CDD_PREP_COUNTRY_RISK);


   %cdd_section_header(Section=CDD_PREP_ENTITY_RISK);
 
      %cdd_prep_entity_risk(relationship_type_code_list='BENE_OWNER' 'DIRECTOR' 'UBO' 'CNTR');

      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmodule_=CDD_CRR_PREP;
         %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_PGM_ABORT,NOQUOTE,cdd_prep_entity_risk))  ;

         %fcf_put_error;
         %goto MACRO_END;
      %end;

   %cdd_section_footer(Section=CDD_PREP_ENTITY_RISK);

   %cdd_section_header(Section=CDD_PREP_PRODUCT_RISK);
 
      %cdd_prep_product_risk;

      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmodule_=CDD_CRR_PREP;
         %let _fcfmsg_=%sysfunc(sasmsg(sashelp.cddmsg,CDD_CRR_PGM_ABORT,NOQUOTE,cdd_prep_product_risk))  ;

         %fcf_put_error;
         %goto MACRO_END;
      %end;

   %cdd_section_footer(Section=CDD_PREP_PRODUCT_RISK);



    

   %MACRO_END:

      
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let &cdd_prep_success_flg_mvar=0;
      %end;
      %else %do;
         %let &cdd_prep_success_flg_mvar=1;
      %end;


%mend cdd_prep;
