/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_ent_load_entity_tx_agg.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Creates the table fsk_entity_tx_agg in Knowledge Center.  This
|          table contains sum of transactions and the transaction count for 
|          all entities with active alerts.  The counts are based on the 
|          fsk_entity_transaction table and grouped by both transaction_cdi_desc
|          and primary_medium_description.

+------------------------------------------------------------------------------+
| USAGE: %fcf_ent_load_entity_tx_agg 
+------------------------------------------------------------------------------+
| COMMENTS: INPUTS
|             None.
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016-2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_ent_load_entity_tx_agg;
    /*------------------------------------------
     * Set error code to 0 and message to blank
     *------------------------------------------*/

     %let trans_rc = 0;
     %let _fcfmsg_=;

    /* Create temporary tables for Entity transactions C/D/I and primary medium aggregates  */
    %put NOTE: FCF: Creating temporary tables for Entity transactions C/D/I and primary medium aggregates;
    proc sql noprint;
        create table ent_tx_agg_cdi_temp as select alerted_entity_level_code,
                                                   alerted_entity_number,
                                                   'CDI' as aggregate_type_code,
                                                   transaction_cdi_desc as group_code,
                                                   sum(transaction_amt) as aggregate_amt
                                          from seg_kc.fsk_alert_transaction  
                                          group by alerted_entity_level_code, alerted_entity_number, transaction_cdi_desc
                                          order by alerted_entity_level_code, alerted_entity_number, transaction_cdi_desc;
        create table ent_tx_agg_pri_temp as select alerted_entity_level_code,
                                                   alerted_entity_number,
                                                   'PRI' as aggregate_type_code,
                                                   primary_medium_desc as group_code,
                                                   sum(transaction_amt) as aggregate_amt
                                          from seg_kc.fsk_alert_transaction  
                                          group by alerted_entity_level_code, alerted_entity_number, primary_medium_desc
                                          order by alerted_entity_level_code, alerted_entity_number, primary_medium_desc;
    quit;

    %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: FCF: Error creating summary data from from seg_kc.fsk_entity_transaction table;
          %fcf_put_error;
          %goto MACRO_END;
      %end;


    /* Merge cust_tx_agg_pri_temp and cust_tx_agg_cdi_temp datasets */
    %put NOTE: FCF: Merging cust_tx_agg_pri_temp and cust_tx_agg_cdi_temp datasets;
    data ent_tx_agg_temp;
        if 1 eq 0 then set seg_kc.fsk_entity_tx_agg;
        fsk_entity_tx_agg_pk=_N_;
        set ent_tx_agg_pri_temp ent_tx_agg_cdi_temp;
        created_timestamp=&fcf_start_datetime;
        group_desc=group_code;
    run;

    %fcf_rcset(&syserr);
      %if &trans_rc. eq 3 or &trans_rc. ge 5 %then %do;
         %let _fcfmsg_=ERROR: FCF: Unable to merge work.cust_tx_agg_pri_temp2 and work.cust_tx_agg_cdi_temp2. ;
         %fcf_put_error;
         %goto MACRO_END;
      %end;

    /* Load the fsk_entity_tx_agg table */
    %put NOTE: FCF: Loading the fsk_entity_tx_agg table;
    proc append base=seg_kc.fsk_entity_tx_agg data=ent_tx_agg_temp;
    run;

    %fcf_rcset(&syserr);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: FCF: Unable to load work.ent_tx_agg_temp into seg_kc.fsk_entity_tx_agg table. ;
          %fcf_put_error;
          %goto MACRO_END;
      %end;

    /* Clean-up: Delete temporary entity transactions aggregate datasets */
    %put NOTE: FCF: Deleting temporary entity transactions aggregate datasets;
    proc datasets library=work nolist;
        delete ent_tx_agg_pri_temp;
        delete ent_tx_agg_cdi_temp;
        delete ent_tx_agg_temp;
    quit;

    %MACRO_END:

       %if &trans_rc eq 3 or &trans_rc ge 5 %then
          %fcf_execute_macro(fcf_error);
       %else %do;
          %fcf_execute_macro(fcf_success);
       %end;

%mend fcf_ent_load_entity_tx_agg;
