/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_attachments.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Purge attachments/files related to entities being purged
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_attachments(in_ds=attachments_to_delete_pty);
+------------------------------------------------------------------------------+
| COMMENTS: 
|   in_ds= Data set of attachments/files.
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_attachments(in_ds=);

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_ATTACHMENTS;

  /*-------------------------------------------
   * Call prefcf_purge_attachments stub macro.
   *-------------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /*-----------------------------------------------------------------------------
   * Delete files (referenced in the purged FSK_ATTACHMENT records for example).
   *-----------------------------------------------------------------------------*/
  data &in_ds;
   set &in_ds;
    length reason $4000;
    drop fname rc rc2 rc3;
    attachment_deleted = 'N';
    reason = '';
    fname = "delfile";
    rc = filename(fname, attachment_path);
    if rc eq 0 then
    do;
       if fexist(fname) then
       do;
          %if %upcase(&test_run) eq Y %then
          %do;
             rc2 = 0;
          %end;
          %else
          %if %upcase(&test_run) eq N %then
          %do;
             rc2 = fdelete(fname);
          %end;
          if rc2 eq 0 then
          do;
             attachment_deleted = 'Y';
             %if %upcase(&test_run) eq Y %then
             %do;
                putlog "NOTE: FCF: File " attachment_path "would have been deleted but this is a test run.";
             %end;
             %else
             %if %upcase(&test_run) eq N %then
             %do;
                putlog "NOTE: FCF: File " attachment_path "deleted.";
             %end;
          end;
          else 
          do;
             putlog "ERROR: FCF: Unable to delete file " attachment_path "reason " rc2;
             reason = "Unable to delete file, reason " || strip(put(rc2,best.));
          end;
       end;
       else
       do;
          putlog "NOTE: FCF: File " attachment_path "does not exist.";
          reason = "File does not exist";
       end;
       rc3 = filename(fname);
    end;
    else
    do;
       putlog "ERROR: FCF: Unable to make fileref pointing to " attachment_path;
       reason = "Unable to make fileref pointing to file, reason " || strip(put(rc, best.));
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error deleting files;
      %fcf_put_error;
      %goto MACRO_END;
  %end;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_attachments;

