/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_from_ds.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Purge from data sets such as mst_prep data sets
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_from_ds;
+------------------------------------------------------------------------------+
| COMMENTS: 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_from_ds;

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_FROM_DS;

  /*---------------------------------------
   * Call prefcf_purge_from_ds stub macro.
   *---------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /*-----------------------------
   * Delete from other data sets
   * for example mst_prep
   *-----------------------------*/
  %do i = 1 %to &sas_ds_count;

     %let sas_libname=;
     %let sas_ds_name=;
     %let entity_type=;
     %let key_type=;
     %let key_var_name=;
     %if &entity_level_code_var_exists eq 1 %then
     %do;
        %let entity_level_code_var_name=;
        %let entity_level_code_value=;
     %end;

     data _null_;
      set work.sas_ds_list;
       if _n_ eq &i then
       do;
          call symput('sas_libname',libname);
          call symput('sas_ds_name',ds_name);
          call symput('entity_type',entity_type);
          call symput('key_type',key_type);
          call symput('key_var_name',key_var_name);
          %if &entity_level_code_var_exists eq 1 %then
          %do;
             if entity_level_code_var_name ne '' then
             do;
                call symput('entity_level_code_var_name',entity_level_code_var_name);
                call symput('entity_level_code_value',entity_level_code_value);
             end;
          %end;
       end;
      run;

     %put NOTE: FCF: &=i;
     %put NOTE: FCF: &=sas_libname;
     %put NOTE: FCF: &=sas_ds_name;
     %put NOTE: FCF: &=entity_type;
     %put NOTE: FCF: &=key_type;
     %put NOTE: FCF: &=key_var_name;
     %if &entity_level_code_var_exists eq 1 %then
     %do;
        %put NOTE: FCF: &=entity_level_code_var_name;
        %put NOTE: FCF: &=entity_level_code_value;
     %end;

     %let key_ds=;
     %let rename_from=;

     /*-----------------------------------
      * Similar code in purge setup macro
      *-----------------------------------*/
     %if %upcase(&entity_type) eq ACCOUNT %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = acc_to_delete_num;
           %if %upcase(&key_var_name) ne ACCOUNT_NUMBER %then
           %do;
              %let rename_from = account_number;
           %end;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = acc_to_delete_key;
           %if %upcase(&key_var_name) ne ACCOUNT_KEY %then
           %do;
              %let rename_from = account_key;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq PARTY %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = pty_to_delete_num;
           %if %upcase(&key_var_name) ne PARTY_NUMBER %then
           %do;
              %let rename_from = party_number;
           %end;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = pty_to_delete_key;
           %if %upcase(&key_var_name) ne PARTY_KEY %then
           %do;
              %let rename_from = party_key;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq HOUSEHOLD %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = hhd_to_delete_num;
           %if %upcase(&key_var_name) ne HOUSEHOLD_NUMBER %then
           %do;
              %let rename_from = household_number;
           %end;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = hhd_to_delete_key;
           %if %upcase(&key_var_name) ne HOUSEHOLD_KEY %then
           %do;
              %let rename_from = household_key;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq ALERT %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = alt_to_delete;
           %if %upcase(&key_var_name) ne ALERT_ID %then
           %do;
              %let rename_from = alert_id;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq CDDREVIEW %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = cdr_to_delete;
           %if %upcase(&key_var_name) ne REVIEW_KEY %then
           %do;
              %let rename_from = review_key;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq RISK %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = ras_to_delete;
           %if %upcase(&key_var_name) ne RISK_ASSESSMENT_ID %then
           %do;
              %let rename_from = risk_assessment_id;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq RISK %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = ras_to_delete;
           %if %upcase(&key_var_name) ne RISK_ASSESSMENT_ID %then
           %do;
              %let rename_from = risk_assessment_id;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq CASE %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = cas_to_delete;
           %if %upcase(&key_var_name) ne CASE_ID %then
           %do;
              %let rename_from = case_id;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq EFILE %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = efl_to_delete;
           %if %upcase(&key_var_name) ne EFILE_KEY %then
           %do;
              %let rename_from = efile_key;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq REPORT %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = rpt_to_delete;
           %if %upcase(&key_var_name) ne REPORT_KEY %then
           %do;
              %let rename_from = report_key;
           %end;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq TRANSACTION %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = trn_to_delete_num;
           %if %upcase(&key_var_name) ne TRANSACTION_REFERENCE_NUMBER %then
           %do;
              %let rename_from = transaction_reference_number;
           %end;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = trn_to_delete_key;
           %if %upcase(&key_var_name) ne TRANSACTION_KEY %then
           %do;
              %let rename_from = transaction_key;
           %end;
        %end;
     %end;

     %put NOTE: FCF: &=key_ds;
     %put NOTE: FCF: &=rename_from;

     %if %length(&key_ds) eq 0 %then
     %do;
        %let _fcfmsg_=NOTE: FCF: Invalid combination of entity type &entity_type and key type &key_type..;
        %fcf_put_error;                  
        %goto NEXT_DS;
     %end;

     %put NOTE: FCF: Purging from data set &sas_libname..&sas_ds_name;

     data %if %upcase(&test_run) eq N %then
          %do;
             &sas_libname..&sas_ds_name(%fcf_get_ds_opts(lib_name=&sas_libname, ds_name=&sas_ds_name, output_ds=Y))
          %end;
          ds_rows_purged(keep=&key_var_name
                         %if &entity_level_code_var_exists eq 1 %then
                         %do;
                            %if %length(&entity_level_code_var_name) gt 0 %then
                            %do;
                               &entity_level_code_var_name
                            %end;
                         %end;
                        )
          ;
      set &sas_libname..&sas_ds_name(%fcf_get_ds_opts(lib_name=&sas_libname, ds_name=&sas_ds_name));
       drop rc;
       if _n_ eq 1 then
       do;
          declare hash hh (dataset:
                                   %if &rename_from ne  %then
                                   %do;
                                      "&key_ds(rename=(&rename_from=&key_var_name))"
                                   %end;
                                   %else
                                   %do;
                                      "&key_ds"
                                   %end;
                          );
                       hh.definekey ("&key_var_name");
                       hh.definedone();
       end;
       rc = hh.find();
       if rc eq 0
                  %if &entity_level_code_var_exists eq 1 %then
                  %do;
                     %if %length(&entity_level_code_var_name) gt 0 %then
                     %do;
                        and &entity_level_code_var_name eq "&entity_level_code_value"
                     %end;
                  %end;
                  then
       do;
          output ds_rows_purged;
          %if %upcase(&test_run) eq N %then
          %do;
             delete;
          %end;
       end;
       %if %upcase(&test_run) eq N %then
       %do;
          else
          do;
             output &sas_libname..&sas_ds_name;
          end;
       %end;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: FCF: Error deleting from data set &sas_libname..&sas_ds_name;
         %let trans_rc = 999999;
         %fcf_put_error;
         %goto MACRO_END;
     %end;

     proc sort data=ds_rows_purged;
       by &key_var_name;
      run;

     data ds_rows_purged;
      set ds_rows_purged;
       by &key_var_name;
       if first.&key_var_name then
          rec_purged = 0;
       rec_purged + 1;
       if last.&key_var_name then
          output;
      run;

     %fcf_purge_add_to_log_ds(in_ds=ds_rows_purged,
                              libname=&sas_libname,
                              table=&sas_ds_name,
                              rolled_up=Y,
                              key_1=&key_var_name,
                           %if %upcase(&key_type) eq NUMBER %then
                           %do; 
                              key_1_type=C
                           %end;
                           %else
                           %do; 
                              key_1_type=N
                           %end;
                           %if &entity_level_code_var_exists eq 1 %then
                           %do;
                              %if %length(&entity_level_code_var_name) gt 0 %then
                              %do;
                                 ,
                                 key_2=&entity_level_code_var_name,
                                 key_2_type=C
                              %end;
                           %end;
                             );

     %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %do;
         %goto MACRO_END;
     %end;

     %NEXT_DS:
  %end;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_from_ds;

