/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_get_eligible_ents.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Get eligible entities to purge
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_get_eligible_ents(in_ds=party_numbers_and_keys,
|                                     out_ds=eligible_parties,
|                                     entity_level_code=PTY); 
+------------------------------------------------------------------------------+
| COMMENTS: 
|   in_ds= input data set of entities we want to determine are eligible to
|      purge or not.
|   out_ds= output data set of eligible entities to purge.
|   entity_level_code= Entity level code of entities, PTY or ACC
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_get_eligible_ents(
                                   in_ds=,
                                   out_ds=,
                                   entity_level_code=
                                  );
  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_GET_ELIGIBLE_ENTS;

  /*-------------------------------------------------
   * Call prefcf_purge_get_eligible_ents stub macro.
   *-------------------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;


  %if &entity_level_code eq PTY %then
  %do;
     %let entity_number_column     = party_number; 
     %let entity_key_column        = party_key;
  %end;
  %else
  %if &entity_level_code eq ACC %then
  %do;
     %let entity_number_column     = account_number; 
     %let entity_key_column        = account_key;
  %end;

  data &entity_level_code._with_report_entity(keep=entity_number entity_level_code report_key entity_key
                                              rename=(entity_number=&entity_number_column));
    if 0 then set &db_lib_kc..fsk_rc_report_entity(keep=entity_level_code);
    set &in_ds(keep=&entity_number_column rename=(&entity_number_column=entity_number));
    entity_level_code = "&entity_level_code";
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_rc_report_entity(keep=entity_number entity_level_code report_key entity_key
                                            dbkey=(entity_number entity_level_code)
                                            /* no dbsastype needed here because entity_level_code is a varchar(32) */)
                                            key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
        do;
           _error_ = 0;
        end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error reading from &db_lib_kc..FSK_RC_REPORT_ENTITY;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=rc_report_entity_purged;
       by entity_key entity_level_code report_key;
      run;

     proc sort data=&entity_level_code._with_report_entity;
       by entity_key entity_level_code report_key;
      run;

     data &entity_level_code._with_report_entity(keep=&entity_number_column);
       merge &entity_level_code._with_report_entity(in=a) rc_report_entity_purged(in=b rename=(entity_number=&entity_number_column));
       by entity_key entity_level_code report_key;
       if a and not b;
      run;
  %end;

  proc sort data=&entity_level_code._with_report_entity nodupkey;
    by &entity_number_column;
   run;

  proc sort data=&in_ds;
    by &entity_number_column;
   run;

  data &out_ds;
    merge &in_ds(in=a) &entity_level_code._with_report_entity(in=b);
    by &entity_number_column;
    if a and not b;
   run;

  proc datasets lib=work nowarn nolist;
    delete &entity_level_code._with_report_entity;
  quit;

  data &entity_level_code._with_case_entity(keep=entity_number entity_level_code entity_key case_id
                                            rename=(entity_number=&entity_number_column));
    if 0 then set &db_lib_kc..fsk_case_entity(keep=entity_level_code);
    set &in_ds(keep=&entity_number_column rename=(&entity_number_column=entity_number));
    entity_level_code = "&entity_level_code";
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_case_entity(keep=entity_number entity_level_code entity_key case_id
                                       dbkey=(entity_number entity_level_code)
                                       dbsastype=(entity_level_code = 'char(3)'))
                                      key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
        do;
           _error_ = 0;
        end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error reading from &db_lib_kc..FSK_CASE_ENTITY;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=case_entity_purged;
       by entity_key entity_level_code case_id;
      run;

     proc sort data=&entity_level_code._with_case_entity;
       by entity_key entity_level_code case_id;
      run;

     data &entity_level_code._with_case_entity(keep=&entity_number_column);
       merge &entity_level_code._with_case_entity(in=a) case_entity_purged(in=b rename=(entity_number=&entity_number_column));
       by entity_key entity_level_code case_id;
       if a and not b;
      run;
  %end;

  proc sort data=&entity_level_code._with_case_entity nodupkey;
    by &entity_number_column;
   run;

  data &out_ds;
    merge &out_ds(in=a) &entity_level_code._with_case_entity(in=b);
    by &entity_number_column;
    if a and not b;
   run;

  proc datasets lib=work nowarn nolist;
    delete &entity_level_code._with_case_entity;
  quit;

  data &entity_level_code._with_case_entity_trx(keep=alerted_entity_number alerted_entity_level_code case_id transaction_id
                                                rename=(alerted_entity_number=&entity_number_column));
    if 0 then set &db_lib_kc..fsk_case_entity_transaction(keep=alerted_entity_level_code);
    set &in_ds(keep=&entity_number_column rename=(&entity_number_column=alerted_entity_number));
    alerted_entity_level_code = "&entity_level_code";
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_case_entity_transaction(keep=alerted_entity_number alerted_entity_level_code case_id transaction_id
                                                   dbkey=(alerted_entity_number alerted_entity_level_code)
                                                   dbsastype=(alerted_entity_level_code = 'char(3)'))
                                                  key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
        do;
           _error_ = 0;
        end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error reading from &db_lib_kc..FSK_CASE_ENTITY_TRANSACTION;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=case_entity_transaction_purged;
       by alerted_entity_number alerted_entity_level_code case_id transaction_id;
      run;

     proc sort data=&entity_level_code._with_case_entity_trx;
       by &entity_number_column alerted_entity_level_code case_id transaction_id;
      run;

     data &entity_level_code._with_case_entity_trx(keep=&entity_number_column);
       merge &entity_level_code._with_case_entity_trx(in=a) case_entity_transaction_purged(in=b rename=(alerted_entity_number=&entity_number_column));
       by &entity_number_column alerted_entity_level_code case_id transaction_id;
       if a and not b;
      run;
  %end;

  proc sort data=&entity_level_code._with_case_entity_trx nodupkey;
    by &entity_number_column;
   run;

  data &out_ds;
    merge &out_ds(in=a) &entity_level_code._with_case_entity_trx(in=b);
    by &entity_number_column;
    if a and not b;
   run;

  proc datasets lib=work nowarn nolist;
    delete &entity_level_code._with_case_entity_trx;
  quit;

  data &entity_level_code._with_case_trx(keep=alerted_entity_key case_id alert_id transaction_id
                                         rename=(alerted_entity_key=&entity_key_column));
    if 0 then set &db_lib_kc..fsk_case_transaction(keep=alerted_entity_level_code);
    set &in_ds(keep=&entity_key_column rename=(&entity_key_column=alerted_entity_key));
    alerted_entity_level_code = "&entity_level_code";
    do until (_iorc_ ne %sysrc(_sok));
       set &db_lib_kc..fsk_case_transaction(keep=alerted_entity_key alerted_entity_level_code case_id alert_id transaction_id
                                            dbkey=(alerted_entity_key alerted_entity_level_code)
                                            dbsastype=(alerted_entity_level_code = 'char(3)'))
                                           key=dbkey;
        if _iorc_ = %sysrc(_sok) then
           output;
        else
        do;
           _error_ = 0;
        end;
    end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Error reading from &db_lib_kc..FSK_CASE_TRANSACTION;
      %fcf_put_error;
      %goto MACRO_END;
  %end;

  %if %upcase(&test_run) eq Y %then
  %do;
     proc sort data=case_transaction_purged;
       by case_id alert_id transaction_id;
      run;

     proc sort data=&entity_level_code._with_case_trx;
       by case_id alert_id transaction_id;
      run;

     data &entity_level_code._with_case_trx(keep=&entity_key_column);
       merge &entity_level_code._with_case_trx(in=a) case_transaction_purged(in=b rename=(alerted_entity_key=&entity_key_column));
       by case_id alert_id transaction_id;
       if a and not b;
      run;
  %end;

  proc sort data=&entity_level_code._with_case_trx nodupkey;
    by &entity_key_column;
   run;

  proc sort data=&out_ds;
    by &entity_key_column;
   run;

  data &out_ds;
    merge &out_ds(in=a) &entity_level_code._with_case_trx(in=b);
    by &entity_key_column;
    if a and not b;
   run;

  proc datasets lib=work nowarn nolist;
    delete &entity_level_code._with_case_trx;
  quit;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_get_eligible_ents;

