/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_purge_setup.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Setup, error checking, etc. before purge job starts purging.
+------------------------------------------------------------------------------+
| USAGE: %fcf_purge_setup;
+------------------------------------------------------------------------------+
| COMMENTS: 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2019 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_purge_setup;

  /*------------
   * Set Module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=FCF_PURGE_SETUP;

  /*-------------------------------------
   * Call prefcf_purge_setup stub macro.
   *-------------------------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*-------------------------------------------
   * Set error code to 0 and message to blank.
   *-------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  %global dbmax_text_option
          db_lib_core_assigned_by_main
          db_lib_kc_assigned_by_main
          purgekey_lib_assigned
          caseStatusClosed
          sas_ds_count
          entity_level_code_var_exists
          ui_availability_set_by_this_job
          ;

  %let db_lib_core_assigned_by_main = 0;
  %let db_lib_kc_assigned_by_main = 0;

  %let ui_availability_set_by_this_job = N;

  /*---------------------------------------------------
   * Verify certain macro parameters are set to Y or N
   *---------------------------------------------------*/
  %if %upcase(&test_run) ne Y and
      %upcase(&test_run) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter test_run is &test_run but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter test_run is set to &test_run;

  %if %upcase(&save_keys) ne Y and
      %upcase(&save_keys) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter save_keys is &save_keys but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter save_keys is set to &save_keys;

  %if %upcase(&purge_from_database) ne Y and
      %upcase(&purge_from_database) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter purge_from_database is &purge_from_database but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter purge_from_database is set to &purge_from_database;

  %if %upcase(&purge_from_data_sets) ne Y and
      %upcase(&purge_from_data_sets) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter purge_from_data_sets is &purge_from_data_sets but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter purge_from_data_sets is set to &purge_from_data_sets;

  %if %upcase(&purge_from_solr) ne Y and
      %upcase(&purge_from_solr) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter purge_from_solr is &purge_from_solr but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter purge_from_solr is set to &purge_from_solr;

  %if %upcase(&purge_restart) ne Y and
      %upcase(&purge_restart) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter purge_restart is &purge_restart but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter purge_restart is set to &purge_restart;

  %if %upcase(&disable_ui) ne Y and
      %upcase(&disable_ui) ne N %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter disable_ui is &disable_ui but must be Y or N.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %put NOTE: FCF: Parameter disable_ui is set to &disable_ui;


  %put NOTE: FCF: Parameter db_lib_core is set to &db_lib_core;
  %put NOTE: FCF: Parameter db_lib_kc is set to &db_lib_kc;
  %put NOTE: FCF: Parameter file_of_parties_to_purge is set to &file_of_parties_to_purge;
  %put NOTE: FCF: Parameter file_of_data_sets_to_purge_from is set to &file_of_data_sets_to_purge_from;
  %put NOTE: FCF: Parameter purge_log_data_set_name is set to &purge_log_data_set_name;
  %put NOTE: FCF: Parameter efile_status_closed is set to &efile_status_closed;
  %put NOTE: FCF: Parameter report_status_closed is set to &report_status_closed;
  %put NOTE: FCF: Parameter case_status_closed is set to &case_status_closed;
  %put NOTE: FCF: Parameter purge_log_dir is set to &purge_log_dir;
  %put NOTE: FCF: Parameter purge_key_dir is set to &purge_key_dir;
  %put NOTE: FCF: Parameter cert_file is set to &cert_file;
  %put NOTE: FCF: Parameter curl_command is set to &curl_command;

  /*------------------------------------------------------------------------------------
   * Remove the following data step if we can %global dbmax_text_option in fcf_autoexec
   *------------------------------------------------------------------------------------*/
  data _null_;
    if upcase(symgetc('dbflavor'))='TERADATA' then
       call symput('dbmax_text_option','');
    else
       call symput('dbmax_text_option','dbmax_text=32767');
   run;

  /*--------------------------------------------
   * Assign libraries which allow direct access
   *--------------------------------------------*/
  %if %length(&db_lib_core) le 0 %then
  %do;
     libname db_core2 &dbflavor authdomain="&coreAuthDomain." &coreDBConnOpts &coreDBLibOpts &dbmax_text_option
                      %if %upcase(&dbflavor) eq ORACLE %then
                      update_lock_type=row read_lock_type=NOLOCK reread_exposure=YES utilconn_transient=yes;
                      %else
                      %if %upcase(&dbflavor) eq DB2 %then
                      direct_exe=DELETE connection=sharedread read_lock_type=ROW read_isolation_level=UR update_lock_type=ROW update_isolation_level=CS reread_exposure=YES utilconn_transient=yes;
                      ;

     %if (%sysfunc(libref(db_core2))) %then
     %do;
        %put %sysfunc(sysmsg());
        %let _fcfmsg_=ERROR: FCF: Cannot assign db_core2 library.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     %let db_lib_core_assigned_by_main = 1;

     %let db_lib_core = db_core2;
  %end;

  %if %length(&db_lib_kc) le 0 %then
  %do;
     libname db_kc2 &dbflavor authdomain="&kcAuthDomain." &kcDBConnOpts &kcDBLibOpts &dbmax_text_option
                    %if %upcase(&dbflavor) eq ORACLE %then
                    update_lock_type=row read_lock_type=NOLOCK reread_exposure=YES utilconn_transient=yes;
                    %else
                    %if %upcase(&dbflavor) eq DB2 %then
                    direct_exe=DELETE connection=sharedread read_lock_type=ROW read_isolation_level=UR update_lock_type=ROW update_isolation_level=CS reread_exposure=YES utilconn_transient=yes;
                    ;

     %if (%sysfunc(libref(db_kc2))) %then
     %do;
        %put %sysfunc(sysmsg());
        %let _fcfmsg_=ERROR: FCF: Cannot assign db_kc2 library.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     %let db_lib_kc_assigned_by_main = 1;

     %let db_lib_kc = db_kc2;
  %end;

  /*-----------------------------------------------------------
   * Verify the file referenced in the parameter purge_key_dir
   * looks okay before proceeding.
   *-----------------------------------------------------------*/
  %let purgekey_lib_assigned = 0;

  %if %upcase(&save_keys) eq Y %then
  %do;
     %if %length(&purge_key_dir) gt 0 %then
     %do;
        filename keysdir "&purge_key_dir";

        %if not %sysfunc(fexist(keysdir)) %then
        %do;
           %let _fcfmsg_=ERROR: FCF: Directory referenced in parameter purge_key_dir does not exist.;
           %let trans_rc = 999999;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        filename keysdir;

        libname purgekey "&purge_key_dir";

        %if %sysfunc(libref(purgekey)) ne 0 %then
        %do;
           %let _fcfmsg_=ERROR: FCF: Unable to assign the purgekey library &purge_key_dir.;
           %let trans_rc = 999999;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        %let purgekey_lib_assigned = 1;

        /* put to the log the data sets in the purgekey library */
        data purgekey_datasets(keep=memtype memname);
         set sashelp.vtable;
          where libname="PURGEKEY" and memtype="DATA";
          putlog "NOTE: FCF: " memtype= memname= crdate= modate= nobs= nvar=;
         run;
     %end;
     %else
     %do;
        /*---------------------------------------------
         * Get the AML purge keys directory preference
         *---------------------------------------------*/
        %fcf_get_property_value(property=amlPurgeKeyDirectory,
                                output_property_value=amlPurgeKeyDirectory,
                                output_status=purge_key_dir_status);

        %if &purge_key_dir_status ne 0 %then
        %do;
           %let _fcfmsg_=ERROR: FCF: The amlPurgeKeyDirectory preference is not set.;
           %let trans_rc = 999999;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        filename prgkydir "&amlPurgeKeyDirectory";

        %if not %sysfunc(fexist(prgkydir)) %then
        %do;
           %let _fcfmsg_=ERROR: FCF: Directory referenced in property amlPurgeKeyDirectory does not exist.;
           %let trans_rc = 999999;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        filename prgkydir;

        libname purgekey "&amlPurgeKeyDirectory";

        %if %sysfunc(libref(purgekey)) ne 0 %then
        %do;
           %let _fcfmsg_=ERROR: FCF: Unable to assign the amlPurgeKeyDirectory library &amlPurgeKeyDirectory.;
           %let trans_rc = 999999;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        %let purgekey_lib_assigned = 1;

        /* put to the log the data sets in the purgekey library */
        data purgekey_datasets(keep=memtype memname);
         set sashelp.vtable;
          where libname="PURGEKEY" and memtype="DATA";
          putlog "NOTE: FCF: " memtype= memname= crdate= modate= nobs= nvar=;
         run;
     %end;
  %end;

  %if %upcase(&purge_restart) eq Y %then
  %do;
     %if &purgekey_lib_assigned eq 0 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Parameter purge_restart is set to &purge_restart but the &purge_key_dir library is not assigned;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;

  /*-----------------------------------------------------------------------------
   * Verify the file referenced in the parameter file_of_data_sets_to_purge_from
   * looks okay before proceeding, if necessary.
   *-----------------------------------------------------------------------------*/
  %if %upcase(&purge_from_data_sets) eq N %then
  %do;
     %goto END_PRE_PURGE_FROM_DATA_SETS;
  %end;

  %BEGIN_PRE_PURGE_FROM_DATA_SETS:

  %if %length(&file_of_data_sets_to_purge_from) eq 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: Parameter file_of_data_sets_to_purge_from cannot be blank.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  filename sasdslst "&file_of_data_sets_to_purge_from";

  %if not %sysfunc(fexist(sasdslst)) %then
  %do;
     %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not exist.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  proc import out=sas_ds_list
              datafile=sasdslst
              dbms=csv replace;
       getnames=yes;
       datarow=2;
       guessingrows=9999;
   run;

  proc contents data=sas_ds_list noprint
                 out=_keepvars(keep=name);
   run;

  proc sql noprint;
    select upcase(name) into :sas_ds_list_vars separated by ' '
      from _keepvars;
  quit;

  %put NOTE: FCF: &=sas_ds_list_vars;

  proc datasets lib=work nowarn nolist;
    delete _keepvars
           ;
  quit;

  %let var_position = %sysfunc(findw(&sas_ds_list_vars, LIBNAME));
  %if &var_position eq 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not have the LIBNAME column.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %let var_position = %sysfunc(findw(&sas_ds_list_vars, DS_NAME));
  %if &var_position eq 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not have the DS_NAME column.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %let var_position = %sysfunc(findw(&sas_ds_list_vars, ENTITY_TYPE));
  %if &var_position eq 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not have the ENTITY_TYPE column.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %let var_position = %sysfunc(findw(&sas_ds_list_vars, KEY_VAR_NAME));
  %if &var_position eq 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not have the KEY_VAR_NAME column.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %let var_position = %sysfunc(findw(&sas_ds_list_vars, KEY_TYPE));
  %if &var_position eq 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not have the KEY_TYPE column.;
     %let trans_rc = 999999;
     %fcf_put_error;
     %goto MACRO_END;
  %end;

  %let entity_level_code_var_exists = 0;

  %let var_position = %sysfunc(findw(&sas_ds_list_vars, ENTITY_LEVEL_CODE_VAR_NAME));
  %if &var_position ne 0 %then
  %do;
     %let entity_level_code_var_exists = 1;

     %let var_position = %sysfunc(findw(&sas_ds_list_vars, ENTITY_LEVEL_CODE_VALUE));
     %if &var_position eq 0 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: File referenced in parameter file_of_data_sets_to_purge_from does not have the ENTITY_LEVEL_CODE_VALUE column.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;

  %let sas_ds_count = 0;

  data _null_;
    if 0 then set work.sas_ds_list nobs=nobs;
    call symputx('sas_ds_count',nobs);
    stop;
   run;
    
  %if &sas_ds_count = 0 %then
  %do;
     %let _fcfmsg_=ERROR: FCF: No data sets to purge from were specified in the file referenced in parameter file_of_data_sets_to_purge_from.;
     %let trans_rc = 999999;
     %fcf_put_error;                  
     %goto MACRO_END;
  %end;

  /* put to the log the data sets in the sas_ds_list data set, and remove any obs caused by blank lines */
  data sas_ds_list;
   set sas_ds_list;
    if _n_ eq 1 then
       putlog "NOTE: FCF: Number of data sets in file_of_data_sets_to_purge_from is &sas_ds_count";
    putlog "NOTE: FCF: " libname= ds_name= entity_type= key_type= key_var_name=
                         %if &entity_level_code_var_exists eq 1 %then
                         %do;
                            entity_level_code_var_name= entity_level_code_value=;
                         %end;
                         ;
    if missing(ds_name) then
       putlog "NOTE: FCF: Ignoring line with blank data set name.";
    else
       output;
   run;

  /* in case any were removed, count again */
  %let sas_ds_count = 0;

  data _null_;
    if 0 then set work.sas_ds_list nobs=nobs;
    call symputx('sas_ds_count',nobs);
    stop;
   run;

  %put NOTE: FCF: &=sas_ds_count;

  %do i = 1 %to &sas_ds_count;
     %let sas_libname=;
     %let sas_ds_name=;
     %let entity_type=;
     %let key_type=;
     %let key_var_name=;
     %if &entity_level_code_var_exists eq 1 %then
     %do;
        %let entity_level_code_var_name=;
        %let entity_level_code_value=;
     %end;

     data _null_;
      set work.sas_ds_list;
       if _n_ eq &i then
       do;
          call symput('sas_libname',libname);
          call symput('sas_ds_name',ds_name);
          call symput('entity_type',entity_type);
          call symput('key_type',key_type);
          call symput('key_var_name',key_var_name);
          %if &entity_level_code_var_exists eq 1 %then
          %do;
             if entity_level_code_var_name ne '' then
             do;
                call symput('entity_level_code_var_name',entity_level_code_var_name);
                call symput('entity_level_code_value',entity_level_code_value);
             end;
          %end;
       end;
      run;

     %if &entity_level_code_var_exists eq 1 %then
     %do;
        %put NOTE: FCF: Checking &i &=sas_libname &=sas_ds_name &=entity_type &=key_type &=key_var_name &=entity_level_code_var_name &=entity_level_code_value;
     %end;
     %else
     %do;
        %put NOTE: FCF: Checking &i &=sas_libname &=sas_ds_name &=entity_type &=key_type &=key_var_name;
     %end;

     %if not %sysfunc(exist(&sas_libname..&sas_ds_name.)) %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Data set &sas_libname..&sas_ds_name. does not exist.;
        %let trans_rc = 999999;
        %fcf_put_error;                  
        %goto MACRO_END;
     %end;

     %if %upcase(&entity_type) ne ACCOUNT and
         %upcase(&entity_type) ne PARTY and
         %upcase(&entity_type) ne HOUSEHOLD and
         %upcase(&entity_type) ne ALERT and
         %upcase(&entity_type) ne CDDREVIEW and
         %upcase(&entity_type) ne RISK and
         %upcase(&entity_type) ne CASE and
         %upcase(&entity_type) ne EFILE and
         %upcase(&entity_type) ne REPORT and
         %upcase(&entity_type) ne TRANSACTION %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Invalid entity type &entity_type for data set &sas_libname..&sas_ds_name..;
        %let trans_rc = 999999;
        %fcf_put_error;                  
        %goto MACRO_END;
     %end;

     %if %upcase(&key_type) ne NUMBER and
         %upcase(&key_type) ne KEY %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Key type must be NUMBER or KEY for data set &sas_libname..&sas_ds_name..;
        %let trans_rc = 999999;
        %fcf_put_error;                  
        %goto MACRO_END;
     %end;

     %let key_ds=;

     /*-------------------------------------------
      * Similar code in purge from data set macro
      *-------------------------------------------*/
     %if %upcase(&entity_type) eq ACCOUNT %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = acc_to_delete_num;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = acc_to_delete_key;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq PARTY %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = pty_to_delete_num;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = pty_to_delete_key;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq HOUSEHOLD %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = hhd_to_delete_num;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = hhd_to_delete_key;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq ALERT %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = alt_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq CDDREVIEW %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = cdr_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq RISK %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = ras_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq RISK %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = ras_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq CASE %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = cas_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq EFILE %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = efl_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq REPORT %then
     %do;
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = rpt_to_delete;
        %end;
     %end;
     %else
     %if %upcase(&entity_type) eq TRANSACTION %then
     %do;
        %if %upcase(&key_type) eq NUMBER %then
        %do;
           %let key_ds = trn_to_delete_num;
        %end;
        %else
        %if %upcase(&key_type) eq KEY %then
        %do;
           %let key_ds = trn_to_delete_key;
        %end;
     %end;

     %if %length(&key_ds) eq 0 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Invalid combination of entity type &entity_type and key type &key_type..;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     /*--------------------------------------------------------
      * Verify the data set has the columns specified for that
      * data set in the file of data sets to delete from.
      *--------------------------------------------------------*/
     proc contents data=&sas_libname..&sas_ds_name(%fcf_get_ds_opts(lib_name=&sas_libname, ds_name=&sas_ds_name)) noprint
                    out=_keepvars2(keep=name);
      run;

     proc sql noprint;
       select count(*) into :key_var_count
         from _keepvars2
        where upcase(name) = "%upcase(&key_var_name)";
     quit;

     %if &key_var_count ne 1 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Data set &sas_libname..&sas_ds_name. does not have the variable &key_var_name..;
        %let trans_rc = 999999;
        %fcf_put_error;                  
        %goto MACRO_END;
     %end;

     %if &entity_level_code_var_exists eq 1 %then
     %do;
        %if %length(&entity_level_code_var_name) gt 0 %then
        %do;
           proc sql noprint;
             select count(*) into :key_var_count
               from _keepvars2
              where upcase(name) = "%upcase(&entity_level_code_var_name)";
           quit;

           %if &key_var_count ne 1 %then
           %do;
              %let _fcfmsg_=ERROR: FCF: Data set &sas_libname..&sas_ds_name. does not have the variable &entity_level_code_var_name..;
              %let trans_rc = 999999;
              %fcf_put_error;                  
              %goto MACRO_END;
           %end;
        %end;
     %end;
  %end;

  proc datasets lib=work nowarn nolist;
    delete _keepvars2
           ;
  quit;

  %END_PRE_PURGE_FROM_DATA_SETS:

  /*-----------------------------------------------------------------------------
   * Verify the file referenced in the parameter file_of_parties_to_purge
   * looks okay before proceeding.
   *-----------------------------------------------------------------------------*/
  %if %length(&file_of_parties_to_purge) gt 0 %then
  %do;
     /*-----------------------------------------------------
      * Read the file of party numbers passed to this macro
      *-----------------------------------------------------*/
     filename parties "&file_of_parties_to_purge";

     %if not %sysfunc(fexist(parties)) %then
     %do;
        %let _fcfmsg_=ERROR: FCF: File &file_of_parties_to_purge does not exist;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     %let header_specified = 0;

     data parties_to_purge;
       if 0 then set &db_lib_core..fsc_party_dim(keep=party_number);
       retain record_number 0;
       infile parties;
       input party_number;
       record_number + 1;
       if record_number eq 1 and upcase(party_number) eq 'PARTY_NUMBER' then
          call symput('header_specified','1');
       if record_number gt 1;
      run;

     %fcf_rcset(&syserr);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to read file &file_of_parties_to_purge;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     %put NOTE: FCF: &=header_specified;

     %if &header_specified eq 0 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: The first line in file &file_of_parties_to_purge must be the word: party_number;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;
  %else
  %do;
     /*---------------------------------------------------------------------------------
      * A file of party numbers wasn't provided so we'll check FSC_PARTY_DIM.purge_date
      * and, for any that aren't NULL and which are less than or equal to today, we'll
      * consider those parties as eligible to purge.
      *---------------------------------------------------------------------------------*/
     data parties_to_purge(keep=party_number);
      set &db_lib_core..fsc_party_dim(keep=party_number purge_date change_current_ind);
       if purge_date ne . and change_current_ind eq 'Y';
       if datepart(purge_date) le today();
      run;
  %end;

  /*-------------------------------------------------------------
   * Verify the purge log directory looks okay before proceeding
   *-------------------------------------------------------------*/
  %if %length(&purge_log_dir) eq 0 %then
  %do;
     /*--------------------------------------------
      * Get the AML purge log directory preference
      *--------------------------------------------*/
     %fcf_get_property_value(property=amlPurgeLogDirectory,
                             output_property_value=amlPurgeLogDirectory,
                             output_status=purge_log_dir_status);

     %if &purge_log_dir_status ne 0 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: The amlPurgeLogDirectory preference is not set.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     filename prglgdir "&amlPurgeLogDirectory";

     %if not %sysfunc(fexist(prglgdir)) %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Directory referenced in property amlPurgeLogDirectory does not exist.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     filename prglgdir;

     libname purgelog "&amlPurgeLogDirectory";

     %if %sysfunc(libref(purgelog)) ne 0 %then
     %do;
        %let _fcfmsg_=ERROR: Unable to assign the amlPurgeLogDirectory library &amlPurgeLogDirectory.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     %let purge_log_dir = &amlPurgeLogDirectory;
  %end;
  %else
  %do;
     filename prglgdir "&purge_log_dir";

     %if not %sysfunc(fexist(prglgdir)) %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Directory referenced in parameter purge_log_dir does not exist.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     filename prglgdir;

     libname purgelog "&purge_log_dir";

     %if %sysfunc(libref(purgelog)) ne 0 %then
     %do;
        %let _fcfmsg_=ERROR: Unable to assign the purge log directory library &purge_log_dir.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;

  /*--------------------------------------------------------------
   * Verify purge log data set name looks okay before proceeding.
   *--------------------------------------------------------------*/
  %if &purge_log_data_set_name eq  %then
  %do;
     %let flndate = %sysfunc(date(),yymmddn8.);  
     %let flnhour   = %sysfunc(putn(%sysfunc(hour(%sysfunc(time()))),z2.));
     %let flnminute = %sysfunc(putn(%sysfunc(minute(%sysfunc(time()))),z2.));
     %let flnsecond = %sysfunc(putn(%sysfunc(int(%sysfunc(second(%sysfunc(time()))))),z2.));
     %let purge_log_data_set_name = AML_purge_log_&flndate._&flnhour.&flnminute.&flnsecond;
  %end;
  %else
  %do;
     %if %length(&purge_log_data_set_name) > 32 %then
     %do;
        %let _fcfmsg_=ERROR: Length of purge_log_data_set_name parameter must be less than or equal to 32 characters.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
     %if %substr(%sysfunc(reverse(&purge_log_data_set_name)),1,9) eq tadb7sas. %then
     %do;
        %let _fcfmsg_=ERROR: purge_log_data_set_name parameter must not include the SAS data set file extention .sas7bdat;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;

  /*-------------------------------------------------
   * Get the retention days preference for EFiles.
   * If the preference doesn't exist then create it.
   *-------------------------------------------------*/
  %fcf_get_property_value(property=amlEFileRetentionDays,
                          output_property_value=amlEFileRetentionDays,
                          output_status=efile_ret_days_status);

  %if &efile_ret_days_status ne 0 %then
  %do;
    %let amlEFileRetentionDays = 1826;

    proc sql noprint;
      insert into &db_lib_kc..fsk_preference (pref_name, pref_value, pref_type, pref_value_default)
                                      values ('amlEFileRetentionDays', '1826', 'integer', '1826');
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to insert preference amlEFileRetentionDays into FSK_PREFERENCE.;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
  %end;

  /*-------------------------------------------------
   * Get the retention days preference for Reports.
   * If the preference doesn't exist then create it.
   *-------------------------------------------------*/
  %fcf_get_property_value(property=amlReportRetentionDays,
                          output_property_value=amlReportRetentionDays,
                          output_status=report_ret_days_status);

  %if &report_ret_days_status ne 0 %then
  %do;
    %let amlReportRetentionDays = 1826;

    proc sql noprint;
      insert into &db_lib_kc..fsk_preference (pref_name, pref_value, pref_type, pref_value_default)
                                      values ('amlReportRetentionDays', '1826', 'integer', '1826');
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to insert preference amlReportRetentionDays into FSK_PREFERENCE.;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
  %end;

  /*-------------------------------------------------
   * Get the retention days preference for Cases.
   * If the preference doesn't exist then create it.
   *-------------------------------------------------*/
  %fcf_get_property_value(property=amlCaseRetentionDays,
                          output_property_value=amlCaseRetentionDays,
                          output_status=case_ret_days_status);

  %if &case_ret_days_status ne 0 %then
  %do;
    %let amlCaseRetentionDays = 1826;

    proc sql noprint;
      insert into &db_lib_kc..fsk_preference (pref_name, pref_value, pref_type, pref_value_default)
                                      values ('amlCaseRetentionDays', '1826', 'integer', '1826');
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: Unable to insert preference amlCaseRetentionDays into FSK_PREFERENCE.;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
  %end;

  /*------------------------------------------------
   * Get the caseStatusClosed preference for Cases.
   *------------------------------------------------*/
  %if %length(&case_status_closed) gt 0 %then
  %do;
     %let caseStatusClosed = &case_status_closed;
  %end;
  %else
  %do;
     %fcf_get_property_value(property=caseStatusClosed,
                             output_property_value=caseStatusClosed,
                             output_status=case_status_closed_status);

     %if &case_status_closed_status ne 0 %then
     %do;
        %let _fcfmsg_=ERROR: FCF: The caseStatusClosed preference is not set.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;

  /*-------------------------------------------------------------------------
   * We must import keys on a restart if we're not purging from the database
   *-------------------------------------------------------------------------*/
  %if %upcase(&purge_restart) eq Y %then
  %do;
     %if %upcase(&purge_from_database) eq N %then
     %do;
        %let sas_key_ds_count = 0;

        data _null_;
          if 0 then set work.purgekey_datasets nobs=nobs;
          call symputx('sas_key_ds_count',nobs);
          stop;
         run;

        %if &sas_key_ds_count = 0 %then
        %do;
           %let _fcfmsg_=ERROR: FCF: purge_restart is set to &purge_restart but there are no key data sets in the purgekey library.;
           %let trans_rc = 999999;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        %if %upcase(&purge_from_data_sets) eq Y %then
        %do;
           data pty_to_delete_key;
            set purgekey.pty_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_key));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.pty_to_delete_key;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data acc_to_delete_key;
            set purgekey.acc_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_key));

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.acc_to_delete_key;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data hhd_to_delete_key;
            set purgekey.hhd_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_key));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.hhd_to_delete_key;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data efl_to_delete;
            set purgekey.efl_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=efl_to_delete));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.efl_to_delete;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data trn_to_delete_key;
            set purgekey.trn_to_delete_key(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_key));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.trn_to_delete_key;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data trn_to_delete_num;
            set purgekey.trn_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=trn_to_delete_num));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.trn_to_delete_num;
              %fcf_put_error;
              %goto MACRO_END;
           %end;
        %end;

        data pty_to_delete_num;
         set purgekey.pty_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=pty_to_delete_num));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.pty_to_delete_num;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data acc_to_delete_num;
         set purgekey.acc_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=acc_to_delete_num));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.acc_to_delete_num;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data hhd_to_delete_num;
         set purgekey.hhd_to_delete_num(%fcf_get_ds_opts(lib_name=purgekey, ds_name=hhd_to_delete_num));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.hhd_to_delete_num;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data cas_to_delete;
         set purgekey.cas_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=cas_to_delete));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.cas_to_delete;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data alt_to_delete;
         set purgekey.alt_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=alt_to_delete));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.alt_to_delete;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data rpt_to_delete;
         set purgekey.rpt_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=rpt_to_delete));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.rpt_to_delete;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data cdr_to_delete;
         set purgekey.cdr_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=cdr_to_delete));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.cdr_to_delete;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        data ras_to_delete;
         set purgekey.ras_to_delete(%fcf_get_ds_opts(lib_name=purgekey, ds_name=ras_to_delete));
         run;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.ras_to_delete;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

        %if %upcase(&purge_from_solr) eq Y %then
        %do;
           data comments_to_delete_pty;
            set purgekey.comments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_pty));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_pty;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_acc;
            set purgekey.comments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_acc));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_acc;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_hhd;
            set purgekey.comments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_hhd));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_hhd;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_cas;
            set purgekey.comments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_cas));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_cas;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_rpt;
            set purgekey.comments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_rpt));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_rpt;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_efl;
            set purgekey.comments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_efl));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_efl;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_cdr;
            set purgekey.comments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_cdr));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_cdr;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_alt;
            set purgekey.comments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_alt));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_alt;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_trn;
            set purgekey.comments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_trn));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_trn;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data comments_to_delete_ras;
            set purgekey.comments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=comments_to_delete_ras));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.comments_to_delete_ras;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_pty;
            set purgekey.attachments_to_delete_pty(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_pty));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_pty;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_acc;
            set purgekey.attachments_to_delete_acc(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_acc));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_acc;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_hhd;
            set purgekey.attachments_to_delete_hhd(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_hhd));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_hhd;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_cas;
            set purgekey.attachments_to_delete_cas(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cas));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_cas;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_rpt;
            set purgekey.attachments_to_delete_rpt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_rpt));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_rpt;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_efl;
            set purgekey.attachments_to_delete_efl(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_efl));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_efl;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_cdr;
            set purgekey.attachments_to_delete_cdr(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_cdr));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_cdr;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_alt;
            set purgekey.attachments_to_delete_alt(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_alt));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_alt;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_trn;
            set purgekey.attachments_to_delete_trn(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_trn));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_trn;
              %fcf_put_error;
              %goto MACRO_END;
           %end;

           data attachments_to_delete_ras;
            set purgekey.attachments_to_delete_ras(%fcf_get_ds_opts(lib_name=purgekey, ds_name=attachments_to_delete_ras));
            run;

           %fcf_rcset(&syserr);
           %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
              %let _fcfmsg_=ERROR: FCF: Unable to read key data set purgekey.attachments_to_delete_ras;
              %fcf_put_error;
              %goto MACRO_END;
           %end;
        %end;
     %end;
  %end;
  %else
  %do;
     /*----------------------------------------------------------------------------
      * Force them to specify it's a restart if not purging from the database
      * (which creates the key data sets used by the data set and solr purge code)
      *----------------------------------------------------------------------------*/
     %if %upcase(&purge_from_database) eq N and %upcase(&purge_from_data_sets) eq Y %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Parameter purge_from_database is &purge_from_database and purge_from_data_sets is &purge_from_data_sets but purge_restart is &purge_restart.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     %if %upcase(&purge_from_database) eq N and %upcase(&purge_from_solr) eq Y %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Parameter purge_from_database is &purge_from_database and purge_from_solr is &purge_from_solr but purge_restart is &purge_restart.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;
  %end;

  %if %upcase(&disable_ui) eq Y %then
  %do;
     %let ui_availability_ind=;

     proc sql noprint;
       select upcase(ui_availability_ind) into :ui_availability_ind
         from &db_lib_kc..fsk_ui_availability;
     quit;

     %put NOTE: FCF: &=ui_availability_ind;

     %if &ui_availability_ind eq N %then
     %do;
        %let _fcfmsg_=ERROR: FCF: Parameter disable_ui is &disable_ui but the UI is already unavailable to users.;
        %let trans_rc = 999999;
        %fcf_put_error;
        %goto MACRO_END;
     %end;

     /*----------------------------------
      * Make the UI unavailable to users
      *----------------------------------*/
     %fcf_set_ui_availability(availability_ind=N);

     %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %do;
        %goto MACRO_END;
     %end;

     %let ui_availability_set_by_this_job = Y;
  %end;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_purge_setup;

