/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_run_generated_headers.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Alert Generation Process
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_run_generated_headers(inLib=STG_ALER,
                                 inDS=generated_headers,
                                 exclude_header=);
  proc sort data=&inLib..&inDS(%fcf_get_ds_opts(lib_name=&inLib, ds_name=&inDS));
    by header_id;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to sort &inLib..&inDS;
     %fcf_put_error;
     %goto MACRO_FINAL_END;
  %end;

  proc sort data=seg_kc.fsk_header(keep=header_id header_name)
             out=generated_header_names;
    by header_id;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to sort seg_kc.fsk_header;
     %fcf_put_error;
     %goto MACRO_FINAL_END;
  %end;

  data generated_header_names;
    merge &inLib..&inDS(
                        %fcf_get_ds_opts(lib_name=&inLib, ds_name=&inDS)
                        in=a
                       )
          generated_header_names(in=b);
    by header_id;
    if a and b;
    %if &exclude_header ne  %then %do;
     if not indexw("&exclude_header", header_name);
    %end;
   run;

  %fcf_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _fcfmsg_=ERROR: FCF: Unable to merge &inLib..&inDS and seg_kc.fsk_header;
     %fcf_put_error;
     %goto MACRO_FINAL_END;
  %end;

 /*--------------------------------------
   * Get codegen path from FSK_PREFERENCE
   *--------------------------------------*/
  data _null_;
      %fcf_get_property_value(property=fcf.svr.aml.scenario.codegenPath,output_property_value=CODEGEN_LOCATION,output_status=property_status);
      %if &property_status ne 0 %then %do;
          %let _fcfmsg_=ERROR: FCF: Unable to get property fcf.svr.aml.scenario.codegenPath from SEG_KC.FSK_PREFERENCE;
          %let trans_rc = 999999;
          %fcf_put_error;
          %goto MACRO_END;
       %end;
  run;
  %let codegen_location=&codegen_location;

  %let dsidrungenheader = %sysfunc(open(generated_header_names));
  %if &dsidrungenheader ne 0 %then %do;
    %syscall set(dsidrungenheader);
    %let numgenheaders = %sysfunc(attrn(&dsidrungenheader, nlobs));
    %if &numgenheaders gt 0 %then %do;
      %do rowgenheader = 1 %to &numgenheaders;
        %let rcfetchgenheader = %sysfunc(fetchobs(&dsidrungenheader,&rowgenheader));
        %if &rcfetchgenheader = 0 %then %do;

          %let stripped_header_name = &header_name;
          %fcf_section_header(Section=%upcase(&stripped_header_name));
            %include "&codegen_location/&stripped_header_name..sas";
            %fcf_rcset(&syserr)
            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %let _fcfmodule_=&stripped_header_name;
               %let _fcfmsg_=ERROR: FCF: &stripped_header_name..sas failed check log.;
               %fcf_put_error;
               %goto MACRO_END;
            %end;
          %fcf_section_footer(Section=%upcase(&stripped_header_name));

        %end;
      %end;
    %end;
  %end;
  %else %goto MACRO_FINAL_END;

  %MACRO_END:
  %let dsidrungenheader = %sysfunc(close(&dsidrungenheader));

  %MACRO_FINAL_END:
%mend fcf_run_generated_headers;
