/*==============================================================================
| NAME:    fcf_wl_dfat_remove
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - Australian Department of Foreign Affairs and Trade
WATCH LIST NAME     - Consolidated List
WATCH LIST CODE     - DFAT
WEB LINK            - http://www.dfat.gov.au/icat/UNSC_financial_sanctions.html

MODULE TYPE         - REMOVE
MODULE PURPOSE      - Logically delete records that are no longer in the data file.

MODULE NOTES
------------
None

================================================================================
Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
- All rights reserved
==============================================================================*/

%macro fcf_wl_dfat_remove;

  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=FCF_WL_DFAT_REMOVE;

  /*---------------
   * USER SETTINGS
   *---------------*/

  /* Set DBMS locking option */
  %let LOCK_OPTIONS=;
  %if %upcase(&dbflavor) eq DB2 %then %do;
    %let LOCK_OPTIONS=%str(UPDATE_ISOLATION_LEVEL=RR);
  %end;
  %else %do;
    %let LOCK_OPTIONS=%str(UPDATE_LOCK_TYPE=TABLE REREAD_EXPOSURE=YES);
  %end;

  /*----------------------
   * END of USER SETTINGS
   *----------------------*/

  /*********************************************************************
   * DESCRIPTION:
   * For records in the data base that are no longer in the input
   * data file, mark these records as logically deleted.
   *
   * INPUTS(S):
   * stg_wtch.wl_dfat_delete
   *
   * OUTPUT(S):
   * seg_kc.fsc_entity_watch_dim
   *********************************************************************/
  %fcf_get_observation_count(table=stg_wtch.wl_dfat_noinput);
  %if %eval(&fcf_obs_count) gt 0 %then %do;

    data &seg_kc_libname..FSC_ENTITY_WATCH_LIST_DIM;
       set STG_WTCH.WL_DFAT_noinput(%fcf_get_ds_opts(lib_name=STG_WTCH, ds_name=WL_DFAT_noinput) rename=(change_end_date=update_end_date));
       modify &seg_kc_libname..FSC_ENTITY_WATCH_LIST_DIM(%fcf_get_ds_opts(lib_name=&seg_kc_libname, ds_name=FSC_ENTITY_WATCH_LIST_DIM) dbkey=entity_watch_list_key &lock_options) key=dbkey;
       if _iorc_=0 then do;
          change_end_date = update_end_date;
          change_current_ind = 'N';
          replace;
       end;

       else do;
          _error_=0;
          put 'WARNING: FCF: Could not update database with deleted watch list records: &watchlist: ' entity_watch_list_key=;
       end;
    run;
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %let _fcfmsg_=ERROR: FCF: Cannot remove records that no longer exist in the input data file.;
       %fcf_put_error;
       %goto MACRO_END;
    %end;

  %end;
  /* End of deleted records -- STG_WTCH.WL_dfat_noinput has obs */
  %else %do;
    %put NOTE: FCF: No records to be removed for watch list.;
  %end;
  
  %MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_dfat_remove;
