/*==============================================================================
| NAME:    fcf_wl_ofac_transport
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - U.S. Treasury - Office of Foreign Assets Control
WATCH LIST NAME     - Specially Designated Nationals List (SDN List)
WATCH LIST CODE     - OFAC
WEB LINK            - http://www.treas.gov/offices/enforcement/ofac/

MODULE TYPE         - TRANSFORM
MODULE PURPOSE      - Transform data related to vessels and aircraft
                      in prepartion for data load.

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2015-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_ofac_transport;

  /*------------
   * Set module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=fcf_WL_OFAC_TRANSPORT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /*------------------------------------------
   * get column names for watch_list_dim
   *------------------------------------------*/
  %fcf_get_column_names(table=seg_kc.fsc_entity_watch_list_dim);

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_ofac_transport_01                                       */
/*                                                                            */
/* DESCRIPTION: Select records from all SDN/ADD/ALT where SDN_TYPE=VESSEL     */
/*              or SDN_TYPE=AIRCRAFT                                          */
/*                                                                            */
/* STG_WTCH.wl_ofac_transport_01 - SDN                                        */
/* STG_WTCH.wl_ofac_transport_02 - ADD                                        */
/* STG_WTCH.wl_ofac_transport_03 - ALT                                        */
/******************************************************************************/
proc sql noprint;

    create table STG_WTCH.wl_ofac_transport_01 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_01, output_ds=Y, add_parens=Y)  as
      select *
      from STG_WTCH.wl_ofac_sdn_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_sdn_extract))
      where upcase(sdn_type) eq 'VESSEL'
            or upcase(sdn_type) eq 'AIRCRAFT';

   create table STG_WTCH.wl_ofac_transport_02 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_02, output_ds=Y, add_parens=Y)  as
      select *
      from STG_WTCH.wl_ofac_add_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_add_extract))
      where ent_num in (select ent_num from STG_WTCH.wl_ofac_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_01)));

   create table STG_WTCH.wl_ofac_transport_03 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_03, output_ds=Y, add_parens=Y)  as
      select *
      from STG_WTCH.wl_ofac_alt_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_alt_extract))
      where ent_num in (select ent_num from STG_WTCH.wl_ofac_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_01)));

quit;
/******************************************************************************/
/* END: STG_WTCH.wl_ofac_transport_01                                         */
/*      STG_WTCH.wl_ofac_transport_02                                         */
/*      STG_WTCH.wl_ofac_transport_03                                         */
/******************************************************************************/


/******************************************************************************/
/* BEGIN: STG_WTCH.wl_ofac_transport_04                                       */
/*        STG_WTCH.wl_ofac_transport_05                                       */
/*        STG_WTCH.wl_ofac_transport_06                                       */
/*                                                                            */
/* DESCRIPTION: Output fields from the SDN multiple entry text field REMARKS. */
/* Multiple entries within the REMARKS text field are delimited by ';'.       */
/*                                                                            */
/* STG_WTCH.wl_ofac_transport_04 - IDENTIFICATION_ID,IDENTIFICATION_TYPE_DESC */
/* STG_WTCH.wl_ofac_transport_05 - MODEL_TYPE,  ENTITY_FLAG                   */
/* STG_WTCH.wl_ofac_transport_06 - OWNER_OPERATOR                             */
/******************************************************************************/
data
stg_wtch.remarks(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=remarks, output_ds=Y)
                 keep=remarks remark_text) 

   STG_WTCH.wl_ofac_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_04, output_ds=Y)
                                 keep=
      ent_num
      remarks
      identification_id
      identification_type_desc
   )


   STG_WTCH.wl_ofac_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_05, output_ds=Y)
                                 keep=
      ent_num
      remarks
      entity_model_type
      entity_flag
   )

   STG_WTCH.wl_ofac_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_06, output_ds=Y)
                                 keep=
      ent_num
      remarks
      entity_owner_operator
   );


      /* TEMP FIELDS */
   attrib   remark_text                    length=$1000;

   /* FSC_TRANSPORT_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;

   /* Exclude records where remarks=-0- (no remarks) */
   set STG_WTCH.wl_ofac_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_01)
                                     where=(remarks ne '-0-')
                                     keep=ent_num
                                     sdn_type
                                     vess_type
                                     vess_owner
                                     vess_flag
                                     remarks) end=eof;

   /* Obtain a count of the number of entries within the remarks field */
   num_remarks=countc(remarks,';') + 1;

   /* Iterate thru remarks field */
   /* Output a record for each instance of a valid entry */
   do i=1 to num_remarks;
      remark_text=upcase(kscan(remarks,i,';'));
output stg_wtch.remarks;
      /* sdn_type=VESSEL */
      if upcase(sdn_type) eq 'VESSEL' then do;
   
         /* if first remark, load ENTITY_MODEL_TYPE ENTITY_OWNER_TYPE ENTITY_FLAG 
            with vess_type, vess_owner, vess_flag information                     */
         if i eq 1 then do;
            entity_model_type=vess_type;
            entity_owner_operator=vess_owner;
            entity_flag=kstrip(upcase(vess_flag));
			if kindex(entity_flag,"NONE IDENTIFIED") then entity_flag="";
			if not missing(entity_flag) or not missing(entity_model_type) then output STG_WTCH.wl_ofac_transport_05;
			if entity_owner_operator ne "-0-" then output STG_WTCH.wl_ofac_transport_06;
          end;
         
         /* CHECK FOR FORMER VESSEL FLAG */
         if indexw(remark_text,"FORMER VESSEL FLAG") then do;
            remark_text=tranwrd(remark_text,"ALT.","");
            remark_text=tranwrd(remark_text,"FORMER VESSEL FLAG","");
            if (kindex(remark_text,"NONE"))=0 then do;
                entity_flag=kcompress(remark_text);
                output STG_WTCH.wl_ofac_transport_05;
			end;
         end;

         /* IDENTIFICATION_ID
            IDENTIFICATION_TYPE_DESC=VESSEL REGISTRATION IDENTIFICATION IMO */
         if indexw(remark_text,'IMO') then do;
            identification_type_desc='IMO';
            start=kindex(remark_text,'IMO')+4;
            end=length(remark_text);
            if kindex(remark_text,'(') then end=kindex(remark_text,'(')-1;
            identification_id=kcompress(substr(remark_text,start,end-start));
            identification_id=tranwrd(identification_id,'.','');
            output STG_WTCH.wl_ofac_transport_04;
         end; /* end: identification_type_desc / identification_type_desc='IMO' */

         /* IDENTIFICATION_ID
            IDENTIFICATION_TYPE_DESC=MMSI */
         else if indexw(upcase(remark_text),'MMSI') then do;
            identification_type_desc='MMSI';
            identification_id=kcompress(substr(remark_text,6));
            output STG_WTCH.wl_ofac_transport_04;
         end; /* end: identification_id / identification_type_desc='MMSI' */

      end; /* end: sdn_type='VESSEL' */


      /* sdn_type=AIRCRAFT */
      /* IDENTIFICATION_ID
         IDENTIFICATION_TYPE_DESC=MSN */
      if upcase(sdn_type) eq 'AIRCRAFT' then do;
         if indexw(remark_text,'MSN') then do;
            identification_type_desc='MSN';
            identification_id=kcompress(substr(remark_text,kindex(remark_text,")")+2));
            output STG_WTCH.wl_ofac_transport_04;
         end;  /* end:  identification_id / identification_type_desc='MSN' */

         /* IDENTIFICATION_ID
            IDENTIFICATION_TYPE_DESC=AIRCRAFT CONSTRUCTION NUMBER */
         else if indexw(remark_text,'AIRCRAFT CONSTRUCTION NUMBER') then do;
            identification_type_desc='AIRCRAFT CONSTRUCTION NUMBER';
            identification_id=kcompress(substr(remark_text,kindex(remark_text,")")+2));
            output STG_WTCH.wl_ofac_transport_04;
         end; /* end: identification_id / identification_type_desc='AIRCRAFT CONSTRUCTION NUMBER' */

         /* ENTITY_MODEL_TYPE */
         else if indexw(remark_text,'AIRCRAFT MODEL') then do;
            ENTITY_MODEL_TYPE=kcompress(tranwrd(remark_text,'AIRCRAFT MODEL',''));
            output STG_WTCH.wl_ofac_transport_05;
         end; /* end: entity_model_type */
      
         /* ENTITY_OWNER_OPERATOR */
         else if indexw(remark_text,'AIRCRAFT OPERATOR') then do;
            entity_owner_operator=kcompress(tranwrd(remark_text,'AIRCRAFT OPERATOR',''));
            output STG_WTCH.wl_ofac_transport_06;
         end; /* end: identification_id / identification_type_desc='COMMERCIAL REGISTRY NUMBER' */
      end; /* aircraft */
   end; /* end: process remarks field */

   /* Set all columns in if set 1=0 column to missing */
   call missing(&col_name_list);

run;

/* Remove potential duplicate entries */
proc sort data=STG_WTCH.wl_ofac_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_04))
          out=STG_WTCH.wl_ofac_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_04, output_ds=Y))
          nodupkey;
by ent_num
   identification_id
   identification_type_desc;
run;

proc sort data=STG_WTCH.wl_ofac_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_05))
          out=STG_WTCH.wl_ofac_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_05, output_ds=Y))
          nodupkey;
by ent_num
   entity_model_type
   entity_flag;
run;

proc sort data=STG_WTCH.wl_ofac_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_06))
          out=STG_WTCH.wl_ofac_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_06, output_ds=Y))
          nodupkey;
by ent_num
   entity_owner_operator;
run;


/******************************************************************************/
/* END:   STG_WTCH.wl_ofac_transport_04                                       */
/*        STG_WTCH.wl_ofac_transport_05                                       */
/*        STG_WTCH.wl_ofac_transport_06                                       */
/******************************************************************************/

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_ofac_transport_07                                       */
/*                                                                            */
/* DESCRIPTION: The final output table 'STG_WTCH.wl_ofac_transport' from this */
/* step contains all possible data permutations for each unique ENT_NUM.      */
/******************************************************************************/

proc sql noprint;

   create table STG_WTCH.wl_ofac_transport_07 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_07, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.identification_id,
             b.identification_type_desc
      from STG_WTCH.wl_ofac_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_01)) as a full join
           STG_WTCH.wl_ofac_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_04)) as b
      on a.ent_num=b.ent_num;
quit;


proc sql noprint;

   create table STG_WTCH.wl_ofac_transport_08 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_08, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.entity_model_type,
             b.entity_flag
      from STG_WTCH.wl_ofac_transport_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_07)) as a full join
           STG_WTCH.wl_ofac_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_05)) as b
      on a.ent_num=b.ent_num;
quit;


proc sql noprint;

   create table STG_WTCH.wl_ofac_transport_09 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_09, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.entity_owner_operator
      from STG_WTCH.wl_ofac_transport_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_08)) as a full join
           STG_WTCH.wl_ofac_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_06)) as b
      on a.ent_num=b.ent_num;
quit;

proc sql noprint;

   create table STG_WTCH.wl_ofac_transport_10 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_10, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.add_num,
             b.address,
             b.city,
             b.country
      from STG_WTCH.wl_ofac_transport_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_09)) as a full join
           STG_WTCH.wl_ofac_transport_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_02)) as b
      on a.ent_num=b.ent_num;
quit;

proc sql noprint;

   create table STG_WTCH.wl_ofac_transport_11 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_11, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.alt_num,
             b.alt_type,
             b.alt_name
      from STG_WTCH.wl_ofac_transport_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_10)) as a inner join
           STG_WTCH.wl_ofac_transport_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_03)) as b
      on a.ent_num=b.ent_num;
quit;
/******************************************************************************/
/* END: STG_WTCH.wl_ofac_transport_08                                         */
/******************************************************************************/

/******************************************************************************/
/* BEGIN: STG_WTCH.wl_ofac_transport                                          */
/* DESCRIPTION: Output table 'STG_WTCH.wl_ofac_transport' contains all final  */
/*              data transformations.                                         */
/******************************************************************************/
data

  STG_WTCH.wl_ofac_transport(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport, output_ds=Y)
                             keep=
     transport_watch_list_key
     transport_watch_list_number
     watch_list_name
     type_desc
     programs
     identification_id
     identification_type_desc
     entity_name
     entity_model_type
     entity_owner_operator
     entity_flag
     address
     city_name
     state_name
     country_code
     country_name
     create_date
     update_date
     exclude_ind
     change_begin_date
     change_end_date
     change_current_ind
  );

    /* FSC_TRANSPORT_WATCH_LIST_DIM */
    if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;


    set STG_WTCH.wl_ofac_transport_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_10))
        STG_WTCH.wl_ofac_transport_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport_11) rename=(address=ofac_address)) end=eof;


/******************************************************************************/
/* NOTE:                                                                      */
/*                                                                            */
/* Initial values for the fields listed below are set to missing as these     */
/* fields values are set by later processes.                                  */
/******************************************************************************/

    /* Fields set by load */
    entity_watch_list_key=.;
    change_begin_date=.;
    change_end_date=.;
    change_current_ind='';

    retain error_flag 0;

/* ************************************************************************ */
/* NOTE:                                                                    */
/*                                                                          */
/* The following fields are set to null as this watch list extract does not */
/* currently include this data.                                             */
/* ************************************************************************ */
    create_date=.;
    update_date=.;

    /* initialize values */
    state_name='';
    postal_code='';



    /* TRANSPORT_WATCH_LIST_NUMBER */
    /* NOTE: watch_list_number is composed of ent_num, add_num and alt_num */
    if not missing(alt_num) then do;
      transport_watch_list_number=kstrip(put(ent_num,best32.)) || '-' ||
                               kstrip(put(add_num,best32.)) || '-' ||
                               kstrip(put(alt_num,best32.));
	  entity_name=alt_nam;
	end;
    else if missing(alt_num) then
      transport_watch_list_number=kstrip(put(ent_num,best32.)) || '-' ||
                               kstrip(put(add_num,best32.)) || '-0';

    /* WATCH_LIST_NAME */
    watch_list_name='OFAC';

    /* CATEGORY_DESC */
    if index(upcase(program),'SDGT') or
      index(upcase(program),'SDT') then
      category_desc='TERRORISM';


    /* TYPE_DESC */
    type_desc=upcase(sdn_type);
    

    /* PROGRAMS */
    programs=upcase(program);

    
   /* ENTITY_NAME */
   entity_name=upcase(compbl(kstrip(sdn_name)));


    /* ADDRESS */
    if ofac_address ne '-0-' then
      address=upcase(compbl(kstrip(ofac_address)));
    else address='';

    /* CITY, STATE/PROVINCE, POSTAL CODE */
    if city ne '-0-' then do;


      /* Find STATE/PROVINCE by searching from right of string for comma */
      find_rc = findc(city, ',', 'b');
      if find_rc > 0 then do;
         city_name = upcase(substr(city, 1, find_rc -1));
         state_name = upcase(kstrip(substr(city, find_rc+1)));
      end;
      else do;
        city_name=upcase(compbl(kstrip(city)));
        state_name = '';
      end;

    end;
    else if city eq '-0-' then do;
      city_name='';
      state_name='';
    end;

    /* COUNTRY_NAME */
    if country ne '-0-' then do;
      country_name=upcase(compbl(kstrip(country)));
    end;
    else if country eq '-0-' then do;
      country_name='';
    end;
	if missing(country_name) then country_name=entity_flag; 

	/* EXCLUDE_IND */
    exclude_ind='N';
    
run;

/************************************************/
/*  Add Country Code                            */
/************************************************/
data STG_WTCH.postwl_ofac_transport(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=postwl_ofac_transport, output_ds=Y));
 set STG_WTCH.wl_ofac_transport(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_ofac_transport));
    if missing(country_code) and not missing(country_name) then do;
       country_code = put(country_name, $country_code.);
    end;
run;


  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_wl_ofac_transport;
