/*==============================================================================
| NAME:    fcf_wl_wchk_remove
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - World-Check
WATCH LIST NAME     - Data File
WATCH LIST CODE     - WCHK
WEB LINK            - https://www.world-check.com/login/

MODULE TYPE         - DELETE
MODULE PURPOSE      - Remove deleted watch list profiles from FCF database.

MODULE NOTES
------------
None
==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_wchk_remove(delete_file=);

  /*************************************************************************/
  /* DESCRIPTION: If the parameter 'delete_file' is not null then process  */
  /* the requested deletes.                                                */
  /*************************************************************************/
  %if %symexist(delete_file) = 0 %then %do;
     %let _fcfmsg_ = NOTE: FCF: No delete data file was specified.  No profiles will be removed from the FCF database.;
     %put &_fcfmsg_;
     %goto MACRO_END;
  %end;
  %if "&delete_file" eq "" %then %do;
     %let _fcfmsg_ = NOTE: FCF: No delete data file was specified.  No profiles will be removed from the FCF database.;
     %put &_fcfmsg_;
     %goto MACRO_END;
  %end;
  %if not %sysfunc(fileexist(&delete_file)) %then %do;
     %let _fcfmsg_ = NOTE: FCF: The specified delete data file does not exist. No profiles will be removed from the FCF database.;
     %put &_fcfmsg_;
     %goto MACRO_END;
  %end;

  /* Make sure runasofdate is set */
  %if not %symexist(runasofdate) %then %do;
    %fcf_get_runasofdate;
    %if not %symexist(runasofdate) %then %do;
      %let _fcfmsg_=ERROR: FCF: Runasofdate could not be set.  &_fcfmodule_ exiting.;
      %put &_fcfmsg_;
      %let trans_rc=999999;
      %goto MACRO_END;
    %end;
  %end;
  %if &runasofdate eq %str() %then %do;
    %let _fcfmsg_=ERROR: FCF: Runasofdate is not set correctly.  &_fcfmodule_ exiting.;
    %put &_fcfmsg_;
    %let trans_rc=999999;
    %goto MACRO_END;
  %end;

  filename in_del "&delete_file";

  data STG_WTCH.wl_wchk_delete_load(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_delete_load, output_ds=Y));
    infile in_del delimiter='09'x dsd missover lrecl=32767 firstobs=2 end=eof;
    attrib
         entity_watch_list_number   length=$35
                                    informat=$35.
                                    format=$35.
                                    label='Entity Watch List Number'

         location_watch_list_number length=$35
                                    informat=$35.
                                    format=$35.
                                    label='Location Watch List Number'

         uid                        length=8
                                    informat=best32.
                                    format=best32.
                                    label='UID'

         timestamp                  length=$26
                                    informat=$26.
                                    format=$26.
                                    label='Timestamp'
      ;

    input uid timestamp $;

    /* ENTITY_WATCH_LIST_NUMBER */
    entity_watch_list_number=kstrip(put(uid,best32.));

    /* LOCATION_WATCH_LIST_NUMBER */
    location_watch_list_number=kstrip(put(uid,best32.));
    
  run;

  /* Remove duplicate values for watch_list_number */
  proc sort data=STG_WTCH.wl_wchk_delete_load(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_delete_load))
             out=STG_WTCH.wl_wchk_delete_load(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_delete_load, output_ds=Y))
             nodupkey;
    by entity_watch_list_number;
  run;

  proc sql;
    update seg_kc.fsc_entity_watch_list_dim
      set change_end_date=dhms(input(put(&runasofdate,8.),yymmdd8.),00,00,00),
           change_current_ind = 'N'
      where upcase(watch_list_name) = 'WCHK' and
            upcase(change_current_ind) = 'Y' and
            entity_watch_list_number in
              (select entity_watch_list_number
                 from STG_WTCH.wl_wchk_delete_load(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_delete_load)));
  quit;
  
  proc sql;
    update seg_kc.fsc_location_watch_list_dim
       set change_end_date=dhms(input(put(&runasofdate,8.),yymmdd8.),00,00,00),
           change_current_ind = 'N'
       where upcase(watch_list_name) = 'WCHK' and
             upcase(change_current_ind) = 'Y' and
             location_watch_list_number in
              (select location_watch_list_number
                 from STG_WTCH.wl_wchk_delete_load(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_wchk_delete_load)));
  quit;


  %MACRO_END:

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
    %fcf_execute_macro(fcf_error);
  %else %do;
    %fcf_execute_macro(post&_fcfmodule_);
    %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_wl_wchk_remove;
