/***********************************************************************************/
/* Copyright (c) 2015, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          rc_efile_gen_xpose_node                                          */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Generate program code for writing efiles                         */
/* PARAMETERS:                                                                     */
/*                form_config_key                                                  */
/* NOTE:                                                                           */
/***********************************************************************************/

 
%macro  rc_efile_gen_macro_xpose_node( form_config_key=
                                      , form_type_code= 
               ) /  des='Macro to create sas code for loading UI data to efile tables';                                                                                                                                                                                                                                              
                 
   
    proc sql noprint;      
 
         
         create table form_efile_record_config as
         select *                
         from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
         where form_config_key=&form_config_key
               and source_table_name = 'RC_REPORT_NODE' 
         order by form_efile_record_id
         ;
         %let form_record_cnt=&sqlobs;

 
   
   %do record_i=1 %to &form_record_cnt ;
         
        data _null_;
                set form_efile_record_config (firstobs=&record_i);              
                call symput("form_efile_record_id",form_efile_record_id);
                call symput("form_efile_record_seq_number",strip(put(form_efile_record_seq_number,best.)));
                call symput("record_length",strip(put(record_length,best.)));
                call symput("source_table_name",source_table_name); 
                stop; 
           run;    
         proc sql;
         create table form_efile_field_config as
         select form_config_key,
                form_efile_record_id,
                case
                    when (index(source_field_name,'.') > 0) then scan(source_field_name,2,'.') 
                    else source_field_name
                end as source_field_name length=64,
                source_field_type,
                source_field_type_parm_list,
                target_field_name,
                target_field_num_flg
                
 
         from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
             where form_config_key=&form_config_key
               and form_efile_record_id="&form_efile_record_id"
               and source_field_name ne '' 
               and target_field_name ne ''
         
         ;   
         
                                                                                                                                                                                                                            

       data _null_;                                                                                                                                                                                                                                                  
        
       Set form_efile_field_config end = eof ;
       length stmt $ 4000; 
       %if &record_i=1 %then
       %do;
       file rc_tmplt(&form_type_code._macro_xpose_node.sas);
       %end;
       %else 
       %do;
        file rc_tmplt(&form_type_code._macro_xpose_node.sas) mod;
       %end;

       If _n_ = 1 then 
       do ;                                                                                                                                                                                                                                        
          stmt= '%macro rc_load_'
                ||strip("&form_type_code")
                ||'_'||strip("&form_efile_record_id")
                ||';'; 
          put stmt;                                                                                                                           
       end ; 

       select (upcase(source_field_type));
           when ('BOOLEAN') 
           do;
               stmt='if source_field_name="'||strip(source_field_name)||'"'||' and node_value="true"  then '||strip(target_field_name)||'="';
        
              if source_field_type_parm_list = '' then
                  stmt=strip(stmt)||'X';
              else stmt=strip(stmt)||strip(source_field_type_parm_list);
              stmt=strip(stmt)||'";';
              put stmt;
           end;
           when ('DATE') /* eg 2002-02-22T05:02:40.000+00:00 */
           do;
              stmt='if source_field_name="'||strip(source_field_name)||'" then '||strip(target_field_name)||'=input(substrn(node_value,1,10),yymmdd10.);';
              put stmt;
           end;
           when ('ARRYCAT') 
           do;
              stmt='if first.node_path then '||strip(target_field_name)||'="";';
              put stmt;
              stmt='if substr(source_field_name,1,length(source_field_name)-1)="'||strip(source_field_name)||'" then '
                   ||strip(target_field_name)||'=strip('||strip(target_field_name)||')||substr(source_field_name,length(source_field_name),1);';
              put stmt;
           end;
           otherwise
           do;            
              if target_field_num_flg='' then
                 stmt='if source_field_name="'||strip(source_field_name)||'" then '||strip(target_field_name)||'=strip(node_value);';
              else 
                 stmt='if source_field_name="'||strip(source_field_name)||'" then '||strip(target_field_name)||'=input(strip(node_value),best20.);';
              put stmt;
           end;
       end;
       
        
       If eof then 
       do;
          stmt='%mend;'; put stmt; 
       end;
    run; 
  

   data _null_;                                                                                                                                                                                                                                                  
        
       Set form_efile_field_config end = eof ;
       length stmt $ 4000; 
       %if &record_i=1 %then
       %do;
       file rc_tmplt(&form_type_code._macro_clear_node.sas);
       %end;
       %else 
       %do;
        file rc_tmplt(&form_type_code._macro_clear_node.sas) mod;
       %end;

       If _n_ = 1 then 
       do ;                                                                                                                                                                                                                                        
          stmt= '%macro rc_clear_'
                ||strip("&form_type_code")
                ||'_'||strip("&form_efile_record_id")
                ||';'; 
          put stmt;                                                                                                                           
       end ; 

          
      if target_field_num_flg='' then
          stmt=strip(target_field_name)||'=" ";';
      else 
          stmt=strip(target_field_name)||'=.;';
          
       put stmt;
       
        
       If eof then 
       do;
          stmt='%mend;'; put stmt; 
       end;
    run; 
   %end;
 
%MEND;   

 
