/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_xml_gen.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Macro to generate sas code to create xml tag with the same name
|          This macro is used to transform RC_CFG.FINCEN_* data fields.
|           
| NOTE:    This macro is used in <form_type_code>_macro_wrt_xml.sas in rc_template
|          which is generated by %rc_efile_gen_macro_wrt_xml in 
|          rc_fincen_config_<form_type_code>.sas 
+------------------------------------------------------------------------------+
| USAGE:   field_name = name of the data field
|          field_type = type of data field 
|                       BOOLEAN - boolean type  
|                       ARRYCAT - multiple codes in one field  
|                       DATE    - date (input must be SAS date (not timestamp) and
|                                 output date is in yyyymmdd
|                       CODE    - code will look for format with name same as the field
|                                 name to convert the value
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_xml_gen(field_name=, field_type=);

%if &field_type=BOOLEAN %then
%do; 
   /* assuming X, 1 or Y are true */
   if indexc(upcase(&field_name),'YX1') > 0 then
   do; 
      stmt="<&field_name>Y</&field_name>"; 
      put stmt;
   end;
%end;

%else %if &field_type=DATE %then
%do;
   if &field_name > 0 then
   do; 
       stmt="<&field_name>"||strip(putn(&field_name),'yymmddn8.'||"</&field_name>"; 
       put stmt;
   end;
%end;

%else %if &field_type=ARRYCAT %then
%do; /* create a boolean field with the character value  as suffix */
     /* For example, if myType='AD', myTypeA and myTypeD will be created with value Y*/  
   do i=1 to length(&field_name);      
       if &field_name > '' then
       do; 
         stmt="<&field_name"||substr(upcase(&field_name),i,1)||">Y</&field_name"||substr(upcase(&field_name),i,1)||">"; 
         put stmt;
       end;
   end;
%end;
%else %if &field_type=CODE %then
%do;
    if &field_name > '' then
    do;
        %let format_name=%sysfunc(compress(&field_name,_));
        %put &field_name format_name=&format_name;
        %if  %sysfunc(cexist(work.formats.&format_name..formatc)) %then
        %do;    
            stmt="<&field_name>"||strip(putc(&field_name,"&format_name"))||"</&field_name>"; 
            put stmt;
        %end;
        %else
        %do;
            stmt="<&field_name>"||strip(htmlencode(&field_name))||"</&field_name>"; 
            put stmt;
        %end;
    end;
%end;
%else
%do; 
   if &field_name > '' then
   do; 
     stmt="<&field_name>"||strip(htmlencode(&field_name))||"</&field_name>"; 
     put stmt;
   end;
%end;

%mend;


